{
 "metadata": {
  "name": "",
  "signature": "sha256:bc95a0e240c414c6a988f3b0cfea66060b6485f50c637d5ce7282afae01700da"
 },
 "nbformat": 3,
 "nbformat_minor": 0,
 "worksheets": [
  {
   "cells": [
    {
     "cell_type": "heading",
     "level": 1,
     "metadata": {},
     "source": [
      "Particle Filters!"
     ]
    },
    {
     "cell_type": "markdown",
     "metadata": {},
     "source": [
      "Make a robot called myrobot that starts at coordinates 30, 50 heading north (pi/2). Have your robot turn clockwise by pi/2, move 5 m, and sense. Then have it turn clockwise by pi/2 again, move 10 m, and sense again.\n",
      " Your program should print out the result of your two sense measurements. Don't modify the code below. Please enter your code at the bottom.\n"
     ]
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "\n",
      "from math import *\n",
      "import random\n",
      "\n",
      "\n",
      "\n",
      "landmarks  = [[20.0, 20.0], [80.0, 80.0], [20.0, 80.0], [80.0, 20.0]]\n",
      "world_size = 100.0\n",
      "\n",
      "\n",
      "class robot:\n",
      "    def __init__(self):\n",
      "        self.x = random.random() * world_size\n",
      "        self.y = random.random() * world_size\n",
      "        self.orientation = random.random() * 2.0 * pi\n",
      "        self.forward_noise = 0.0;\n",
      "        self.turn_noise    = 0.0;\n",
      "        self.sense_noise   = 0.0;\n",
      "    \n",
      "    def set(self, new_x, new_y, new_orientation):\n",
      "        if new_x < 0 or new_x >= world_size:\n",
      "            raise ValueError, 'X coordinate out of bound'\n",
      "        if new_y < 0 or new_y >= world_size:\n",
      "            raise ValueError, 'Y coordinate out of bound'\n",
      "        if new_orientation < 0 or new_orientation >= 2 * pi:\n",
      "            raise ValueError, 'Orientation must be in [0..2pi]'\n",
      "        self.x = float(new_x)\n",
      "        self.y = float(new_y)\n",
      "        self.orientation = float(new_orientation)\n",
      "    \n",
      "    \n",
      "    def set_noise(self, new_f_noise, new_t_noise, new_s_noise):\n",
      "        # makes it possible to change the noise parameters\n",
      "        # this is often useful in particle filters\n",
      "        self.forward_noise = float(new_f_noise);\n",
      "        self.turn_noise    = float(new_t_noise);\n",
      "        self.sense_noise   = float(new_s_noise);\n",
      "    \n",
      "    \n",
      "    def sense(self):\n",
      "        Z = []\n",
      "        for i in range(len(landmarks)):\n",
      "            dist = sqrt((self.x - landmarks[i][0]) ** 2 + (self.y - landmarks[i][1]) ** 2)\n",
      "            dist += random.gauss(0.0, self.sense_noise)\n",
      "            Z.append(dist)\n",
      "        return Z\n",
      "    \n",
      "    \n",
      "    def move(self, turn, forward):\n",
      "        if forward < 0:\n",
      "            raise ValueError, 'Robot cant move backwards'         \n",
      "        \n",
      "        # turn, and add randomness to the turning command\n",
      "        orientation = self.orientation + float(turn) + random.gauss(0.0, self.turn_noise)\n",
      "        orientation %= 2 * pi\n",
      "        \n",
      "        # move, and add randomness to the motion command\n",
      "        dist = float(forward) + random.gauss(0.0, self.forward_noise)\n",
      "        x = self.x + (cos(orientation) * dist)\n",
      "        y = self.y + (sin(orientation) * dist)\n",
      "        x %= world_size    # cyclic truncate\n",
      "        y %= world_size\n",
      "        \n",
      "        # set particle\n",
      "        res = robot()\n",
      "        res.set(x, y, orientation)\n",
      "        res.set_noise(self.forward_noise, self.turn_noise, self.sense_noise)\n",
      "        return res\n",
      "    \n",
      "    def Gaussian(self, mu, sigma, x):\n",
      "        \n",
      "        # calculates the probability of x for 1-dim Gaussian with mean mu and var. sigma\n",
      "        return exp(- ((mu - x) ** 2) / (sigma ** 2) / 2.0) / sqrt(2.0 * pi * (sigma ** 2))\n",
      "    \n",
      "    \n",
      "    def measurement_prob(self, measurement):\n",
      "        \n",
      "        # calculates how likely a measurement should be\n",
      "        \n",
      "        prob = 1.0;\n",
      "        for i in range(len(landmarks)):\n",
      "            dist = sqrt((self.x - landmarks[i][0]) ** 2 + (self.y - landmarks[i][1]) ** 2)\n",
      "            prob *= self.Gaussian(dist, self.sense_noise, measurement[i])\n",
      "        return prob\n",
      "    \n",
      "    \n",
      "    \n",
      "    def __repr__(self):\n",
      "        return '[x=%.6s y=%.6s orient=%.6s]' % (str(self.x), str(self.y), str(self.orientation))\n",
      "\n",
      "\n",
      "\n",
      "def eval(r, p):\n",
      "    sum = 0.0;\n",
      "    for i in range(len(p)): # calculate mean error\n",
      "        dx = (p[i].x - r.x + (world_size/2.0)) % world_size - (world_size/2.0)\n",
      "        dy = (p[i].y - r.y + (world_size/2.0)) % world_size - (world_size/2.0)\n",
      "        err = sqrt(dx * dx + dy * dy)\n",
      "        sum += err\n",
      "    return sum / float(len(p))\n",
      "\n",
      "\n",
      "\n",
      "####   DON'T MODIFY ANYTHING ABOVE HERE! ENTER CODE BELOW ####\n"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "[39.05124837953327, 46.09772228646444, 39.05124837953327, 46.09772228646444]\n",
        "[32.01562118716424, 53.150729063673246, 47.16990566028302, 40.311288741492746]\n"
       ]
      }
     ],
     "prompt_number": 1
    },
    {
     "cell_type": "heading",
     "level": 2,
     "metadata": {},
     "source": [
      "Adding Noise"
     ]
    },
    {
     "cell_type": "markdown",
     "metadata": {},
     "source": [
      "Now add noise to your robot as follows:\n",
      "forward_noise = 5.0, turn_noise = 0.1,\n",
      "sense_noise = 5.0.\n",
      " Once again, your robot starts at 30, 50,\n",
      " heading north (pi/2), then turns clockwise\n",
      " by pi/2, moves 15 meters, senses,\n",
      " then turns clockwise by pi/2 again, moves\n",
      " 10 m, then senses again.\n",
      "\n",
      " Your program should print out the result of\n",
      " your two sense measurements.\n",
      "\n",
      " Don't modify the code below. Please enter\n",
      " your code at the bottom.\n",
      " \n",
      " We can do this by using the <code>set_noise</code> function"
     ]
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "from math import *\n",
      "import random\n",
      "\n",
      "\n",
      "\n",
      "landmarks  = [[20.0, 20.0], [80.0, 80.0], [20.0, 80.0], [80.0, 20.0]]\n",
      "world_size = 100.0\n",
      "\n",
      "\n",
      "class robot:\n",
      "    def __init__(self):\n",
      "        self.x = random.random() * world_size\n",
      "        self.y = random.random() * world_size\n",
      "        self.orientation = random.random() * 2.0 * pi\n",
      "        self.forward_noise = 0.0;\n",
      "        self.turn_noise    = 0.0;\n",
      "        self.sense_noise   = 0.0;\n",
      "    \n",
      "    def set(self, new_x, new_y, new_orientation):\n",
      "        if new_x < 0 or new_x >= world_size:\n",
      "            raise ValueError, 'X coordinate out of bound'\n",
      "        if new_y < 0 or new_y >= world_size:\n",
      "            raise ValueError, 'Y coordinate out of bound'\n",
      "        if new_orientation < 0 or new_orientation >= 2 * pi:\n",
      "            raise ValueError, 'Orientation must be in [0..2pi]'\n",
      "        self.x = float(new_x)\n",
      "        self.y = float(new_y)\n",
      "        self.orientation = float(new_orientation)\n",
      "    \n",
      "    \n",
      "    def set_noise(self, new_f_noise, new_t_noise, new_s_noise):\n",
      "        # makes it possible to change the noise parameters\n",
      "        # this is often useful in particle filters\n",
      "        self.forward_noise = float(new_f_noise);\n",
      "        self.turn_noise    = float(new_t_noise);\n",
      "        self.sense_noise   = float(new_s_noise);\n",
      "    \n",
      "    \n",
      "    def sense(self):\n",
      "        Z = []\n",
      "        for i in range(len(landmarks)):\n",
      "            dist = sqrt((self.x - landmarks[i][0]) ** 2 + (self.y - landmarks[i][1]) ** 2)\n",
      "            dist += random.gauss(0.0, self.sense_noise)\n",
      "            Z.append(dist)\n",
      "        return Z\n",
      "    \n",
      "    \n",
      "    def move(self, turn, forward):\n",
      "        if forward < 0:\n",
      "            raise ValueError, 'Robot cant move backwards'         \n",
      "        \n",
      "        # turn, and add randomness to the turning command\n",
      "        orientation = self.orientation + float(turn) + random.gauss(0.0, self.turn_noise)\n",
      "        orientation %= 2 * pi\n",
      "        \n",
      "        # move, and add randomness to the motion command\n",
      "        dist = float(forward) + random.gauss(0.0, self.forward_noise)\n",
      "        x = self.x + (cos(orientation) * dist)\n",
      "        y = self.y + (sin(orientation) * dist)\n",
      "        x %= world_size    # cyclic truncate\n",
      "        y %= world_size\n",
      "        \n",
      "        # set particle\n",
      "        res = robot()\n",
      "        res.set(x, y, orientation)\n",
      "        res.set_noise(self.forward_noise, self.turn_noise, self.sense_noise)\n",
      "        return res\n",
      "    \n",
      "    def Gaussian(self, mu, sigma, x):\n",
      "        \n",
      "        # calculates the probability of x for 1-dim Gaussian with mean mu and var. sigma\n",
      "        return exp(- ((mu - x) ** 2) / (sigma ** 2) / 2.0) / sqrt(2.0 * pi * (sigma ** 2))\n",
      "    \n",
      "    \n",
      "    def measurement_prob(self, measurement):\n",
      "        \n",
      "        # calculates how likely a measurement should be\n",
      "        \n",
      "        prob = 1.0;\n",
      "        for i in range(len(landmarks)):\n",
      "            dist = sqrt((self.x - landmarks[i][0]) ** 2 + (self.y - landmarks[i][1]) ** 2)\n",
      "            prob *= self.Gaussian(dist, self.sense_noise, measurement[i])\n",
      "        return prob\n",
      "    \n",
      "    \n",
      "    \n",
      "    def __repr__(self):\n",
      "        return '[x=%.6s y=%.6s orient=%.6s]' % (str(self.x), str(self.y), str(self.orientation))\n",
      "\n",
      "\n",
      "\n",
      "def eval(r, p):\n",
      "    sum = 0.0;\n",
      "    for i in range(len(p)): # calculate mean error\n",
      "        dx = (p[i].x - r.x + (world_size/2.0)) % world_size - (world_size/2.0)\n",
      "        dy = (p[i].y - r.y + (world_size/2.0)) % world_size - (world_size/2.0)\n",
      "        err = sqrt(dx * dx + dy * dy)\n",
      "        sum += err\n",
      "    return sum / float(len(p))\n",
      "\n",
      "\n",
      "\n",
      "####   DON'T MODIFY ANYTHING ABOVE HERE! ENTER CODE BELOW ####\n",
      "\n",
      "myrobot = robot()\n",
      "# enter code here\n",
      "\n"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "[38.64044201699455, 47.63778565155778, 42.592273435917036, 38.695638867987014]\n",
        "[28.820716992349755, 54.192106538643635, 42.8674784192372, 42.27236579530312]\n"
       ]
      }
     ],
     "prompt_number": 2
    },
    {
     "cell_type": "heading",
     "level": 1,
     "metadata": {},
     "source": [
      "Details on sensing."
     ]
    },
    {
     "cell_type": "markdown",
     "metadata": {},
     "source": [
      "The sense method returns the distance the robot is from 4 beacons. I should also note that the world is cyclic. If the robot exits one side he shows up on the other.\n",
      "\n",
      "For our particle filter we are going to create 1,000 particles that are randomly placed in the world. Each particle is a vector of three numbers. For\n",
      "example [38.2, 12.4, 0.18]. These are the x and y coordinates and the heading (orientation) - the angle relative to the x axis.\n",
      "\n",
      "We need to create a list of 1,000 random particles. In the code below that is N. The list of particles is called p and is initially empty. Add 1,000 random particles to p\n",
      "\n",
      "HINT: Look at the initializer for the robot class.\n",
      "\n"
     ]
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "\n",
      "# Now we want to create particles,\n",
      "# p[i] = robot(). In this assignment, write\n",
      "# code that will assign 1000 such particles\n",
      "# to a list.\n",
      "#\n",
      "# Your program should print out the length\n",
      "# of your list (don't cheat by making an\n",
      "# arbitrary list of 1000 elements!)\n",
      "#\n",
      "# Don't modify the code below. Please enter\n",
      "# your code at the bottom.\n",
      "\n",
      "from math import *\n",
      "import random\n",
      "\n",
      "\n",
      "\n",
      "landmarks  = [[20.0, 20.0], [80.0, 80.0], [20.0, 80.0], [80.0, 20.0]]\n",
      "world_size = 100.0\n",
      "\n",
      "\n",
      "class robot:\n",
      "    def __init__(self):\n",
      "        self.x = random.random() * world_size\n",
      "        self.y = random.random() * world_size\n",
      "        self.orientation = random.random() * 2.0 * pi\n",
      "        self.forward_noise = 0.0;\n",
      "        self.turn_noise    = 0.0;\n",
      "        self.sense_noise   = 0.0;\n",
      "    \n",
      "    def set(self, new_x, new_y, new_orientation):\n",
      "        if new_x < 0 or new_x >= world_size:\n",
      "            raise ValueError, 'X coordinate out of bound'\n",
      "        if new_y < 0 or new_y >= world_size:\n",
      "            raise ValueError, 'Y coordinate out of bound'\n",
      "        if new_orientation < 0 or new_orientation >= 2 * pi:\n",
      "            raise ValueError, 'Orientation must be in [0..2pi]'\n",
      "        self.x = float(new_x)\n",
      "        self.y = float(new_y)\n",
      "        self.orientation = float(new_orientation)\n",
      "    \n",
      "    \n",
      "    def set_noise(self, new_f_noise, new_t_noise, new_s_noise):\n",
      "        # makes it possible to change the noise parameters\n",
      "        # this is often useful in particle filters\n",
      "        self.forward_noise = float(new_f_noise);\n",
      "        self.turn_noise    = float(new_t_noise);\n",
      "        self.sense_noise   = float(new_s_noise);\n",
      "    \n",
      "    \n",
      "    def sense(self):\n",
      "        Z = []\n",
      "        for i in range(len(landmarks)):\n",
      "            dist = sqrt((self.x - landmarks[i][0]) ** 2 + (self.y - landmarks[i][1]) ** 2)\n",
      "            dist += random.gauss(0.0, self.sense_noise)\n",
      "            Z.append(dist)\n",
      "        return Z\n",
      "    \n",
      "    \n",
      "    def move(self, turn, forward):\n",
      "        if forward < 0:\n",
      "            raise ValueError, 'Robot cant move backwards'         \n",
      "        \n",
      "        # turn, and add randomness to the turning command\n",
      "        orientation = self.orientation + float(turn) + random.gauss(0.0, self.turn_noise)\n",
      "        orientation %= 2 * pi\n",
      "        \n",
      "        # move, and add randomness to the motion command\n",
      "        dist = float(forward) + random.gauss(0.0, self.forward_noise)\n",
      "        x = self.x + (cos(orientation) * dist)\n",
      "        y = self.y + (sin(orientation) * dist)\n",
      "        x %= world_size    # cyclic truncate\n",
      "        y %= world_size\n",
      "        \n",
      "        # set particle\n",
      "        res = robot()\n",
      "        res.set(x, y, orientation)\n",
      "        res.set_noise(self.forward_noise, self.turn_noise, self.sense_noise)\n",
      "        return res\n",
      "    \n",
      "    def Gaussian(self, mu, sigma, x):\n",
      "        \n",
      "        # calculates the probability of x for 1-dim Gaussian with mean mu and var. sigma\n",
      "        return exp(- ((mu - x) ** 2) / (sigma ** 2) / 2.0) / sqrt(2.0 * pi * (sigma ** 2))\n",
      "    \n",
      "    \n",
      "    def measurement_prob(self, measurement):\n",
      "        \n",
      "        # calculates how likely a measurement should be\n",
      "        \n",
      "        prob = 1.0;\n",
      "        for i in range(len(landmarks)):\n",
      "            dist = sqrt((self.x - landmarks[i][0]) ** 2 + (self.y - landmarks[i][1]) ** 2)\n",
      "            prob *= self.Gaussian(dist, self.sense_noise, measurement[i])\n",
      "        return prob\n",
      "    \n",
      "    \n",
      "    \n",
      "    def __repr__(self):\n",
      "        return '[x=%.6s y=%.6s orient=%.6s]' % (str(self.x), str(self.y), str(self.orientation))\n",
      "\n",
      "\n",
      "\n",
      "def eval(r, p):\n",
      "    sum = 0.0;\n",
      "    for i in range(len(p)): # calculate mean error\n",
      "        dx = (p[i].x - r.x + (world_size/2.0)) % world_size - (world_size/2.0)\n",
      "        dy = (p[i].y - r.y + (world_size/2.0)) % world_size - (world_size/2.0)\n",
      "        err = sqrt(dx * dx + dy * dy)\n",
      "        sum += err\n",
      "    return sum / float(len(p))\n",
      "\n",
      "#myrobot = robot()\n",
      "#myrobot.set_noise(5.0, 0.1, 5.0)\n",
      "#myrobot.set(30.0, 50.0, pi/2)\n",
      "#myrobot = myrobot.move(-pi/2, 15.0)\n",
      "#print myrobot.sense()\n",
      "#myrobot = myrobot.move(-pi/2, 10.0)\n",
      "#print myrobot.sense()\n",
      "\n",
      "####   DON'T MODIFY ANYTHING ABOVE HERE! ENTER CODE BELOW ####\n",
      "\n",
      "N = 1000\n",
      "p = []\n",
      "\n",
      "#enter code here\n",
      "\n",
      "\n",
      "print len(p)\n"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "1000\n"
       ]
      }
     ],
     "prompt_number": 3
    },
    {
     "cell_type": "markdown",
     "metadata": {},
     "source": [
      "you may want to modify the code above to print the list (it is long but informative)"
     ]
    },
    {
     "cell_type": "heading",
     "level": 2,
     "metadata": {},
     "source": [
      "Movement"
     ]
    },
    {
     "cell_type": "markdown",
     "metadata": {},
     "source": [
      "This is an extension of the code above -so you need to run that first.\n",
      "\n",
      "Now we are going to move each of the 1,000 particles. Please write code that moves each particle\n",
      "\n",
      "\n",
      "<code>\n",
      "turn by 0.1\n",
      "move by 5 meters\n",
      "</code>\n",
      "\n",
      "So your code should have a new p with the updated particles\n"
     ]
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "# add code\n",
      "\n",
      "\n",
      "print p\n"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "[[x=88.934 y=12.200 orient=3.5681], [x=27.231 y=47.940 orient=3.7085], [x=32.440 y=72.254 orient=3.9054], [x=24.113 y=19.573 orient=3.9218], [x=91.220 y=43.618 orient=0.9153], [x=80.681 y=20.597 orient=3.1470], [x=65.077 y=76.508 orient=5.4220], [x=56.429 y=51.355 orient=0.5074], [x=81.755 y=70.685 orient=3.7057], [x=45.535 y=56.590 orient=2.3235], [x=37.091 y=32.325 orient=3.6132], [x=95.629 y=31.280 orient=0.4212], [x=41.493 y=21.827 orient=4.7092], [x=21.495 y=59.204 orient=3.3444], [x=89.119 y=79.561 orient=0.6095], [x=71.790 y=59.213 orient=0.3542], [x=52.162 y=77.115 orient=2.0952], [x=81.562 y=73.508 orient=5.8170], [x=53.485 y=89.809 orient=0.9232], [x=68.116 y=13.423 orient=4.5546], [x=34.324 y=81.438 orient=4.5081], [x=83.818 y=92.342 orient=4.4719], [x=97.520 y=61.963 orient=0.1649], [x=19.885 y=2.5204 orient=2.2626], [x=83.106 y=63.478 orient=3.2456], [x=80.874 y=88.575 orient=5.8538], [x=44.088 y=64.268 orient=3.8847], [x=17.355 y=67.457 orient=5.9730], [x=44.657 y=71.691 orient=4.8175], [x=2.7791 y=41.452 orient=1.6836], [x=21.759 y=6.1023 orient=5.3518], [x=91.503 y=20.712 orient=1.6039], [x=4.7238 y=65.230 orient=3.0437], [x=13.891 y=28.717 orient=3.0662], [x=64.514 y=52.681 orient=1.6352], [x=63.192 y=67.588 orient=0.7066], [x=39.908 y=59.188 orient=3.3486], [x=9.7187 y=41.177 orient=6.0417], [x=67.592 y=52.526 orient=4.9223], [x=51.584 y=14.474 orient=6.0860], [x=63.585 y=35.774 orient=0.9738], [x=2.9792 y=67.459 orient=5.2796], [x=33.660 y=36.514 orient=4.2381], [x=0.7065 y=10.312 orient=2.1797], [x=96.815 y=14.188 orient=0.1428], [x=57.998 y=68.718 orient=4.5014], [x=16.371 y=40.475 orient=3.6715], [x=97.460 y=76.563 orient=3.7183], [x=14.866 y=68.629 orient=3.1580], [x=89.978 y=76.180 orient=0.7515], [x=73.534 y=76.253 orient=6.2146], [x=65.867 y=37.420 orient=5.0135], [x=34.398 y=94.807 orient=2.9298], [x=81.813 y=94.127 orient=1.6849], [x=63.304 y=16.600 orient=6.0216], [x=5.6759 y=57.063 orient=5.0339], [x=61.972 y=44.194 orient=2.6731], [x=68.923 y=28.658 orient=2.5524], [x=19.685 y=58.646 orient=3.2826], [x=19.326 y=17.086 orient=1.1624], [x=66.880 y=20.966 orient=4.9337], [x=32.042 y=30.911 orient=0.8994], [x=8.3134 y=87.827 orient=0.2503], [x=66.696 y=90.197 orient=3.7549], [x=65.469 y=78.115 orient=4.5242], [x=98.058 y=99.392 orient=3.0866], [x=9.5276 y=73.215 orient=5.8023], [x=19.669 y=74.943 orient=1.6028], [x=7.8110 y=94.610 orient=6.1452], [x=32.312 y=92.749 orient=4.5583], [x=29.230 y=68.563 orient=3.3945], [x=40.694 y=77.919 orient=0.9057], [x=66.693 y=10.805 orient=4.7019], [x=44.374 y=17.417 orient=6.2544], [x=20.031 y=26.310 orient=4.6239], [x=41.789 y=27.111 orient=3.6984], [x=54.839 y=24.635 orient=4.6798], [x=44.914 y=71.713 orient=3.5897], [x=0.1466 y=29.270 orient=3.1285], [x=66.818 y=99.646 orient=2.6087], [x=14.166 y=67.603 orient=2.7987], [x=6.7195 y=16.295 orient=5.2857], [x=2.3980 y=22.991 orient=5.9255], [x=68.397 y=12.016 orient=0.9892], [x=52.770 y=68.426 orient=5.8705], [x=92.439 y=87.729 orient=4.8481], [x=7.0263 y=30.491 orient=2.7973], [x=41.908 y=87.012 orient=2.9989], [x=78.797 y=58.583 orient=1.2275], [x=64.435 y=35.376 orient=3.7570], [x=93.611 y=24.541 orient=1.9276], [x=26.264 y=80.619 orient=2.2685], [x=16.289 y=21.627 orient=1.4692], [x=17.541 y=3.1946 orient=0.2027], [x=39.024 y=94.607 orient=4.9829], [x=61.472 y=37.247 orient=4.2123], [x=95.366 y=97.126 orient=1.5766], [x=67.947 y=47.607 orient=0.1036], [x=75.878 y=10.321 orient=2.3439], [x=81.881 y=91.373 orient=1.2414], [x=0.0257 y=18.628 orient=4.4675], [x=32.331 y=65.240 orient=0.2376], [x=71.849 y=75.714 orient=2.4223], [x=31.341 y=49.640 orient=4.9704], [x=8.0009 y=69.323 orient=6.2552], [x=80.981 y=16.322 orient=3.8003], [x=22.960 y=23.713 orient=3.8609], [x=80.220 y=10.786 orient=5.0323], [x=57.420 y=18.711 orient=2.5482], [x=13.524 y=68.240 orient=1.0203], [x=63.284 y=74.029 orient=1.3018], [x=21.485 y=47.153 orient=5.9377], [x=17.684 y=6.4391 orient=1.7326], [x=96.757 y=40.710 orient=2.6798], [x=5.4973 y=67.045 orient=3.1570], [x=57.103 y=67.641 orient=4.1337], [x=93.159 y=2.6903 orient=2.3285], [x=38.294 y=50.417 orient=6.0212], [x=60.212 y=40.156 orient=3.3032], [x=55.898 y=85.506 orient=1.0501], [x=82.189 y=52.742 orient=4.6701], [x=0.3890 y=70.306 orient=4.0184], [x=70.736 y=41.841 orient=3.8460], [x=36.100 y=97.188 orient=0.6983], [x=57.226 y=44.740 orient=5.4217], [x=16.362 y=70.203 orient=2.5958], [x=61.300 y=42.199 orient=4.0000], [x=14.499 y=66.945 orient=2.1026], [x=9.5521 y=69.883 orient=1.5990], [x=98.970 y=59.582 orient=1.0518], [x=45.136 y=1.6445 orient=1.7038], [x=48.056 y=15.131 orient=1.9837], [x=72.298 y=50.004 orient=4.3716], [x=96.491 y=93.625 orient=0.5592], [x=45.189 y=57.460 orient=0.2605], [x=92.085 y=58.046 orient=3.1138], [x=25.376 y=36.408 orient=3.0394], [x=73.468 y=2.1508 orient=2.8068], [x=92.370 y=38.854 orient=2.2586], [x=59.954 y=94.828 orient=3.0879], [x=66.481 y=57.796 orient=2.2845], [x=57.580 y=44.434 orient=0.9934], [x=15.097 y=44.478 orient=2.1424], [x=55.835 y=93.833 orient=5.0926], [x=89.507 y=17.064 orient=0.5023], [x=52.514 y=25.069 orient=0.3732], [x=45.770 y=70.099 orient=5.6954], [x=27.722 y=10.615 orient=2.8109], [x=79.107 y=29.427 orient=2.7932], [x=76.042 y=86.803 orient=3.8619], [x=98.383 y=16.635 orient=5.8339], [x=89.745 y=50.281 orient=0.4787], [x=83.535 y=44.208 orient=6.2129], [x=13.178 y=20.364 orient=4.0279], [x=44.544 y=79.500 orient=4.4429], [x=40.506 y=99.131 orient=3.1185], [x=74.946 y=74.308 orient=0.7113], [x=22.156 y=52.249 orient=0.8136], [x=62.449 y=0.1265 orient=2.3128], [x=64.033 y=89.569 orient=4.7934], [x=27.786 y=4.0738 orient=1.8552], [x=33.062 y=31.878 orient=4.3413], [x=76.028 y=97.766 orient=1.6482], [x=94.799 y=86.029 orient=4.3250], [x=92.522 y=62.554 orient=2.1925], [x=46.633 y=0.3042 orient=5.3401], [x=70.016 y=87.658 orient=1.0923], [x=86.832 y=58.575 orient=4.5203], [x=9.3534 y=11.659 orient=2.5485], [x=39.029 y=76.737 orient=3.3128], [x=86.313 y=46.909 orient=2.7884], [x=70.529 y=4.7611 orient=5.3693], [x=38.046 y=60.886 orient=4.3147], [x=10.434 y=17.933 orient=6.0881], [x=35.132 y=69.878 orient=4.4202], [x=0.9569 y=41.398 orient=2.7632], [x=7.2728 y=21.487 orient=5.8667], [x=39.836 y=21.522 orient=0.5550], [x=38.287 y=62.231 orient=5.8859], [x=66.594 y=75.239 orient=5.1734], [x=84.872 y=99.959 orient=2.3986], [x=91.623 y=88.258 orient=0.7710], [x=0.0702 y=68.570 orient=5.2379], [x=38.895 y=93.305 orient=1.9200], [x=71.297 y=76.319 orient=6.2809], [x=12.665 y=55.777 orient=2.8963], [x=81.998 y=38.732 orient=1.5809], [x=19.438 y=43.659 orient=3.0631], [x=17.257 y=28.243 orient=0.0174], [x=41.159 y=0.7236 orient=4.9043], [x=53.479 y=97.857 orient=2.8406], [x=34.689 y=43.708 orient=4.3995], [x=82.845 y=79.839 orient=5.3464], [x=44.122 y=56.041 orient=0.4787], [x=17.849 y=13.146 orient=4.7179], [x=14.659 y=74.911 orient=2.4956], [x=9.0550 y=16.800 orient=0.5519], [x=77.209 y=22.093 orient=0.6535], [x=7.0702 y=19.907 orient=5.3078], [x=54.372 y=78.858 orient=5.0828], [x=45.972 y=92.371 orient=2.1989], [x=5.3963 y=84.989 orient=3.8964], [x=44.559 y=68.016 orient=1.9081], [x=10.993 y=48.606 orient=3.7299], [x=59.146 y=82.913 orient=2.7499], [x=36.762 y=46.747 orient=0.5849], [x=22.879 y=58.103 orient=5.8208], [x=62.300 y=61.102 orient=0.1974], [x=96.897 y=20.279 orient=2.7938], [x=93.280 y=56.397 orient=0.8875], [x=41.698 y=15.584 orient=1.6107], [x=72.149 y=48.923 orient=0.7794], [x=80.303 y=56.773 orient=4.3470], [x=68.057 y=5.8144 orient=6.1854], [x=63.592 y=30.361 orient=5.1091], [x=86.982 y=35.350 orient=2.6483], [x=54.660 y=40.443 orient=2.7010], [x=79.077 y=0.3629 orient=3.9515], [x=39.260 y=51.188 orient=0.2581], [x=42.705 y=59.317 orient=2.6505], [x=98.370 y=65.625 orient=3.1724], [x=82.960 y=31.449 orient=4.4986], [x=37.287 y=17.111 orient=6.1175], [x=33.098 y=19.995 orient=3.9492], [x=75.511 y=38.675 orient=0.1632], [x=60.311 y=34.541 orient=3.6199], [x=85.920 y=7.0618 orient=3.8229], [x=65.131 y=14.359 orient=0.9360], [x=83.741 y=36.542 orient=1.7973], [x=51.274 y=98.518 orient=0.0839], [x=19.863 y=34.336 orient=0.6534], [x=61.350 y=85.979 orient=2.3257], [x=63.265 y=16.899 orient=5.8648], [x=55.115 y=77.661 orient=5.1366], [x=92.683 y=70.133 orient=3.8932], [x=81.913 y=98.823 orient=0.5938], [x=82.744 y=19.867 orient=3.7932], [x=18.542 y=70.590 orient=3.1617], [x=35.456 y=8.6621 orient=4.8200], [x=51.522 y=32.234 orient=3.7280], [x=92.050 y=95.195 orient=3.6794], [x=25.533 y=73.295 orient=6.1340], [x=97.075 y=48.684 orient=5.1075], [x=3.2003 y=31.871 orient=0.3437], [x=52.224 y=36.779 orient=3.4897], [x=75.868 y=92.997 orient=3.8563], [x=32.406 y=95.776 orient=0.1262], [x=47.872 y=93.369 orient=5.8256], [x=69.594 y=29.195 orient=1.1310], [x=76.786 y=53.336 orient=3.4888], [x=82.798 y=6.6354 orient=2.7138], [x=37.897 y=42.691 orient=4.7821], [x=15.608 y=62.062 orient=0.0712], [x=13.051 y=16.714 orient=0.9253], [x=29.349 y=20.403 orient=4.5025], [x=43.595 y=75.691 orient=3.5758], [x=39.680 y=8.6813 orient=0.0832], [x=13.328 y=0.5135 orient=0.4616], [x=23.633 y=57.159 orient=0.8362], [x=22.028 y=89.382 orient=4.3966], [x=41.166 y=97.507 orient=5.0942], [x=52.204 y=42.473 orient=2.8237], [x=1.0982 y=33.774 orient=5.5737], [x=8.7303 y=25.548 orient=5.3462], [x=24.775 y=81.477 orient=0.8248], [x=70.024 y=73.606 orient=6.0935], [x=74.661 y=99.686 orient=2.0340], [x=28.414 y=44.568 orient=2.9976], [x=19.504 y=44.475 orient=5.4047], [x=4.2275 y=62.794 orient=1.2412], [x=67.377 y=23.540 orient=3.8384], [x=59.231 y=36.046 orient=5.4072], [x=89.602 y=36.443 orient=4.9294], [x=8.8640 y=85.465 orient=4.0905], [x=62.826 y=76.008 orient=2.5441], [x=66.227 y=27.361 orient=3.2670], [x=7.7212 y=78.739 orient=0.5083], [x=0.8968 y=69.862 orient=1.9898], [x=67.602 y=94.197 orient=2.1885], [x=74.940 y=62.437 orient=1.6490], [x=8.0690 y=38.003 orient=3.1854], [x=11.761 y=36.630 orient=0.6660], [x=78.416 y=84.915 orient=5.1992], [x=78.270 y=7.7166 orient=1.6015], [x=69.058 y=82.438 orient=3.8489], [x=33.431 y=54.409 orient=0.7205], [x=11.320 y=37.440 orient=2.9767], [x=94.042 y=64.758 orient=1.5640], [x=17.923 y=4.9804 orient=6.1178], [x=32.330 y=49.409 orient=5.2756], [x=47.079 y=89.419 orient=5.5280], [x=89.271 y=61.020 orient=2.0548], [x=86.273 y=66.599 orient=2.4138], [x=65.465 y=75.934 orient=5.4326], [x=25.305 y=51.093 orient=3.3051], [x=25.135 y=95.784 orient=6.2232], [x=1.5685 y=0.3058 orient=2.9084], [x=84.644 y=48.379 orient=5.7824], [x=82.473 y=99.664 orient=4.4411], [x=56.969 y=4.7740 orient=3.6548], [x=72.570 y=34.136 orient=2.2246], [x=2.1517 y=65.794 orient=0.0115], [x=5.6599 y=46.480 orient=2.4530], [x=20.254 y=81.008 orient=3.7051], [x=36.437 y=37.890 orient=1.3692], [x=89.629 y=33.868 orient=5.0556], [x=70.505 y=37.857 orient=3.9665], [x=61.621 y=58.701 orient=6.1728], [x=34.727 y=64.632 orient=0.5322], [x=92.007 y=24.837 orient=1.6158], [x=81.618 y=47.423 orient=4.2493], [x=21.353 y=25.649 orient=0.3585], [x=43.984 y=0.5929 orient=5.2404], [x=17.958 y=45.517 orient=3.4666], [x=21.185 y=42.088 orient=3.7293], [x=31.690 y=93.200 orient=0.4268], [x=12.189 y=65.481 orient=4.1608], [x=48.348 y=97.458 orient=3.4693], [x=30.741 y=7.5680 orient=0.1157], [x=43.098 y=34.109 orient=5.5573], [x=93.142 y=66.354 orient=1.8537], [x=56.843 y=51.202 orient=2.2892], [x=50.784 y=45.525 orient=1.4173], [x=23.281 y=2.2332 orient=3.4307], [x=81.148 y=4.7708 orient=1.5613], [x=42.523 y=23.805 orient=3.9235], [x=95.849 y=6.6270 orient=3.4870], [x=12.922 y=32.538 orient=4.6111], [x=71.585 y=26.056 orient=4.7321], [x=99.419 y=92.859 orient=1.4504], [x=6.3257 y=46.364 orient=0.8055], [x=84.601 y=62.391 orient=5.7923], [x=90.549 y=28.947 orient=5.7128], [x=77.452 y=22.193 orient=2.0391], [x=38.511 y=12.874 orient=3.8803], [x=22.828 y=35.074 orient=1.8710], [x=74.429 y=90.094 orient=1.2055], [x=0.7633 y=36.609 orient=4.4679], [x=35.171 y=18.748 orient=2.2603], [x=81.660 y=53.484 orient=5.6600], [x=24.773 y=89.916 orient=0.8322], [x=83.933 y=88.356 orient=1.6989], [x=69.611 y=53.515 orient=2.3059], [x=41.160 y=90.634 orient=0.0816], [x=61.867 y=16.750 orient=2.2506], [x=94.228 y=57.115 orient=3.7496], [x=96.531 y=80.196 orient=0.9627], [x=52.168 y=97.741 orient=4.6173], [x=46.404 y=62.291 orient=2.9858], [x=89.123 y=74.900 orient=6.1319], [x=20.453 y=90.205 orient=5.8309], [x=17.143 y=99.853 orient=3.6994], [x=51.335 y=92.407 orient=2.1422], [x=99.534 y=61.722 orient=2.9630], [x=55.412 y=6.9261 orient=3.7525], [x=62.880 y=42.684 orient=1.9728], [x=61.395 y=39.023 orient=5.1392], [x=15.144 y=17.519 orient=2.1424], [x=91.513 y=12.377 orient=2.5900], [x=8.1896 y=62.726 orient=1.6652], [x=98.905 y=74.221 orient=6.0110], [x=81.837 y=95.440 orient=2.2661], [x=1.5024 y=19.608 orient=0.7763], [x=73.413 y=54.378 orient=2.0961], [x=55.139 y=32.523 orient=1.5805], [x=59.286 y=11.289 orient=4.9278], [x=96.298 y=34.947 orient=3.0705], [x=95.091 y=26.546 orient=3.6411], [x=4.6285 y=46.854 orient=3.5619], [x=9.5435 y=60.079 orient=1.3483], [x=26.581 y=61.302 orient=5.0036], [x=64.306 y=31.631 orient=5.0262], [x=74.334 y=18.557 orient=4.6031], [x=92.867 y=96.805 orient=2.0030], [x=41.155 y=35.334 orient=5.6086], [x=80.230 y=67.237 orient=1.3640], [x=28.659 y=57.931 orient=3.0730], [x=83.605 y=64.398 orient=1.9325], [x=7.8323 y=62.759 orient=1.0607], [x=18.661 y=22.415 orient=4.0540], [x=80.999 y=72.042 orient=0.3387], [x=74.186 y=3.3386 orient=3.3996], [x=88.581 y=18.921 orient=2.4560], [x=86.928 y=18.096 orient=4.3480], [x=61.745 y=84.476 orient=5.3833], [x=71.094 y=19.043 orient=4.7347], [x=96.903 y=76.069 orient=5.3554], [x=94.270 y=74.238 orient=5.3896], [x=56.695 y=63.507 orient=3.9604], [x=35.064 y=46.849 orient=6.1399], [x=18.187 y=64.012 orient=4.0744], [x=21.947 y=12.818 orient=1.1998], [x=70.745 y=81.880 orient=1.0505], [x=49.071 y=41.150 orient=1.9203], [x=54.971 y=98.779 orient=5.1416], [x=64.131 y=63.083 orient=0.0989], [x=17.421 y=9.4388 orient=2.0747], [x=9.8002 y=98.031 orient=0.6916], [x=75.688 y=53.648 orient=5.4486], [x=21.747 y=58.123 orient=3.2949], [x=49.494 y=8.7646 orient=2.1043], [x=40.877 y=64.519 orient=5.0889], [x=51.058 y=54.587 orient=2.7720], [x=25.348 y=27.405 orient=2.0851], [x=4.7471 y=51.784 orient=4.6003], [x=15.343 y=94.622 orient=4.0995], [x=75.877 y=71.194 orient=5.1654], [x=41.710 y=68.164 orient=0.7778], [x=79.274 y=32.555 orient=4.9962], [x=76.777 y=87.502 orient=5.7426], [x=32.571 y=3.6568 orient=3.3917], [x=45.680 y=69.909 orient=3.8240], [x=82.426 y=72.729 orient=0.1533], [x=29.430 y=27.430 orient=3.8988], [x=42.257 y=22.961 orient=1.7077], [x=4.2102 y=30.342 orient=5.5076], [x=52.487 y=32.989 orient=2.3841], [x=16.644 y=9.1757 orient=0.4890], [x=11.203 y=91.463 orient=2.3653], [x=34.700 y=76.439 orient=0.9014], [x=39.150 y=2.0368 orient=5.7112], [x=32.711 y=17.970 orient=4.3712], [x=12.484 y=29.931 orient=4.5320], [x=90.916 y=89.329 orient=1.6137], [x=45.549 y=51.502 orient=4.4418], [x=79.563 y=11.653 orient=2.4996], [x=62.441 y=40.634 orient=1.7910], [x=26.998 y=3.0494 orient=2.1376], [x=2.7833 y=72.502 orient=1.7893], [x=38.791 y=22.751 orient=2.9997], [x=44.000 y=83.980 orient=4.9675], [x=61.926 y=60.609 orient=4.0740], [x=21.027 y=16.198 orient=0.8832], [x=69.173 y=63.966 orient=6.0517], [x=7.4589 y=69.737 orient=0.1221], [x=35.249 y=13.161 orient=1.4272], [x=32.245 y=80.860 orient=4.9196], [x=72.391 y=23.731 orient=2.2012], [x=73.629 y=51.208 orient=4.8589], [x=28.371 y=50.595 orient=3.7102], [x=31.591 y=74.671 orient=1.5353], [x=79.200 y=41.233 orient=4.4715], [x=87.795 y=86.137 orient=0.3272], [x=8.3165 y=44.359 orient=0.5310], [x=52.872 y=8.2828 orient=0.7740], [x=94.041 y=88.935 orient=5.5403], [x=63.533 y=76.185 orient=1.0733], [x=93.003 y=79.796 orient=3.0200], [x=40.671 y=99.389 orient=2.4965], [x=10.706 y=11.994 orient=0.7995], [x=26.238 y=22.078 orient=0.4151], [x=39.312 y=94.271 orient=3.6113], [x=3.0949 y=22.230 orient=3.1219], [x=21.922 y=46.799 orient=5.2203], [x=21.367 y=12.660 orient=2.7461], [x=94.237 y=93.313 orient=0.0601], [x=62.690 y=10.421 orient=4.6444], [x=25.045 y=72.923 orient=4.0574], [x=11.823 y=88.496 orient=0.4362], [x=0.6473 y=82.391 orient=0.0542], [x=32.792 y=59.291 orient=3.7341], [x=74.701 y=91.783 orient=1.3220], [x=11.448 y=19.661 orient=3.6560], [x=22.936 y=30.731 orient=5.9994], [x=93.419 y=88.780 orient=5.7583], [x=56.663 y=74.591 orient=3.0589], [x=7.0422 y=3.8545 orient=3.0617], [x=71.860 y=78.035 orient=0.6789], [x=43.698 y=83.513 orient=4.5832], [x=63.667 y=0.0580 orient=2.9407], [x=78.190 y=82.738 orient=3.5424], [x=86.112 y=0.3756 orient=0.6478], [x=15.677 y=17.888 orient=5.6001], [x=52.576 y=54.752 orient=0.4414], [x=0.3474 y=33.449 orient=4.4045], [x=87.232 y=93.320 orient=0.2983], [x=12.945 y=77.788 orient=3.6261], [x=24.154 y=36.302 orient=1.0051], [x=36.021 y=91.931 orient=0.9677], [x=32.395 y=73.086 orient=3.2115], [x=87.967 y=86.100 orient=3.3669], [x=12.601 y=14.368 orient=1.2032], [x=18.822 y=44.439 orient=3.5248], [x=36.329 y=57.674 orient=0.6927], [x=85.531 y=14.082 orient=5.8205], [x=5.1702 y=4.0781 orient=2.7506], [x=1.3096 y=1.4753 orient=0.6602], [x=10.591 y=1.1361 orient=2.6616], [x=55.184 y=83.734 orient=2.4304], [x=73.558 y=78.592 orient=3.3757], [x=77.370 y=48.744 orient=3.4686], [x=0.3863 y=99.305 orient=1.9008], [x=63.404 y=83.602 orient=2.5108], [x=74.410 y=83.634 orient=6.1295], [x=44.964 y=22.798 orient=4.8638], [x=77.216 y=97.438 orient=5.0284], [x=35.597 y=8.7549 orient=5.7472], [x=86.116 y=50.363 orient=3.3518], [x=38.821 y=43.377 orient=4.8737], [x=64.259 y=56.736 orient=1.6331], [x=58.528 y=86.465 orient=1.5816], [x=23.714 y=43.046 orient=1.5504], [x=88.140 y=36.670 orient=3.1773], [x=93.110 y=46.245 orient=4.9495], [x=17.001 y=39.319 orient=1.1757], [x=41.303 y=58.137 orient=3.2622], [x=59.414 y=56.631 orient=0.4024], [x=74.887 y=88.642 orient=3.0245], [x=10.242 y=69.735 orient=2.0133], [x=95.134 y=68.086 orient=4.7048], [x=27.970 y=35.664 orient=2.9571], [x=41.167 y=1.2247 orient=0.0700], [x=95.940 y=89.557 orient=0.2664], [x=39.993 y=45.141 orient=4.9833], [x=74.383 y=76.999 orient=2.3051], [x=47.459 y=31.048 orient=1.0460], [x=99.123 y=54.134 orient=5.5512], [x=3.9058 y=72.823 orient=4.3787], [x=62.163 y=55.014 orient=2.1907], [x=50.352 y=52.123 orient=0.5867], [x=21.419 y=36.570 orient=4.0577], [x=84.233 y=24.975 orient=5.7594], [x=37.800 y=17.172 orient=0.2338], [x=68.660 y=45.247 orient=4.2283], [x=61.962 y=4.0672 orient=3.8368], [x=24.928 y=25.069 orient=1.2088], [x=66.207 y=43.027 orient=4.4436], [x=74.139 y=49.182 orient=2.9388], [x=73.798 y=94.891 orient=5.2083], [x=77.463 y=91.937 orient=1.2714], [x=94.474 y=4.8757 orient=5.9954], [x=99.994 y=7.9270 orient=3.7562], [x=5.0659 y=59.193 orient=4.3351], [x=96.700 y=92.503 orient=0.3994], [x=27.713 y=8.8121 orient=0.6357], [x=12.850 y=23.860 orient=5.3451], [x=19.511 y=2.8402 orient=1.7679], [x=21.785 y=88.423 orient=5.6629], [x=62.363 y=97.140 orient=4.2104], [x=18.504 y=15.414 orient=3.1933], [x=31.095 y=32.035 orient=5.8000], [x=85.151 y=16.414 orient=4.6956], [x=71.522 y=84.705 orient=3.5263], [x=46.427 y=30.590 orient=0.9084], [x=62.956 y=62.467 orient=5.6177], [x=60.889 y=25.631 orient=4.1014], [x=40.639 y=82.185 orient=1.3351], [x=10.223 y=55.730 orient=6.0149], [x=62.302 y=74.792 orient=1.7469], [x=88.213 y=2.6819 orient=4.0636], [x=66.408 y=22.326 orient=2.2611], [x=20.637 y=40.579 orient=2.6961], [x=26.349 y=71.695 orient=3.9679], [x=23.651 y=6.0923 orient=4.8775], [x=80.682 y=46.678 orient=3.5850], [x=61.431 y=67.593 orient=4.9125], [x=96.519 y=4.0577 orient=2.1574], [x=33.139 y=3.5272 orient=2.9113], [x=65.010 y=98.820 orient=2.3095], [x=57.801 y=86.153 orient=6.2763], [x=41.254 y=40.304 orient=4.6270], [x=30.946 y=5.1819 orient=5.6872], [x=91.283 y=99.855 orient=5.1883], [x=79.699 y=89.861 orient=2.9837], [x=63.666 y=22.598 orient=0.1075], [x=6.1018 y=66.489 orient=0.5003], [x=89.883 y=42.189 orient=5.5331], [x=84.256 y=53.153 orient=0.6216], [x=53.764 y=61.871 orient=4.6003], [x=18.445 y=14.022 orient=5.5497], [x=50.738 y=84.976 orient=4.6964], [x=21.862 y=19.253 orient=3.4313], [x=26.703 y=77.092 orient=3.0880], [x=5.0879 y=34.503 orient=5.0889], [x=20.328 y=35.936 orient=0.9703], [x=1.5669 y=69.374 orient=4.3526], [x=18.251 y=5.8904 orient=3.1143], [x=58.255 y=22.730 orient=4.2916], [x=48.736 y=29.075 orient=3.1005], [x=60.503 y=38.150 orient=5.6844], [x=37.537 y=96.112 orient=2.7249], [x=38.384 y=7.2620 orient=2.0044], [x=65.150 y=58.321 orient=4.5042], [x=67.375 y=67.490 orient=2.9232], [x=10.609 y=87.409 orient=3.9090], [x=1.0258 y=18.916 orient=0.1658], [x=99.501 y=80.177 orient=2.6420], [x=20.630 y=58.661 orient=4.7985], [x=66.805 y=74.047 orient=6.1709], [x=30.924 y=83.991 orient=6.2582], [x=39.574 y=35.347 orient=1.8252], [x=16.455 y=27.412 orient=3.8374], [x=8.2168 y=14.911 orient=0.4776], [x=70.564 y=46.582 orient=4.9720], [x=42.484 y=41.022 orient=0.8852], [x=44.395 y=20.709 orient=3.8536], [x=84.700 y=26.505 orient=1.8414], [x=59.939 y=92.492 orient=0.6125], [x=35.430 y=78.282 orient=2.7403], [x=22.887 y=12.717 orient=1.7620], [x=79.057 y=11.060 orient=4.7603], [x=28.776 y=1.6021 orient=6.2273], [x=14.618 y=72.410 orient=5.1269], [x=78.999 y=19.755 orient=4.3703], [x=63.415 y=64.750 orient=5.8737], [x=75.696 y=46.012 orient=3.5073], [x=95.057 y=64.490 orient=0.6340], [x=62.537 y=74.154 orient=0.7009], [x=85.569 y=88.438 orient=2.2333], [x=3.7725 y=66.487 orient=1.7316], [x=25.889 y=5.0613 orient=2.0159], [x=92.174 y=17.846 orient=3.0007], [x=32.328 y=0.1365 orient=0.3916], [x=23.517 y=94.085 orient=1.7872], [x=72.441 y=92.711 orient=4.1015], [x=92.525 y=43.660 orient=0.2939], [x=48.059 y=50.745 orient=3.4786], [x=34.949 y=16.310 orient=2.5808], [x=85.433 y=55.950 orient=6.0413], [x=46.162 y=46.684 orient=0.9984], [x=28.835 y=1.9873 orient=0.9514], [x=2.7365 y=89.853 orient=3.7626], [x=26.968 y=36.701 orient=3.3586], [x=65.216 y=51.801 orient=4.5938], [x=26.888 y=27.436 orient=0.2000], [x=7.8939 y=63.449 orient=4.5939], [x=77.344 y=94.682 orient=2.5515], [x=13.740 y=87.738 orient=3.3426], [x=35.479 y=56.185 orient=5.6077], [x=8.1284 y=40.814 orient=3.3028], [x=32.731 y=5.7763 orient=1.8794], [x=70.820 y=95.560 orient=4.6857], [x=80.502 y=74.256 orient=5.5134], [x=75.260 y=30.926 orient=6.2564], [x=92.047 y=51.646 orient=4.9239], [x=36.505 y=84.106 orient=1.8132], [x=22.441 y=96.509 orient=4.4397], [x=13.222 y=97.924 orient=4.7193], [x=6.0529 y=7.7414 orient=4.0236], [x=65.242 y=78.316 orient=3.6707], [x=83.023 y=12.711 orient=2.8072], [x=92.178 y=75.812 orient=5.9137], [x=9.5037 y=26.375 orient=1.0569], [x=31.338 y=86.626 orient=5.5325], [x=88.717 y=38.059 orient=2.9127], [x=62.443 y=39.601 orient=6.0763], [x=77.592 y=69.038 orient=2.9582], [x=57.951 y=31.576 orient=2.2266], [x=16.186 y=45.333 orient=0.5357], [x=29.703 y=50.806 orient=4.5689], [x=81.650 y=15.021 orient=5.2651], [x=84.561 y=20.315 orient=1.6521], [x=3.2390 y=46.154 orient=1.2929], [x=30.924 y=60.687 orient=3.4625], [x=97.167 y=77.088 orient=0.7151], [x=43.902 y=64.808 orient=3.4888], [x=62.857 y=0.9524 orient=1.6668], [x=24.100 y=8.8350 orient=4.7172], [x=64.511 y=49.517 orient=3.3446], [x=18.082 y=8.4909 orient=0.8795], [x=14.383 y=28.913 orient=0.3334], [x=98.437 y=48.257 orient=0.0069], [x=89.554 y=47.543 orient=4.8317], [x=19.676 y=56.550 orient=4.2534], [x=14.756 y=27.934 orient=0.9344], [x=42.555 y=80.100 orient=2.8663], [x=56.807 y=73.425 orient=2.1006], [x=13.201 y=92.993 orient=2.8065], [x=36.160 y=68.746 orient=4.4273], [x=68.214 y=4.8911 orient=4.0001], [x=34.779 y=50.904 orient=1.0192], [x=94.054 y=51.507 orient=4.1506], [x=23.408 y=19.471 orient=4.4448], [x=91.324 y=4.2194 orient=5.2655], [x=25.531 y=72.294 orient=2.3912], [x=20.164 y=78.832 orient=3.9518], [x=26.344 y=98.515 orient=4.6824], [x=16.277 y=96.440 orient=4.6522], [x=36.497 y=68.220 orient=3.2689], [x=21.504 y=20.903 orient=1.8832], [x=2.0619 y=69.855 orient=0.9190], [x=80.937 y=73.383 orient=4.2636], [x=55.341 y=50.419 orient=2.0032], [x=48.842 y=64.011 orient=5.4816], [x=40.698 y=65.239 orient=4.7275], [x=16.003 y=44.523 orient=5.2485], [x=61.139 y=76.141 orient=2.2559], [x=75.760 y=3.1502 orient=5.4483], [x=35.615 y=70.003 orient=2.4635], [x=62.288 y=42.659 orient=2.4766], [x=48.929 y=91.396 orient=3.6673], [x=39.316 y=58.011 orient=2.2591], [x=27.593 y=85.530 orient=1.4886], [x=98.685 y=48.916 orient=1.1968], [x=9.1455 y=55.756 orient=0.1612], [x=93.995 y=48.786 orient=3.8537], [x=78.753 y=72.012 orient=2.8420], [x=44.149 y=95.123 orient=6.1023], [x=31.810 y=88.867 orient=4.6892], [x=90.541 y=40.325 orient=0.7988], [x=49.055 y=2.8640 orient=4.5125], [x=9.5461 y=38.559 orient=2.2465], [x=36.666 y=21.385 orient=4.6528], [x=3.3922 y=23.748 orient=5.7778], [x=52.798 y=71.569 orient=5.9913], [x=84.589 y=38.125 orient=2.1824], [x=39.150 y=10.788 orient=4.1365], [x=85.958 y=3.9779 orient=0.7865], [x=51.271 y=62.009 orient=5.1577], [x=22.372 y=12.622 orient=1.2423], [x=78.615 y=67.948 orient=4.9434], [x=2.3239 y=63.620 orient=4.5832], [x=47.443 y=71.032 orient=1.2488], [x=51.911 y=4.5545 orient=4.4811], [x=69.197 y=24.971 orient=5.3949], [x=11.469 y=81.473 orient=1.6208], [x=30.200 y=79.256 orient=4.0186], [x=31.683 y=16.309 orient=0.4891], [x=17.257 y=66.709 orient=5.2446], [x=85.884 y=36.632 orient=2.5471], [x=6.8844 y=6.6236 orient=0.4153], [x=95.741 y=74.733 orient=3.6259], [x=13.231 y=11.731 orient=1.5808], [x=61.516 y=51.581 orient=3.9895], [x=75.169 y=30.409 orient=1.3708], [x=32.334 y=68.797 orient=0.5143], [x=14.701 y=77.921 orient=1.8815], [x=61.079 y=82.336 orient=5.4085], [x=78.501 y=59.992 orient=0.7441], [x=90.295 y=20.665 orient=2.2203], [x=84.602 y=60.445 orient=6.2344], [x=89.074 y=5.0356 orient=2.4768], [x=12.753 y=11.010 orient=5.4963], [x=2.9025 y=44.708 orient=6.1371], [x=34.298 y=86.515 orient=0.5949], [x=18.722 y=74.719 orient=1.9008], [x=78.851 y=98.042 orient=2.1195], [x=51.171 y=29.953 orient=3.0396], [x=66.209 y=35.579 orient=0.9614], [x=16.796 y=12.184 orient=4.7029], [x=47.310 y=68.876 orient=5.1580], [x=75.538 y=79.952 orient=4.2732], [x=87.775 y=45.968 orient=4.8094], [x=18.611 y=0.0759 orient=5.8255], [x=27.580 y=83.356 orient=4.6710], [x=46.258 y=21.649 orient=3.8478], [x=95.779 y=98.574 orient=5.9184], [x=65.050 y=35.378 orient=3.9356], [x=7.3326 y=40.424 orient=0.2975], [x=72.715 y=11.367 orient=2.2685], [x=28.922 y=12.683 orient=2.6958], [x=12.643 y=54.055 orient=1.8052], [x=11.292 y=49.357 orient=3.3479], [x=57.761 y=60.487 orient=2.9471], [x=72.809 y=46.704 orient=0.1319], [x=84.940 y=53.769 orient=2.8329], [x=26.332 y=37.114 orient=4.7698], [x=94.133 y=53.030 orient=3.3629], [x=55.127 y=21.247 orient=4.1877], [x=9.4391 y=97.901 orient=4.6665], [x=42.387 y=34.814 orient=2.9102], [x=99.357 y=32.285 orient=1.3443], [x=26.921 y=22.417 orient=1.4021], [x=5.8070 y=52.179 orient=4.3862], [x=80.065 y=43.742 orient=2.5246], [x=14.377 y=71.330 orient=2.8697], [x=47.692 y=61.205 orient=3.6760], [x=76.485 y=26.456 orient=0.7281], [x=95.431 y=46.361 orient=3.0863], [x=85.666 y=40.537 orient=1.9582], [x=20.180 y=21.777 orient=1.2104], [x=37.339 y=76.764 orient=3.5639], [x=17.761 y=50.704 orient=5.0844], [x=90.155 y=58.608 orient=3.8370], [x=18.707 y=49.834 orient=1.4232], [x=23.678 y=22.846 orient=1.2867], [x=34.439 y=82.610 orient=1.8877], [x=17.066 y=82.504 orient=3.5403], [x=14.010 y=93.067 orient=3.0473], [x=1.4222 y=41.291 orient=4.1362], [x=54.661 y=98.780 orient=2.2219], [x=72.466 y=72.960 orient=4.0473], [x=0.2059 y=21.678 orient=5.3503], [x=90.599 y=9.8108 orient=4.1739], [x=83.332 y=75.368 orient=5.6627], [x=66.932 y=14.147 orient=4.1431], [x=81.713 y=98.091 orient=5.9146], [x=42.076 y=94.208 orient=2.7601], [x=70.172 y=57.547 orient=3.3370], [x=58.264 y=11.373 orient=5.7565], [x=96.873 y=31.403 orient=2.3884], [x=57.351 y=55.853 orient=2.8705], [x=50.292 y=98.224 orient=4.2850], [x=47.373 y=91.299 orient=3.7151], [x=27.979 y=68.580 orient=2.6663], [x=5.5172 y=53.013 orient=6.0649], [x=70.176 y=77.781 orient=3.7580], [x=67.844 y=22.359 orient=5.6277], [x=88.130 y=0.2830 orient=2.0947], [x=13.530 y=89.104 orient=3.2152], [x=61.085 y=3.2326 orient=6.0534], [x=52.456 y=40.279 orient=4.3889], [x=10.630 y=22.956 orient=2.6899], [x=59.727 y=25.141 orient=0.2613], [x=40.141 y=80.427 orient=5.1051], [x=52.166 y=22.740 orient=4.8962], [x=13.633 y=49.827 orient=4.4857], [x=87.702 y=32.968 orient=0.1292], [x=74.610 y=69.642 orient=3.3031], [x=66.235 y=57.957 orient=5.2534], [x=77.959 y=11.344 orient=0.7783], [x=0.5220 y=15.237 orient=1.3714], [x=71.168 y=78.641 orient=3.6030], [x=90.098 y=64.013 orient=3.5914], [x=59.053 y=24.623 orient=1.9161], [x=50.319 y=53.204 orient=4.6244], [x=46.011 y=70.303 orient=2.9214], [x=76.729 y=0.9807 orient=4.6305], [x=70.943 y=78.670 orient=1.1628], [x=95.546 y=53.857 orient=2.3088], [x=47.269 y=91.081 orient=2.6540], [x=18.269 y=4.0170 orient=5.0414], [x=30.425 y=66.095 orient=0.5299], [x=31.897 y=81.146 orient=0.8361], [x=43.794 y=26.165 orient=1.8675], [x=11.698 y=42.527 orient=3.8015], [x=16.451 y=48.668 orient=1.4887], [x=64.851 y=36.565 orient=5.9326], [x=21.027 y=0.5203 orient=2.0385], [x=62.050 y=69.930 orient=1.6637], [x=66.629 y=19.996 orient=4.0120], [x=2.4077 y=45.572 orient=5.7537], [x=74.865 y=27.492 orient=0.0046], [x=86.373 y=50.703 orient=0.0035], [x=79.555 y=15.628 orient=2.8928], [x=97.480 y=60.711 orient=4.8769], [x=47.087 y=95.075 orient=5.6245], [x=19.320 y=21.272 orient=4.1811], [x=51.069 y=45.138 orient=0.0199], [x=54.252 y=84.289 orient=1.3396], [x=20.793 y=95.751 orient=1.5643], [x=73.854 y=91.877 orient=2.4492], [x=47.532 y=57.543 orient=5.0470], [x=69.179 y=4.1872 orient=0.4828], [x=9.7691 y=66.441 orient=1.4128], [x=18.851 y=8.7368 orient=4.2521], [x=58.410 y=76.300 orient=1.6328], [x=24.393 y=61.683 orient=3.9847], [x=44.945 y=66.805 orient=2.9462], [x=33.194 y=91.556 orient=2.8944], [x=66.256 y=34.190 orient=2.1125], [x=87.053 y=5.1750 orient=1.3280], [x=50.671 y=4.3651 orient=4.0296], [x=87.106 y=41.735 orient=3.2298], [x=27.465 y=74.164 orient=6.1821], [x=49.050 y=71.251 orient=4.4830], [x=4.8577 y=46.951 orient=3.5481], [x=73.889 y=94.124 orient=4.7914], [x=89.060 y=91.968 orient=0.7683], [x=87.704 y=72.339 orient=5.1713], [x=69.110 y=99.414 orient=4.4982], [x=19.890 y=92.873 orient=6.0773], [x=77.944 y=97.998 orient=4.6074], [x=38.997 y=13.685 orient=3.9192], [x=32.451 y=50.756 orient=2.9148], [x=10.124 y=33.714 orient=0.5857], [x=99.363 y=22.872 orient=5.4491], [x=13.836 y=88.921 orient=1.6811], [x=20.326 y=35.700 orient=5.0518], [x=64.596 y=14.787 orient=0.1878], [x=53.281 y=10.928 orient=4.0001], [x=13.564 y=9.6562 orient=3.4740], [x=1.6007 y=50.040 orient=1.7803], [x=36.461 y=20.232 orient=3.4669], [x=28.050 y=3.8637 orient=2.9874], [x=21.623 y=78.933 orient=4.9878], [x=50.647 y=58.558 orient=5.2317], [x=53.860 y=19.796 orient=0.9206], [x=20.599 y=85.809 orient=0.3627], [x=7.3022 y=11.194 orient=0.8819], [x=18.799 y=73.313 orient=1.2969], [x=39.337 y=96.256 orient=4.8025], [x=8.5451 y=98.135 orient=6.2381], [x=18.808 y=96.556 orient=3.0583], [x=4.4088 y=59.603 orient=5.4043], [x=54.969 y=27.159 orient=2.7814], [x=33.001 y=40.610 orient=3.8093], [x=59.275 y=6.5198 orient=5.0867], [x=58.120 y=44.212 orient=2.7289], [x=58.100 y=39.597 orient=3.3540], [x=6.5124 y=9.7067 orient=2.5558], [x=88.019 y=95.334 orient=3.6104], [x=37.103 y=4.5302 orient=2.0351], [x=83.077 y=52.233 orient=4.5265], [x=37.253 y=92.032 orient=2.9194], [x=90.775 y=94.471 orient=5.1861], [x=76.042 y=23.525 orient=1.6428], [x=63.269 y=83.475 orient=1.5296], [x=94.590 y=13.351 orient=1.0198], [x=83.826 y=31.828 orient=0.1362], [x=15.310 y=14.923 orient=3.6966], [x=95.044 y=10.127 orient=3.7791], [x=85.043 y=79.378 orient=3.5123], [x=24.188 y=94.958 orient=6.1947], [x=85.385 y=51.983 orient=5.5063], [x=60.955 y=15.637 orient=4.6928], [x=99.466 y=35.554 orient=1.7056], [x=13.800 y=28.263 orient=0.0977], [x=36.881 y=71.367 orient=0.9839], [x=39.029 y=1.5981 orient=4.2845], [x=20.065 y=10.480 orient=4.5087], [x=43.094 y=18.719 orient=3.3316], [x=67.402 y=94.099 orient=1.9545], [x=64.062 y=55.540 orient=6.0765], [x=78.806 y=29.101 orient=5.0212], [x=28.359 y=36.122 orient=5.5522], [x=25.562 y=38.023 orient=5.1052], [x=90.942 y=37.809 orient=1.3938], [x=3.0045 y=43.784 orient=0.4390], [x=50.110 y=82.680 orient=3.0375], [x=69.750 y=6.0884 orient=1.7095], [x=57.068 y=52.894 orient=2.6768], [x=1.6569 y=98.335 orient=1.3576], [x=59.071 y=39.286 orient=5.8921], [x=4.5246 y=79.576 orient=4.9422], [x=21.170 y=65.225 orient=3.9121], [x=35.262 y=71.976 orient=5.5082], [x=22.495 y=15.133 orient=0.2799], [x=2.6791 y=11.515 orient=6.0593], [x=23.632 y=14.379 orient=2.4386], [x=74.229 y=93.136 orient=2.2810], [x=51.078 y=39.936 orient=5.0076], [x=12.410 y=93.225 orient=2.1697], [x=79.198 y=22.301 orient=2.0099], [x=7.7791 y=86.787 orient=3.2724], [x=26.631 y=42.575 orient=2.7179], [x=71.173 y=97.018 orient=0.0615], [x=64.090 y=53.554 orient=0.5379], [x=38.064 y=95.226 orient=4.9132], [x=89.862 y=6.9200 orient=6.0671], [x=33.200 y=61.597 orient=5.6447], [x=8.9489 y=83.166 orient=3.8673], [x=43.090 y=56.788 orient=1.2133], [x=63.007 y=56.058 orient=0.1813], [x=59.866 y=51.110 orient=3.3383], [x=96.500 y=56.427 orient=3.3734], [x=10.346 y=79.518 orient=1.3085], [x=55.505 y=70.875 orient=2.2124], [x=77.089 y=85.361 orient=3.7266], [x=26.592 y=70.472 orient=3.2589], [x=49.167 y=7.3832 orient=6.1507], [x=58.539 y=12.052 orient=3.6287], [x=94.678 y=87.465 orient=0.9259], [x=97.140 y=56.398 orient=4.4664], [x=9.3074 y=61.397 orient=5.9913], [x=96.826 y=34.844 orient=0.4787], [x=79.675 y=5.2770 orient=4.0228], [x=60.692 y=64.450 orient=2.6947], [x=19.368 y=99.931 orient=2.8076], [x=70.184 y=82.803 orient=5.6048], [x=51.194 y=75.681 orient=2.5253], [x=87.182 y=50.436 orient=3.7636], [x=81.439 y=35.476 orient=4.5398], [x=71.840 y=4.7096 orient=3.9734], [x=29.748 y=99.737 orient=1.6619], [x=54.213 y=39.497 orient=1.1600], [x=91.782 y=55.442 orient=6.1956], [x=12.695 y=43.092 orient=3.8786], [x=95.163 y=50.071 orient=2.8943], [x=47.410 y=45.700 orient=1.6367], [x=20.617 y=82.907 orient=1.2224], [x=82.552 y=98.154 orient=0.8582], [x=51.581 y=38.481 orient=2.7523], [x=20.162 y=40.018 orient=4.9853], [x=47.225 y=37.074 orient=1.5504], [x=72.768 y=26.165 orient=4.6468], [x=83.799 y=99.380 orient=1.1103], [x=45.682 y=93.657 orient=3.7467], [x=74.043 y=22.037 orient=1.5887], [x=39.722 y=69.201 orient=0.5850], [x=3.9569 y=56.054 orient=5.2274], [x=1.3003 y=85.613 orient=4.1595], [x=24.240 y=58.403 orient=0.5214], [x=10.881 y=16.407 orient=1.5003], [x=56.155 y=78.722 orient=0.0548], [x=45.800 y=48.528 orient=3.7123], [x=75.020 y=66.171 orient=1.8746], [x=4.2054 y=94.345 orient=1.3811], [x=77.117 y=21.268 orient=5.4637], [x=68.379 y=99.469 orient=2.6542], [x=11.845 y=4.1528 orient=6.1618], [x=59.854 y=44.777 orient=2.1479], [x=57.629 y=60.429 orient=5.7631], [x=92.679 y=60.190 orient=3.4804], [x=56.550 y=10.897 orient=5.6111], [x=29.777 y=29.453 orient=4.3707], [x=9.0817 y=71.581 orient=5.7929], [x=34.362 y=67.807 orient=3.3031], [x=74.271 y=6.5773 orient=1.2083], [x=35.143 y=55.478 orient=0.8878]]\n"
       ]
      }
     ],
     "prompt_number": 5
    },
    {
     "cell_type": "heading",
     "level": 2,
     "metadata": {},
     "source": [
      "Halftime!"
     ]
    },
    {
     "cell_type": "markdown",
     "metadata": {},
     "source": [
      "Congratulations, you have written 1/2 of the particle filter. However, it was the EASY half!"
     ]
    },
    {
     "cell_type": "heading",
     "level": 3,
     "metadata": {},
     "source": [
      "Noisy sensing"
     ]
    },
    {
     "cell_type": "markdown",
     "metadata": {},
     "source": [
      "Sensing is inexact. We get a measurement distance to a particle beacon, but it may be off by a bit. It is a gaussian distribution of noise.\n",
      "\n",
      "Let's say we have two particles, one close to the correct robot position and one far away. We get a sensor reading for the 4 beacons. Now we can use\n",
      "probability. How likely is that measurement given that the particle is close to the correct robot position?\n",
      "\n",
      "We are going to compute an importance weight for each particle based on the mismatch between the expected sensor measurement and the actual measurement.\n",
      "\n",
      "Here is what we need to do. First, we need to create a list, p, of 1000 particles but this time we will set the turn and forward noise to be 0.5 and the sense noise to be 5.\n",
      "\n",
      "Next, notice that we have a function, measurement_prob. You need to create a vector, w, of the importance weights of each particle using this method."
     ]
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "myrobot = robot()\n",
      "myrobot = myrobot.move(0.1, 5.0)\n",
      "Z = myrobot.sense()\n",
      "\n",
      "\n",
      "N = 1000\n",
      "p = []\n",
      "\n",
      "# insert code here\n",
      "\n",
      "\n",
      "print w #Please print w \n"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "[1.7177169498944006e-18, 4.7422166696244735e-80, 4.6003893797131844e-40, 5.203497132742118e-85, 3.3031456992343966e-30, 9.916112030771273e-40, 8.324299950494198e-11, 1.5467089912595204e-13, 8.34422680829091e-28, 1.3283406727188598e-44, 6.603819720650222e-08, 6.359743615858707e-97, 6.62179962100224e-79, 1.4036436854019879e-83, 3.012029265176305e-59, 2.198677830633381e-96, 4.9540405404166105e-28, 3.0966406840798824e-42, 1.7174954805146597e-05, 3.28788607099345e-45, 6.326516865334802e-40, 1.3945817336443625e-79, 2.7920740738195713e-72, 7.287220515911524e-103, 6.935830415531848e-66, 7.287945672614764e-46, 3.763975635052279e-32, 4.079857858818498e-37, 1.3979482503422412e-33, 2.228115064966055e-87, 2.2979147563149397e-49, 2.8490003839128384e-95, 6.993382709428871e-106, 4.955014302957644e-31, 4.2403121367775204e-32, 1.5400001561294559e-06, 1.4877789952247884e-09, 2.9697678385363375e-98, 2.0788170789838947e-21, 2.2548795266823809e-72, 9.672738353450672e-15, 8.093211442493331e-21, 1.2898342594936193e-17, 2.9932066479455806e-60, 2.1320034358444636e-17, 3.555851214215241e-15, 3.005059177379245e-18, 7.764428646446848e-70, 3.907429474579392e-80, 1.2603006592542113e-12, 2.3274648617656693e-11, 2.3938669411230552e-51, 7.016812625669811e-16, 2.4864090802541045e-41, 1.1316141443151407e-59, 5.95272235350211e-47, 2.0526993364664566e-20, 3.880648973343879e-22, 7.70219606664962e-86, 5.40179659313656e-88, 4.6948955406146683e-11, 4.975834601637471e-80, 1.9084638304111376e-56, 2.7500244626904005e-94, 6.498378491187748e-68, 2.0921168824154013e-37, 2.5925286554609283e-13, 1.2176419732889745e-96, 3.4348813840001793e-06, 3.1016585419965876e-76, 3.94387208833616e-95, 6.022862881438745e-58, 9.688418201270319e-64, 4.009021441935406e-46, 9.88947299546826e-06, 7.604457530774062e-11, 8.101450347616765e-11, 6.926100470538022e-20, 6.975489465337367e-07, 4.318165601007551e-09, 6.971629259814507e-53, 1.3906525829994396e-19, 1.27330784629415e-11, 2.3824522259631182e-26, 6.95806998775472e-33, 5.401679374180894e-08, 4.063359613178708e-79, 1.0723383308563698e-54, 5.156244907111905e-96, 5.193654549650054e-23, 1.0379510643416196e-42, 1.1251918211421407e-40, 2.3034926029164246e-67, 2.117273101313399e-05, 6.758982688824859e-84, 6.457757287358375e-61, 6.494861944796057e-34, 1.8540990695892356e-36, 2.1768128601340878e-64, 3.506035950111568e-16, 9.365489559768105e-15, 8.644681688941203e-19, 4.913601379314301e-96, 1.0128350545150432e-17, 4.861682717836798e-70, 2.1965246225457813e-07, 1.4342659317726943e-12, 1.9856400827495602e-20, 9.449875554482179e-07, 1.491571993546887e-78, 1.767270437573159e-18, 1.4963662957251533e-34, 1.3944942693559953e-81, 3.7192053592331657e-34, 1.475231811989921e-12, 7.605911163273237e-13, 8.095755712962891e-55, 6.169562731765785e-35, 1.5216381507381608e-13, 2.158627554479966e-29, 1.5764885883448442e-32, 7.864459049684385e-46, 7.740771216357824e-104, 4.406048325149765e-40, 2.55653834492224e-66, 9.495733743568598e-06, 8.846101317480158e-77, 5.213091581608402e-91, 2.3669040375497792e-32, 3.2140050323284494e-64, 4.605796305863936e-77, 1.6838531968966503e-11, 6.256574745281976e-52, 1.630247394162665e-60, 1.726062872962326e-46, 1.3176446902839766e-44, 9.114606526488993e-94, 3.235037542503966e-14, 9.081996788974485e-48, 1.3197005894636897e-12, 1.0223765829434486e-16, 2.012362841802444e-89, 6.089929901310012e-28, 1.2976226990757072e-41, 6.645767471870685e-18, 8.537611367148579e-16, 5.1945704938504824e-61, 3.907438593605904e-58, 3.196787365280188e-22, 1.4348522857442693e-34, 2.145091790986884e-22, 3.463916663602512e-72, 1.5917423333132192e-85, 8.187765211581265e-14, 4.32403421168603e-98, 2.820231424366686e-44, 1.5509437838321448e-66, 9.809523273313686e-49, 8.140112630134284e-17, 1.5181977494090687e-35, 5.560979727348608e-56, 1.1446676362791504e-77, 8.546330988671191e-08, 1.2038052223703441e-56, 7.8332268709471e-109, 3.278263416990682e-58, 1.3560181102340129e-05, 4.524475712242662e-85, 1.4925458529148835e-72, 1.664323061282409e-56, 1.3855031040942335e-20, 1.0075258132827353e-80, 8.358835904312542e-12, 1.1328528251187589e-49, 1.6818229472807463e-80, 1.9905610131375202e-18, 1.7802919811896644e-38, 3.0613523287107816e-17, 7.7604904628614095e-87, 1.1810771886016487e-16, 1.140245520360828e-46, 6.267979869071077e-83, 3.3242505407826973e-07, 2.6871392754400503e-41, 4.003260089369826e-50, 1.0525482363943842e-72, 6.908771887553429e-38, 2.0135107541400255e-19, 4.832434548140909e-56, 1.6508962135310354e-53, 2.94123275805381e-32, 8.021914880466797e-78, 6.654933180094526e-56, 1.537239860750377e-06, 2.8264385696531227e-24, 4.699820762964684e-34, 9.767708634497591e-24, 2.0607855240702307e-38, 1.554038308580096e-70, 2.383858688100484e-09, 6.585023916569128e-84, 1.3357748792495316e-45, 1.660398998354617e-08, 2.9467620665189636e-42, 3.0191235323032555e-10, 1.5777676202956554e-94, 4.7344421647229015e-77, 1.0246666907210042e-46, 7.772332592597833e-07, 5.676569553543243e-07, 4.194820916536108e-06, 7.304723639489859e-48, 3.8885293962342186e-76, 7.445127688700343e-22, 2.1585998538036703e-08, 6.345318281463527e-86, 1.5194655679659892e-32, 2.368750276518686e-27, 8.518025164903913e-43, 5.384757092159236e-92, 7.787276843626824e-54, 1.666283216449794e-23, 1.2065230097863125e-30, 1.1576883990043424e-98, 8.632567051534014e-43, 1.1022978978669153e-17, 3.746961878572236e-89, 4.602683864052317e-11, 4.120948528234123e-13, 1.2650712773737218e-09, 3.1741090061571785e-07, 2.1668446727126487e-63, 4.023571201206519e-16, 5.897822908751174e-13, 3.219908356965926e-15, 5.417621893926842e-91, 1.3634357447289949e-46, 3.1427086850387675e-61, 4.140714142299088e-95, 2.8691686541488254e-06, 4.3526422217519835e-07, 3.868074820837041e-88, 4.4585106445188267e-11, 1.5976095180740793e-07, 1.4165040158936553e-73, 2.7480319234515806e-11, 5.445792860387344e-12, 2.9930350959148762e-43, 1.7383126433342646e-37, 1.3990493969774282e-11, 3.437440985589428e-10, 2.302871289439455e-53, 1.0650025521610312e-14, 5.1661682337818505e-08, 1.1936356538854185e-72, 1.842499070203351e-61, 2.476327634504616e-94, 3.549855508982168e-16, 1.4733590663785566e-74, 1.4143297502752285e-18, 1.1214390479298042e-76, 1.5158747676189145e-20, 5.38841260047186e-89, 2.986123619655554e-08, 1.6422604701223558e-59, 1.3783568226454142e-89, 3.784627187926879e-36, 3.83533503198667e-06, 1.5256429269855626e-27, 4.0269027417284714e-33, 2.4300195122807574e-66, 1.2811071268251455e-21, 2.390048525117965e-09, 2.7837215250099344e-41, 5.782223672372145e-85, 4.3140143262306786e-26, 5.6586193385429186e-46, 2.9954489081149168e-12, 9.430059434587414e-20, 7.515007603002506e-67, 7.933384492849646e-38, 5.825973079575739e-83, 1.1097917653745295e-11, 5.495480886702688e-13, 6.267170912013531e-07, 2.9817271994761978e-62, 2.4816581412647477e-24, 5.02056450618669e-08, 3.9233856645611155e-81, 4.4724197670240954e-79, 5.210742180915012e-64, 6.183481315083284e-41, 2.6345290029608005e-21, 6.131006274107374e-11, 2.257517392421895e-55, 2.0111973707380788e-25, 2.1527181685781283e-82, 1.435406078799276e-51, 5.326588940068232e-49, 2.479981734410206e-33, 1.4865057814536e-80, 2.772372386311887e-22, 1.1737581368280122e-99, 1.5858228132470157e-31, 1.7839208230055549e-59, 6.952661101128488e-26, 5.0897035833166024e-33, 1.2513642661553569e-45, 1.3398716879945134e-30, 6.093731833213843e-07, 8.374351004849205e-101, 6.448762921056209e-21, 4.4747452992167495e-40, 1.919177050235853e-40, 6.467663585295645e-49, 1.3418220559048781e-21, 6.2475299243752956e-58, 4.524035739661004e-80, 7.059691559712677e-78, 6.196463381739617e-85, 7.687276438184418e-11, 1.0030619114906062e-35, 1.697425439166594e-65, 3.96486841519612e-39, 8.641674942587038e-69, 1.871003319098591e-69, 4.117260887667438e-14, 1.7436559365287296e-30, 4.557068317973352e-34, 1.7685645452440464e-68, 9.804117554787592e-30, 1.0729129176472585e-90, 5.108810452992612e-06, 5.588244130725833e-77, 1.693236051306434e-65, 5.1569236248881924e-14, 2.7426922272894682e-45, 8.41243860997639e-32, 1.7736597430343055e-20, 7.26512663067886e-48, 3.7908693169613463e-66, 4.291293372018632e-21, 5.085307431125693e-43, 8.424563772740102e-06, 6.353043205143045e-62, 2.2508325557898024e-87, 3.408826841476752e-08, 5.4833453226866356e-61, 4.243917108369117e-62, 2.20211534169032e-24, 1.6108066611290336e-33, 2.158821757023513e-11, 3.33501497448222e-28, 1.1635820898722937e-45, 1.5210203971606002e-16, 1.5011553609968126e-45, 3.497676842875926e-21, 1.3628826255320035e-13, 2.8328239614402396e-65, 2.6023129533585847e-65, 5.912336253440151e-07, 5.570239856325986e-86, 1.8704653447104807e-37, 7.922985852082949e-64, 1.956532268296076e-13, 1.1580326777991913e-28, 3.308300263532188e-15, 3.332338839494863e-51, 2.6019394077609326e-24, 4.355326485315248e-24, 1.7624287421756085e-34, 1.2215314186255099e-11, 1.9647759859897097e-30, 1.4260483474301551e-105, 3.1589906850420757e-53, 1.4569050845208464e-86, 7.527684854811059e-07, 1.109573817120158e-93, 4.16371690467711e-68, 2.743981486455783e-65, 1.6197288565308677e-80, 3.3025530596696415e-11, 1.5067374705507898e-20, 1.0529665339334027e-23, 1.6646420257981986e-36, 1.8980946591429287e-14, 1.0359555459706035e-40, 1.5211809581201596e-17, 8.162791025396558e-42, 9.622109387816524e-84, 3.002615421504436e-14, 2.264164651826953e-78, 4.703815869265492e-15, 9.85764636305224e-67, 3.3654098381815844e-05, 3.4317206312985834e-19, 2.717582333399289e-80, 1.086569611595371e-09, 1.3601986450763333e-83, 1.92551542268709e-87, 8.327671146678303e-80, 5.8294379574540975e-90, 5.595107247867374e-82, 9.836309418195546e-37, 2.682241670006889e-17, 3.732318438455668e-24, 2.9328516157437282e-67, 4.817222404786229e-25, 5.061923524383025e-80, 2.8761797951499934e-92, 3.994340462118069e-56, 2.9610867259062085e-37, 6.902171730044346e-33, 5.1683310654511865e-15, 3.370536300507507e-89, 1.4858563652130765e-07, 4.0483492101030216e-72, 8.793103838585731e-92, 5.135839380357433e-29, 1.7868711887913935e-88, 2.512030437120059e-32, 1.2699882624999773e-59, 7.764378718386022e-50, 5.966925440991888e-50, 1.1216793012109244e-89, 1.819665240471796e-42, 7.719132398412671e-84, 1.952142563341658e-18, 1.4171722237871764e-85, 6.241005858775121e-47, 2.3799199972935775e-81, 4.860410284489149e-27, 6.810620187542313e-52, 4.307772044936074e-19, 1.8254395154509874e-09, 9.244241156996601e-30, 6.261164636063024e-23, 1.1419160564169852e-45, 3.1352061345591622e-24, 3.1169874623360223e-07, 4.210256666563156e-83, 2.6971854241750052e-18, 1.1619894792552404e-49, 4.0462724748572184e-80, 2.9819853404432506e-07, 2.8776499061112988e-21, 5.2506665686713e-46, 1.7208603327110888e-43, 4.684219978363638e-25, 2.017448083908753e-11, 2.3409419315707593e-57, 4.6671496423785285e-78, 8.615913585833303e-49, 2.573493537524573e-47, 6.480759379743518e-15, 3.0163859618548694e-79, 1.5112309521507796e-28, 1.254881052321962e-58, 6.485614410552212e-58, 7.08005046256537e-14, 3.917264204257795e-33, 9.164813785637383e-38, 6.37574413325567e-89, 3.513844566218359e-15, 6.589706671947565e-91, 7.654432109447831e-99, 6.135665043305916e-88, 1.4405860563581879e-71, 4.144089621779088e-55, 4.168096099023404e-27, 4.990210805850427e-51, 1.2347290408731898e-14, 3.4308161260197066e-86, 3.877155795975066e-07, 2.8960769148856327e-44, 5.885018743114455e-22, 5.369882942008058e-66, 2.0141080466917944e-54, 1.6871760923262057e-25, 2.1032517215058662e-79, 4.781246794895998e-94, 1.2783980954598559e-23, 2.0629087045846798e-21, 1.501585499986526e-51, 3.711986893179447e-71, 1.9907013647333847e-05, 1.181453005459456e-20, 9.537476089274515e-84, 3.814075946807385e-35, 3.958906336183639e-58, 3.256937515377723e-73, 1.0257059323785269e-07, 2.299626438763908e-43, 6.748981784624804e-24, 3.323090400909196e-82, 2.530738008569605e-27, 6.370935346916001e-51, 1.2976687491161202e-29, 1.5494784691018214e-27, 4.04213924591064e-33, 1.2572790976020146e-58, 3.1290490105103955e-06, 3.7789902587665165e-52, 1.0806118232721967e-15, 9.97216205470175e-20, 8.948046771811702e-17, 1.1465396927660799e-42, 1.063230317429444e-12, 1.9430391796782737e-94, 4.2345847641459805e-10, 8.117096017546695e-45, 2.6713530722231925e-43, 2.122574543958548e-59, 1.0269718241309074e-40, 4.281360453585078e-26, 2.6921396737836914e-13, 3.374882581849943e-50, 2.5846463245371645e-77, 5.590729798426516e-78, 5.471465302914505e-29, 3.6723414982968847e-07, 4.519201972673626e-55, 4.63789840315043e-24, 5.759596896950347e-34, 4.410129752140768e-67, 1.1413872472143811e-81, 1.0279382625977578e-41, 1.520760363196604e-75, 9.935821124804706e-90, 4.1095485316620315e-21, 1.7638749396893296e-72, 2.3202196282495447e-06, 2.1905419851613813e-51, 1.2584761404262493e-31, 1.6600142278064405e-76, 8.116021930424007e-72, 8.794548791564096e-15, 2.4418911169723178e-17, 2.87086778083957e-42, 1.0720483358864051e-106, 9.380658545470307e-44, 2.422673324747803e-07, 1.496787552622936e-73, 8.311271254171026e-41, 7.491972734159272e-52, 5.523917808743238e-66, 1.4651833803422325e-23, 2.4059337218129305e-59, 5.3094288747931684e-76, 7.7991422326306464e-31, 1.1270832388092503e-41, 5.0541155813269515e-43, 5.102873691888274e-72, 4.5751472002908664e-91, 7.371469082265457e-15, 1.1040924399028639e-74, 2.3349074497167013e-40, 1.6778073535859096e-25, 1.458167786844107e-35, 5.898332741977714e-58, 4.2544632495034665e-45, 5.900380363736873e-08, 3.353206972460061e-13, 5.412242765919071e-20, 1.7770952540747157e-16, 1.1165171394024488e-42, 3.704523100138559e-08, 5.602316793238522e-58, 8.415491737361616e-25, 2.5734939103557678e-08, 2.2748569221812236e-16, 3.637584027746417e-70, 2.4046269209515733e-33, 1.0000650599182626e-17, 1.329777123484023e-88, 1.718646928149355e-63, 4.2217196482238826e-106, 3.782774556731907e-110, 1.6599772614534394e-08, 8.4938141050354215e-78, 1.1227968658889348e-22, 5.0956192060211754e-58, 2.1361343511630513e-10, 1.350315383512734e-13, 3.4375111644117374e-05, 1.0501945317736525e-39, 4.477122256663897e-34, 2.6025411688541806e-31, 1.1056749019966426e-33, 7.720362443984635e-44, 1.426897688310164e-76, 1.0514945487702275e-31, 2.090399862478252e-82, 1.0811568580207615e-23, 3.075298327443167e-26, 1.8194503893758926e-83, 1.1791941146706902e-92, 5.992635314304287e-56, 1.8186820428072486e-42, 2.220538622271277e-37, 1.0549998751310693e-53, 1.7945479325461503e-18, 1.325850914448161e-27, 6.608937864799918e-18, 3.0075941456946607e-42, 4.090038248933667e-25, 1.9678207426001944e-22, 1.115906279762429e-83, 1.3635670032332802e-07, 2.055016127844028e-38, 4.153165948094994e-23, 3.3352050466209582e-43, 6.512988126733061e-92, 7.243938139224854e-91, 2.6853555674884973e-05, 1.5564338313612413e-11, 8.472496079764532e-33, 4.105382156359265e-94, 6.617199973388138e-13, 9.883217099865218e-87, 1.2181785866524265e-82, 6.673332553880836e-22, 7.298752538679423e-65, 6.057825768235835e-36, 1.0237029558002067e-33, 7.652713689925761e-19, 1.076491514017496e-14, 2.1051137856624674e-95, 3.639161995113493e-46, 5.089400135426924e-14, 4.8018414616895425e-15, 1.2831595243237771e-12, 1.8644844928344151e-29, 1.3349391956428126e-76, 3.223099816508772e-32, 2.7755617694512886e-23, 1.6212003922622449e-53, 1.0444024767272882e-19, 1.1464675233788965e-25, 4.851807530223611e-58, 1.1318658008410228e-79, 9.638855726660064e-75, 3.0558719535581573e-21, 2.464108042173872e-41, 9.72747281800386e-17, 2.2156543659872753e-47, 5.749503756148976e-43, 6.194228056601971e-66, 5.83758540116929e-51, 2.63884962796214e-85, 1.4264927328299384e-78, 1.8295142795676105e-58, 1.4093044117387898e-26, 2.8098513969988064e-96, 4.3563501892807826e-09, 9.206788351969597e-13, 1.647178136574212e-46, 6.175350637357247e-31, 3.595330466474318e-19, 3.6242323895266195e-12, 7.207838248538568e-08, 6.642843191776859e-12, 2.8063563840440748e-42, 1.2662318424726224e-62, 6.89279872949807e-74, 6.543163784049459e-19, 1.0016164375675337e-13, 1.6887919056923175e-23, 1.1904435315215355e-38, 1.5670519308435144e-45, 1.189133455628817e-10, 3.873805208415061e-48, 2.972330108171083e-11, 1.4808840130416573e-54, 1.4254811631749422e-62, 3.111055281349879e-87, 2.9407982999467795e-07, 3.2730035023788876e-33, 5.120382306679985e-57, 1.3955452599611867e-67, 3.081544638535834e-57, 1.1178774214290633e-85, 2.2647476045895168e-17, 9.106892201609067e-52, 1.8253799220944054e-52, 9.269745851752337e-60, 2.4760411558738494e-12, 7.312385317220914e-08, 1.402745386364847e-07, 1.9075133103569317e-95, 4.175781541759341e-41, 3.051945117285081e-77, 3.1871828098608023e-68, 5.553600908653126e-16, 2.252154876330669e-12, 3.105060181522783e-63, 3.475076725006499e-32, 3.104876904227813e-09, 4.341511526021011e-91, 1.3883844637601032e-15, 2.1794846966694314e-12, 2.0350774410006997e-46, 9.633898568151486e-91, 1.1612535942064734e-96, 2.759827743163004e-40, 9.294006952281799e-49, 2.628060269766294e-31, 5.000340259043235e-80, 1.9434342122470033e-49, 3.525670830307013e-09, 4.019343370846449e-76, 3.0825416146019886e-76, 1.4161970774689084e-57, 3.5909814962721795e-08, 2.198036309550365e-24, 1.2511696920193826e-06, 1.1538853578138322e-42, 1.717524776165434e-44, 8.749740360233063e-33, 2.470946028820956e-14, 1.261862444689899e-14, 1.5354380773427034e-94, 4.011702925896934e-22, 1.5927725070005832e-13, 8.6879957997534e-24, 1.1673293582967024e-27, 2.699510132142886e-27, 2.1779012927678312e-14, 3.565025818509935e-09, 1.3526648294528909e-77, 1.790744196057287e-50, 1.3893536627336974e-17, 8.034992484908774e-15, 1.1058053483348858e-72, 9.814072227528185e-52, 4.725949105344703e-59, 4.677398661220042e-51, 3.907458327365914e-09, 1.7418752868160126e-25, 8.01534959328164e-89, 1.73178180608906e-81, 6.446941274637315e-85, 3.6032458310148794e-10, 8.425999259596096e-33, 2.214976307212369e-86, 3.094978073779258e-45, 6.982787748392328e-33, 8.572851276146222e-19, 3.115125323640634e-08, 3.4485374093316445e-67, 6.483021904391027e-08, 4.760053165893027e-67, 1.2368998722980199e-33, 3.517119586204826e-39, 1.2211224478094415e-30, 5.3922859641354764e-20, 7.759678480722335e-10, 3.855396344686572e-15, 3.888848510360168e-19, 2.573393338938242e-53, 2.3387324056176703e-26, 9.32194487192174e-24, 9.016355711050996e-46, 4.681279226499841e-64, 4.6753271647041334e-70, 2.48559744523123e-40, 2.032664853343451e-23, 2.2825039872477685e-42, 6.374111815455301e-19, 8.91773222857918e-19, 7.5266584184610645e-90, 1.2607822140633376e-07, 2.08585728277396e-77, 8.184234864584521e-15, 1.4947266834844875e-09, 4.788480241729656e-93, 5.208114373967105e-68, 8.064933291985986e-19, 4.590070627972942e-16, 2.486436018740689e-09, 3.438809896897926e-20, 4.371067161509342e-53, 6.87247096330904e-80, 1.0052769136364941e-39, 1.3453792875241292e-88, 1.703238166629533e-86, 4.010820169488497e-36, 4.073350429593567e-19, 7.242457698490414e-20, 2.65321690277914e-15, 7.867737146411253e-07, 1.2604286985761058e-94, 7.281614579061741e-18, 6.374971669399503e-26, 2.4588525020437786e-30, 4.1469194695186455e-38, 9.805347902433228e-35, 1.0822889897840918e-34, 6.194042555475392e-33, 4.208372709287363e-90, 9.891541567354912e-84, 3.568416173764192e-74, 8.451108364312226e-09, 7.573616899061247e-47, 3.3413481328275655e-67, 1.5061967013045093e-10, 1.388199551770023e-15, 1.9971416538496016e-87, 5.74583449833826e-78, 1.6760764918401002e-77, 1.0488283521554316e-07, 6.1898003979772175e-18, 5.4220916615899315e-30, 3.3418767175700336e-75, 2.834057515552077e-34, 4.240870705246134e-22, 1.6292162051327745e-31, 1.641610585649719e-06, 1.3960573247272256e-62, 4.035088455506323e-11, 3.9331421323263404e-54, 2.87558718645814e-78, 2.1807333732204984e-08, 4.888603197997867e-10, 7.570353253643122e-70, 9.48342552466804e-09, 1.9222938480864633e-06, 2.6439627743818262e-12, 9.797306312940167e-37, 8.416107808765962e-19, 1.0687737970754395e-88, 3.1656151792755684e-79, 9.95672678995446e-66, 3.894924838007384e-15, 2.508528200209702e-72, 3.6990172838147017e-25, 1.57712671546903e-44, 3.9347936396756714e-64, 4.6266279111731956e-42, 9.181144774456303e-75, 6.784829016847827e-08, 3.665827599713599e-33, 1.8717855156527683e-23, 1.3558526638092112e-06, 1.4878288915955267e-17, 1.0821551739673131e-37, 2.3542711953186026e-10, 2.5353932388781025e-16, 3.4990393854018094e-58, 7.729614084777965e-58, 1.0146229620958412e-19, 8.931978194310805e-30, 1.280308347778454e-61, 4.96354714852926e-75, 9.873028604941236e-15, 3.570358124754792e-18, 7.424364445764261e-72, 5.793493556375488e-07, 1.274230084580146e-57, 4.44222327740353e-19, 1.9874252154508325e-17, 1.5579568244040145e-78, 2.9339819014030126e-85, 2.179536362988252e-15, 5.316518697304038e-16, 6.917474800782152e-22, 1.263090120860293e-65, 1.7639558616570552e-14, 1.9985853091458448e-82, 1.131185327130208e-11, 4.682718923360602e-70, 5.9123050288251294e-67, 1.3973933538535563e-75, 9.010898602484624e-17, 1.2095566014040962e-48, 3.1666701310974023e-37, 2.419913318405823e-38, 4.387887146759055e-37, 1.7902350725621234e-50, 5.1478593193893715e-47, 1.3691170028982549e-44, 1.1265248673108794e-70, 9.92106690611495e-75, 2.141148404866524e-42, 5.58678162024383e-26, 3.161413856061745e-05, 2.7874081349504605e-48, 7.733440614558865e-16, 5.937604017111346e-71, 9.258923039784283e-80, 8.400156850322383e-22, 5.7296814030110684e-46, 1.1395380093284899e-73, 3.7120676212124644e-72, 1.1223782827222234e-111, 4.002777955319166e-09, 4.836452062966205e-59, 2.9862232303192898e-47, 1.3798758494229287e-11, 5.010978815746286e-52, 1.276632698481909e-34, 1.0513680993830304e-06, 3.523318788812977e-59, 5.365767242331936e-18, 1.5095077657020363e-82, 1.5970933037052297e-73, 3.743255531251364e-05, 1.8509661130270025e-40, 4.428871300806531e-74, 1.6918199723754323e-11, 7.808546336709003e-82, 3.8400128096774475e-78, 4.905563149288618e-63, 3.1904481185977078e-09, 6.395260636806311e-27, 1.342949263957424e-64, 9.402160805622754e-24, 2.643506872523633e-15, 2.3237950745951255e-95, 9.130190157893743e-84, 3.9248475638545966e-79, 1.1623939438845006e-23, 9.536152490245908e-80, 4.048801489934093e-90, 2.339344643867502e-48, 2.4470676920939494e-40, 1.453454638999972e-29, 1.5313090682189303e-45, 6.871810811513126e-29, 5.6394894594454755e-15, 1.1079657888031035e-58, 7.163423205764144e-42, 3.0329118086442098e-37, 4.941170029724773e-78, 9.35201153093e-36, 1.6053355612088923e-07, 1.0381749690861798e-46, 1.2476557410230997e-41, 1.5763845605871505e-50, 8.300581711732864e-28, 5.713230533395574e-36, 3.431871896866016e-72, 3.0515351131860137e-06, 1.5409219832691784e-27, 2.745710143229267e-55, 7.838750329008484e-46, 5.824147084863082e-77, 2.3698503318409376e-58, 1.0376814581243451e-05, 1.6420495278591351e-69, 4.621427768860064e-07, 1.4329558901097253e-14, 7.364963103048795e-42, 2.3683207136174253e-38, 8.134918715408822e-41, 1.2565232876045784e-45, 1.4303018225268718e-40, 5.130350476703986e-37, 6.047801441564291e-39, 4.940179881136128e-20, 3.0959388044870284e-05, 1.2985559308095277e-44, 2.087912971207617e-12, 4.8755829204651256e-26, 1.1495333288188512e-20, 3.7285547446115273e-81, 1.0399000421498084e-38, 9.764501342878665e-25, 5.224469435969378e-92, 9.976153988208395e-29, 3.6651668580024736e-40, 1.4721057563552097e-28, 1.1508583634943522e-35, 4.968823023072083e-40, 6.465372829387298e-29, 1.0676986344765199e-10, 4.987378310196184e-16, 9.627314706204372e-28, 3.357534630962578e-28, 1.2082234134988763e-109, 1.0910743783246288e-39, 7.078735815050162e-24, 3.4965474495355515e-77, 4.7821755879039184e-14, 1.599742202150891e-16, 5.628671035783392e-81, 2.381931166249e-06, 2.1382866281857947e-80, 2.027313142839098e-17, 2.8249047115951365e-46, 7.0874696276369124e-09, 1.2492186238018803e-07, 7.175081366576071e-38, 3.483859663842693e-96, 7.642894644161301e-67, 1.470933122110101e-17, 2.062949216288083e-43, 1.5882616560930894e-51, 4.778161031332015e-09, 3.491252929327005e-14]\n"
       ]
      }
     ],
     "prompt_number": 8
    },
    {
     "cell_type": "heading",
     "level": 2,
     "metadata": {},
     "source": [
      "Resampling"
     ]
    },
    {
     "cell_type": "markdown",
     "metadata": {},
     "source": [
      "Resampling simply means that we are given n particles each with a weight, and we will create a new sample by picking these particles \n",
      "with replacement based on these weights.  \n",
      "\n",
      "Here is a simple example, suppose I have 3 particles A, B, and C with weights 4, 2, and 1 respectively. In my new set of particles I \n",
      "should have twice as many A particles as B ones, and twice as many B particles as C.\n",
      "\n",
      "now create a new set of particles using this method and call that p"
     ]
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "\n",
      "myrobot = robot()\n",
      "myrobot = myrobot.move(0.1, 5.0)\n",
      "Z = myrobot.sense()\n",
      "\n",
      "N = 1000\n",
      "p = []\n",
      "\n",
      "\n",
      "print p"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "[[x=62.600 y=17.123 orient=5.6908], [x=65.640 y=22.416 orient=5.5109], [x=60.174 y=22.617 orient=2.8975], [x=60.174 y=22.617 orient=2.8975], [x=65.640 y=22.416 orient=5.5109], [x=60.174 y=22.617 orient=2.8975], [x=62.600 y=17.123 orient=5.6908], [x=58.709 y=20.893 orient=0.2426], [x=68.072 y=25.445 orient=3.6899], [x=63.159 y=15.033 orient=0.2284], [x=67.160 y=27.494 orient=5.6512], [x=67.160 y=27.494 orient=5.6512], [x=62.892 y=16.125 orient=2.4730], [x=62.987 y=20.014 orient=2.5047], [x=62.669 y=29.136 orient=1.1942], [x=68.072 y=25.445 orient=3.6899], [x=68.072 y=25.445 orient=3.6899], [x=64.725 y=17.230 orient=1.4140], [x=63.159 y=15.033 orient=0.2284], [x=58.709 y=20.893 orient=0.2426], [x=63.159 y=15.033 orient=0.2284], [x=62.892 y=16.125 orient=2.4730], [x=60.189 y=19.192 orient=4.4119], [x=63.749 y=28.510 orient=0.6105], [x=60.174 y=22.617 orient=2.8975], [x=65.640 y=22.416 orient=5.5109], [x=58.709 y=20.893 orient=0.2426], [x=67.160 y=27.494 orient=5.6512], [x=60.174 y=22.617 orient=2.8975], [x=63.749 y=28.510 orient=0.6105], [x=61.410 y=27.629 orient=1.9361], [x=68.072 y=25.445 orient=3.6899], [x=60.189 y=19.192 orient=4.4119], [x=63.390 y=27.703 orient=3.3770], [x=62.987 y=20.014 orient=2.5047], [x=60.189 y=19.192 orient=4.4119], [x=63.390 y=27.703 orient=3.3770], [x=65.640 y=22.416 orient=5.5109], [x=63.159 y=15.033 orient=0.2284], [x=61.410 y=27.629 orient=1.9361], [x=64.725 y=17.230 orient=1.4140], [x=60.714 y=25.287 orient=4.9028], [x=62.987 y=20.014 orient=2.5047], [x=62.892 y=16.125 orient=2.4730], [x=65.640 y=22.416 orient=5.5109], [x=67.160 y=27.494 orient=5.6512], [x=62.987 y=20.014 orient=2.5047], [x=63.749 y=28.510 orient=0.6105], [x=65.640 y=22.416 orient=5.5109], [x=63.749 y=28.510 orient=0.6105], [x=60.174 y=22.617 orient=2.8975], [x=60.189 y=19.192 orient=4.4119], [x=62.600 y=17.123 orient=5.6908], [x=62.987 y=20.014 orient=2.5047], [x=63.390 y=27.703 orient=3.3770], [x=68.072 y=25.445 orient=3.6899], [x=65.640 y=22.416 orient=5.5109], [x=58.709 y=20.893 orient=0.2426], [x=62.892 y=16.125 orient=2.4730], [x=63.571 y=32.633 orient=4.4861], [x=62.987 y=20.014 orient=2.5047], [x=60.189 y=19.192 orient=4.4119], [x=69.057 y=33.039 orient=0.9117], [x=60.574 y=27.893 orient=5.5351], [x=58.709 y=20.893 orient=0.2426], [x=60.174 y=22.617 orient=2.8975], [x=57.600 y=26.078 orient=5.5993], [x=64.725 y=17.230 orient=1.4140], [x=68.072 y=25.445 orient=3.6899], [x=65.640 y=22.416 orient=5.5109], [x=68.072 y=25.445 orient=3.6899], [x=67.160 y=27.494 orient=5.6512], [x=58.709 y=20.893 orient=0.2426], [x=60.189 y=19.192 orient=4.4119], [x=60.174 y=22.617 orient=2.8975], [x=63.390 y=27.703 orient=3.3770], [x=64.725 y=17.230 orient=1.4140], [x=58.709 y=20.893 orient=0.2426], [x=62.987 y=20.014 orient=2.5047], [x=64.725 y=17.230 orient=1.4140], [x=64.786 y=31.835 orient=3.0217], [x=62.987 y=20.014 orient=2.5047], [x=63.749 y=28.510 orient=0.6105], [x=63.749 y=28.510 orient=0.6105], [x=70.848 y=23.457 orient=4.8458], [x=62.987 y=20.014 orient=2.5047], [x=60.189 y=19.192 orient=4.4119], [x=60.174 y=22.617 orient=2.8975], [x=62.600 y=17.123 orient=5.6908], [x=62.892 y=16.125 orient=2.4730], [x=62.600 y=17.123 orient=5.6908], [x=62.987 y=20.014 orient=2.5047], [x=60.174 y=22.617 orient=2.8975], [x=60.174 y=22.617 orient=2.8975], [x=63.040 y=33.040 orient=3.6497], [x=60.189 y=19.192 orient=4.4119], [x=60.714 y=25.287 orient=4.9028], [x=63.159 y=15.033 orient=0.2284], [x=63.390 y=27.703 orient=3.3770], [x=60.189 y=19.192 orient=4.4119], [x=64.725 y=17.230 orient=1.4140], [x=60.174 y=22.617 orient=2.8975], [x=60.714 y=25.287 orient=4.9028], [x=63.159 y=15.033 orient=0.2284], [x=63.159 y=15.033 orient=0.2284], [x=61.410 y=27.629 orient=1.9361], [x=65.640 y=22.416 orient=5.5109], [x=65.640 y=22.416 orient=5.5109], [x=60.174 y=22.617 orient=2.8975], [x=63.749 y=28.510 orient=0.6105], [x=60.574 y=27.893 orient=5.5351], [x=62.987 y=20.014 orient=2.5047], [x=60.174 y=22.617 orient=2.8975], [x=69.238 y=18.692 orient=5.7303], [x=63.749 y=28.510 orient=0.6105], [x=62.987 y=20.014 orient=2.5047], [x=62.987 y=20.014 orient=2.5047], [x=65.640 y=22.416 orient=5.5109], [x=63.159 y=15.033 orient=0.2284], [x=67.160 y=27.494 orient=5.6512], [x=61.410 y=27.629 orient=1.9361], [x=68.072 y=25.445 orient=3.6899], [x=62.987 y=20.014 orient=2.5047], [x=60.174 y=22.617 orient=2.8975], [x=60.189 y=19.192 orient=4.4119], [x=60.174 y=22.617 orient=2.8975], [x=64.725 y=17.230 orient=1.4140], [x=61.410 y=27.629 orient=1.9361], [x=64.786 y=31.835 orient=3.0217], [x=60.189 y=19.192 orient=4.4119], [x=65.640 y=22.416 orient=5.5109], [x=57.600 y=26.078 orient=5.5993], [x=67.160 y=27.494 orient=5.6512], [x=62.669 y=29.136 orient=1.1942], [x=62.987 y=20.014 orient=2.5047], [x=60.714 y=25.287 orient=4.9028], [x=63.159 y=15.033 orient=0.2284], [x=72.773 y=26.174 orient=1.8237], [x=62.669 y=29.136 orient=1.1942], [x=58.783 y=27.311 orient=0.5627], [x=60.174 y=22.617 orient=2.8975], [x=60.574 y=27.893 orient=5.5351], [x=68.072 y=25.445 orient=3.6899], [x=60.714 y=25.287 orient=4.9028], [x=60.574 y=27.893 orient=5.5351], [x=63.749 y=28.510 orient=0.6105], [x=57.807 y=28.066 orient=5.1702], [x=60.174 y=22.617 orient=2.8975], [x=64.725 y=17.230 orient=1.4140], [x=64.725 y=17.230 orient=1.4140], [x=68.072 y=25.445 orient=3.6899], [x=67.160 y=27.494 orient=5.6512], [x=60.189 y=19.192 orient=4.4119], [x=57.600 y=26.078 orient=5.5993], [x=54.719 y=19.531 orient=1.2957], [x=57.600 y=26.078 orient=5.5993], [x=62.600 y=17.123 orient=5.6908], [x=61.410 y=27.629 orient=1.9361], [x=58.783 y=27.311 orient=0.5627], [x=62.892 y=16.125 orient=2.4730], [x=62.669 y=29.136 orient=1.1942], [x=68.072 y=25.445 orient=3.6899], [x=65.640 y=22.416 orient=5.5109], [x=64.725 y=17.230 orient=1.4140], [x=60.714 y=25.287 orient=4.9028], [x=62.987 y=20.014 orient=2.5047], [x=64.725 y=17.230 orient=1.4140], [x=62.987 y=20.014 orient=2.5047], [x=62.987 y=20.014 orient=2.5047], [x=63.571 y=32.633 orient=4.4861], [x=64.725 y=17.230 orient=1.4140], [x=61.410 y=27.629 orient=1.9361], [x=62.669 y=29.136 orient=1.1942], [x=63.390 y=27.703 orient=3.3770], [x=68.072 y=25.445 orient=3.6899], [x=62.987 y=20.014 orient=2.5047], [x=60.714 y=25.287 orient=4.9028], [x=64.725 y=17.230 orient=1.4140], [x=62.987 y=20.014 orient=2.5047], [x=64.725 y=17.230 orient=1.4140], [x=65.640 y=22.416 orient=5.5109], [x=65.640 y=22.416 orient=5.5109], [x=67.160 y=27.494 orient=5.6512], [x=64.725 y=17.230 orient=1.4140], [x=60.189 y=19.192 orient=4.4119], [x=67.160 y=27.494 orient=5.6512], [x=62.987 y=20.014 orient=2.5047], [x=62.892 y=16.125 orient=2.4730], [x=63.390 y=27.703 orient=3.3770], [x=60.174 y=22.617 orient=2.8975], [x=55.973 y=21.065 orient=0.3253], [x=58.709 y=20.893 orient=0.2426], [x=64.725 y=17.230 orient=1.4140], [x=63.390 y=27.703 orient=3.3770], [x=60.714 y=25.287 orient=4.9028], [x=62.669 y=29.136 orient=1.1942], [x=62.600 y=17.123 orient=5.6908], [x=67.160 y=27.494 orient=5.6512], [x=60.574 y=27.893 orient=5.5351], [x=70.848 y=23.457 orient=4.8458], [x=58.709 y=20.893 orient=0.2426], [x=60.714 y=25.287 orient=4.9028], [x=63.390 y=27.703 orient=3.3770], [x=68.072 y=25.445 orient=3.6899], [x=60.174 y=22.617 orient=2.8975], [x=64.725 y=17.230 orient=1.4140], [x=60.714 y=25.287 orient=4.9028], [x=62.892 y=16.125 orient=2.4730], [x=62.987 y=20.014 orient=2.5047], [x=63.749 y=28.510 orient=0.6105], [x=60.189 y=19.192 orient=4.4119], [x=67.160 y=27.494 orient=5.6512], [x=63.390 y=27.703 orient=3.3770], [x=62.600 y=17.123 orient=5.6908], [x=63.159 y=15.033 orient=0.2284], [x=62.987 y=20.014 orient=2.5047], [x=63.390 y=27.703 orient=3.3770], [x=60.714 y=25.287 orient=4.9028], [x=60.189 y=19.192 orient=4.4119], [x=60.574 y=27.893 orient=5.5351], [x=65.640 y=22.416 orient=5.5109], [x=65.640 y=22.416 orient=5.5109], [x=63.390 y=27.703 orient=3.3770], [x=62.987 y=20.014 orient=2.5047], [x=62.987 y=20.014 orient=2.5047], [x=62.669 y=29.136 orient=1.1942], [x=60.174 y=22.617 orient=2.8975], [x=60.174 y=22.617 orient=2.8975], [x=62.987 y=20.014 orient=2.5047], [x=58.783 y=27.311 orient=0.5627], [x=65.640 y=22.416 orient=5.5109], [x=68.072 y=25.445 orient=3.6899], [x=60.189 y=19.192 orient=4.4119], [x=60.574 y=27.893 orient=5.5351], [x=63.390 y=27.703 orient=3.3770], [x=60.714 y=25.287 orient=4.9028], [x=62.600 y=17.123 orient=5.6908], [x=62.892 y=16.125 orient=2.4730], [x=62.987 y=20.014 orient=2.5047], [x=64.725 y=17.230 orient=1.4140], [x=62.669 y=29.136 orient=1.1942], [x=65.640 y=22.416 orient=5.5109], [x=58.709 y=20.893 orient=0.2426], [x=65.640 y=22.416 orient=5.5109], [x=61.410 y=27.629 orient=1.9361], [x=62.987 y=20.014 orient=2.5047], [x=64.725 y=17.230 orient=1.4140], [x=67.160 y=27.494 orient=5.6512], [x=65.640 y=22.416 orient=5.5109], [x=60.714 y=25.287 orient=4.9028], [x=65.640 y=22.416 orient=5.5109], [x=65.259 y=35.630 orient=2.2356], [x=67.160 y=27.494 orient=5.6512], [x=58.709 y=20.893 orient=0.2426], [x=62.600 y=17.123 orient=5.6908], [x=64.725 y=17.230 orient=1.4140], [x=58.783 y=27.311 orient=0.5627], [x=68.072 y=25.445 orient=3.6899], [x=69.057 y=33.039 orient=0.9117], [x=65.640 y=22.416 orient=5.5109], [x=60.174 y=22.617 orient=2.8975], [x=62.669 y=29.136 orient=1.1942], [x=62.987 y=20.014 orient=2.5047], [x=64.786 y=31.835 orient=3.0217], [x=62.669 y=29.136 orient=1.1942], [x=69.238 y=18.692 orient=5.7303], [x=63.390 y=27.703 orient=3.3770], [x=63.390 y=27.703 orient=3.3770], [x=63.390 y=27.703 orient=3.3770], [x=62.987 y=20.014 orient=2.5047], [x=60.714 y=25.287 orient=4.9028], [x=65.640 y=22.416 orient=5.5109], [x=63.159 y=15.033 orient=0.2284], [x=66.264 y=13.297 orient=2.2057], [x=63.390 y=27.703 orient=3.3770], [x=69.238 y=18.692 orient=5.7303], [x=67.160 y=27.494 orient=5.6512], [x=64.725 y=17.230 orient=1.4140], [x=69.238 y=18.692 orient=5.7303], [x=68.072 y=25.445 orient=3.6899], [x=62.481 y=13.413 orient=1.6861], [x=67.160 y=27.494 orient=5.6512], [x=62.987 y=20.014 orient=2.5047], [x=56.136 y=27.163 orient=4.3826], [x=63.749 y=28.510 orient=0.6105], [x=61.410 y=27.629 orient=1.9361], [x=65.640 y=22.416 orient=5.5109], [x=60.714 y=25.287 orient=4.9028], [x=63.749 y=28.510 orient=0.6105], [x=63.390 y=27.703 orient=3.3770], [x=60.189 y=19.192 orient=4.4119], [x=66.264 y=13.297 orient=2.2057], [x=62.669 y=29.136 orient=1.1942], [x=63.159 y=15.033 orient=0.2284], [x=55.973 y=21.065 orient=0.3253], [x=62.669 y=29.136 orient=1.1942], [x=60.189 y=19.192 orient=4.4119], [x=60.189 y=19.192 orient=4.4119], [x=58.783 y=27.311 orient=0.5627], [x=68.072 y=25.445 orient=3.6899], [x=62.669 y=29.136 orient=1.1942], [x=63.749 y=28.510 orient=0.6105], [x=61.410 y=27.629 orient=1.9361], [x=60.174 y=22.617 orient=2.8975], [x=61.410 y=27.629 orient=1.9361], [x=62.600 y=17.123 orient=5.6908], [x=63.283 y=14.866 orient=2.0852], [x=62.987 y=20.014 orient=2.5047], [x=60.574 y=27.893 orient=5.5351], [x=58.709 y=20.893 orient=0.2426], [x=60.714 y=25.287 orient=4.9028], [x=68.072 y=25.445 orient=3.6899], [x=60.189 y=19.192 orient=4.4119], [x=65.640 y=22.416 orient=5.5109], [x=63.283 y=14.866 orient=2.0852], [x=62.987 y=20.014 orient=2.5047], [x=60.174 y=22.617 orient=2.8975], [x=65.640 y=22.416 orient=5.5109], [x=60.189 y=19.192 orient=4.4119], [x=58.709 y=20.893 orient=0.2426], [x=68.072 y=25.445 orient=3.6899], [x=60.714 y=25.287 orient=4.9028], [x=60.171 y=32.316 orient=1.9545], [x=63.040 y=33.040 orient=3.6497], [x=65.640 y=22.416 orient=5.5109], [x=60.714 y=25.287 orient=4.9028], [x=60.714 y=25.287 orient=4.9028], [x=62.600 y=17.123 orient=5.6908], [x=65.640 y=22.416 orient=5.5109], [x=70.848 y=23.457 orient=4.8458], [x=70.848 y=23.457 orient=4.8458], [x=55.973 y=21.065 orient=0.3253], [x=58.783 y=27.311 orient=0.5627], [x=60.574 y=27.893 orient=5.5351], [x=60.189 y=19.192 orient=4.4119], [x=58.709 y=20.893 orient=0.2426], [x=61.410 y=27.629 orient=1.9361], [x=62.987 y=20.014 orient=2.5047], [x=68.072 y=25.445 orient=3.6899], [x=60.174 y=22.617 orient=2.8975], [x=60.714 y=25.287 orient=4.9028], [x=57.600 y=26.078 orient=5.5993], [x=68.072 y=25.445 orient=3.6899], [x=67.160 y=27.494 orient=5.6512], [x=62.987 y=20.014 orient=2.5047], [x=60.714 y=25.287 orient=4.9028], [x=62.600 y=17.123 orient=5.6908], [x=57.600 y=26.078 orient=5.5993], [x=67.110 y=32.163 orient=5.4945], [x=67.160 y=27.494 orient=5.6512], [x=68.072 y=25.445 orient=3.6899], [x=62.987 y=20.014 orient=2.5047], [x=63.749 y=28.510 orient=0.6105], [x=67.160 y=27.494 orient=5.6512], [x=63.283 y=14.866 orient=2.0852], [x=65.640 y=22.416 orient=5.5109], [x=58.709 y=20.893 orient=0.2426], [x=55.973 y=21.065 orient=0.3253], [x=61.410 y=27.629 orient=1.9361], [x=60.174 y=22.617 orient=2.8975], [x=60.174 y=22.617 orient=2.8975], [x=60.574 y=27.893 orient=5.5351], [x=58.783 y=27.311 orient=0.5627], [x=65.640 y=22.416 orient=5.5109], [x=60.174 y=22.617 orient=2.8975], [x=62.892 y=16.125 orient=2.4730], [x=69.238 y=18.692 orient=5.7303], [x=62.892 y=16.125 orient=2.4730], [x=58.709 y=20.893 orient=0.2426], [x=60.189 y=19.192 orient=4.4119], [x=62.987 y=20.014 orient=2.5047], [x=64.725 y=17.230 orient=1.4140], [x=60.174 y=22.617 orient=2.8975], [x=61.410 y=27.629 orient=1.9361], [x=60.189 y=19.192 orient=4.4119], [x=68.072 y=25.445 orient=3.6899], [x=62.669 y=29.136 orient=1.1942], [x=62.987 y=20.014 orient=2.5047], [x=64.725 y=17.230 orient=1.4140], [x=64.725 y=17.230 orient=1.4140], [x=62.600 y=17.123 orient=5.6908], [x=67.160 y=27.494 orient=5.6512], [x=61.410 y=27.629 orient=1.9361], [x=67.160 y=27.494 orient=5.6512], [x=61.410 y=27.629 orient=1.9361], [x=65.640 y=22.416 orient=5.5109], [x=60.714 y=25.287 orient=4.9028], [x=60.189 y=19.192 orient=4.4119], [x=58.709 y=20.893 orient=0.2426], [x=60.174 y=22.617 orient=2.8975], [x=68.072 y=25.445 orient=3.6899], [x=62.987 y=20.014 orient=2.5047], [x=60.189 y=19.192 orient=4.4119], [x=65.640 y=22.416 orient=5.5109], [x=65.640 y=22.416 orient=5.5109], [x=67.160 y=27.494 orient=5.6512], [x=62.987 y=20.014 orient=2.5047], [x=63.040 y=33.040 orient=3.6497], [x=60.714 y=25.287 orient=4.9028], [x=62.669 y=29.136 orient=1.1942], [x=62.892 y=16.125 orient=2.4730], [x=65.640 y=22.416 orient=5.5109], [x=62.600 y=17.123 orient=5.6908], [x=62.892 y=16.125 orient=2.4730], [x=67.160 y=27.494 orient=5.6512], [x=58.709 y=20.893 orient=0.2426], [x=62.987 y=20.014 orient=2.5047], [x=60.174 y=22.617 orient=2.8975], [x=65.259 y=35.630 orient=2.2356], [x=61.410 y=27.629 orient=1.9361], [x=62.600 y=17.123 orient=5.6908], [x=60.189 y=19.192 orient=4.4119], [x=68.072 y=25.445 orient=3.6899], [x=63.390 y=27.703 orient=3.3770], [x=60.189 y=19.192 orient=4.4119], [x=68.072 y=25.445 orient=3.6899], [x=60.174 y=22.617 orient=2.8975], [x=73.086 y=25.151 orient=2.4954], [x=63.159 y=15.033 orient=0.2284], [x=62.600 y=17.123 orient=5.6908], [x=66.264 y=13.297 orient=2.2057], [x=62.987 y=20.014 orient=2.5047], [x=66.264 y=13.297 orient=2.2057], [x=69.238 y=18.692 orient=5.7303], [x=62.987 y=20.014 orient=2.5047], [x=61.410 y=27.629 orient=1.9361], [x=62.987 y=20.014 orient=2.5047], [x=69.238 y=18.692 orient=5.7303], [x=62.892 y=16.125 orient=2.4730], [x=60.714 y=25.287 orient=4.9028], [x=60.574 y=27.893 orient=5.5351], [x=60.189 y=19.192 orient=4.4119], [x=63.749 y=28.510 orient=0.6105], [x=60.189 y=19.192 orient=4.4119], [x=63.390 y=27.703 orient=3.3770], [x=65.640 y=22.416 orient=5.5109], [x=67.160 y=27.494 orient=5.6512], [x=60.189 y=19.192 orient=4.4119], [x=67.110 y=32.163 orient=5.4945], [x=68.072 y=25.445 orient=3.6899], [x=67.160 y=27.494 orient=5.6512], [x=60.574 y=27.893 orient=5.5351], [x=62.987 y=20.014 orient=2.5047], [x=64.725 y=17.230 orient=1.4140], [x=65.640 y=22.416 orient=5.5109], [x=68.072 y=25.445 orient=3.6899], [x=69.238 y=18.692 orient=5.7303], [x=66.736 y=7.8275 orient=2.1384], [x=58.709 y=20.893 orient=0.2426], [x=65.640 y=22.416 orient=5.5109], [x=56.136 y=27.163 orient=4.3826], [x=67.160 y=27.494 orient=5.6512], [x=57.807 y=28.066 orient=5.1702], [x=63.749 y=28.510 orient=0.6105], [x=60.574 y=27.893 orient=5.5351], [x=60.174 y=22.617 orient=2.8975], [x=60.714 y=25.287 orient=4.9028], [x=62.600 y=17.123 orient=5.6908], [x=63.040 y=33.040 orient=3.6497], [x=64.786 y=31.835 orient=3.0217], [x=60.174 y=22.617 orient=2.8975], [x=70.848 y=23.457 orient=4.8458], [x=60.189 y=19.192 orient=4.4119], [x=63.749 y=28.510 orient=0.6105], [x=60.714 y=25.287 orient=4.9028], [x=60.189 y=19.192 orient=4.4119], [x=60.574 y=27.893 orient=5.5351], [x=61.410 y=27.629 orient=1.9361], [x=65.640 y=22.416 orient=5.5109], [x=65.640 y=22.416 orient=5.5109], [x=57.600 y=26.078 orient=5.5993], [x=63.571 y=32.633 orient=4.4861], [x=62.600 y=17.123 orient=5.6908], [x=69.238 y=18.692 orient=5.7303], [x=67.160 y=27.494 orient=5.6512], [x=63.159 y=15.033 orient=0.2284], [x=60.174 y=22.617 orient=2.8975], [x=65.640 y=22.416 orient=5.5109], [x=60.189 y=19.192 orient=4.4119], [x=63.159 y=15.033 orient=0.2284], [x=64.786 y=31.835 orient=3.0217], [x=58.709 y=20.893 orient=0.2426], [x=63.283 y=14.866 orient=2.0852], [x=63.390 y=27.703 orient=3.3770], [x=63.283 y=14.866 orient=2.0852], [x=65.640 y=22.416 orient=5.5109], [x=62.892 y=16.125 orient=2.4730], [x=62.987 y=20.014 orient=2.5047], [x=60.174 y=22.617 orient=2.8975], [x=65.640 y=22.416 orient=5.5109], [x=62.892 y=16.125 orient=2.4730], [x=62.669 y=29.136 orient=1.1942], [x=68.072 y=25.445 orient=3.6899], [x=63.749 y=28.510 orient=0.6105], [x=62.987 y=20.014 orient=2.5047], [x=67.160 y=27.494 orient=5.6512], [x=60.574 y=27.893 orient=5.5351], [x=64.725 y=17.230 orient=1.4140], [x=58.709 y=20.893 orient=0.2426], [x=58.783 y=27.311 orient=0.5627], [x=63.390 y=27.703 orient=3.3770], [x=62.600 y=17.123 orient=5.6908], [x=62.669 y=29.136 orient=1.1942], [x=60.714 y=25.287 orient=4.9028], [x=62.987 y=20.014 orient=2.5047], [x=63.159 y=15.033 orient=0.2284], [x=62.600 y=17.123 orient=5.6908], [x=62.600 y=17.123 orient=5.6908], [x=63.390 y=27.703 orient=3.3770], [x=69.238 y=18.692 orient=5.7303], [x=63.749 y=28.510 orient=0.6105], [x=65.640 y=22.416 orient=5.5109], [x=63.749 y=28.510 orient=0.6105], [x=62.987 y=20.014 orient=2.5047], [x=63.749 y=28.510 orient=0.6105], [x=63.390 y=27.703 orient=3.3770], [x=62.892 y=16.125 orient=2.4730], [x=63.390 y=27.703 orient=3.3770], [x=62.669 y=29.136 orient=1.1942], [x=58.709 y=20.893 orient=0.2426], [x=62.987 y=20.014 orient=2.5047], [x=64.725 y=17.230 orient=1.4140], [x=60.189 y=19.192 orient=4.4119], [x=67.160 y=27.494 orient=5.6512], [x=62.987 y=20.014 orient=2.5047], [x=63.390 y=27.703 orient=3.3770], [x=62.987 y=20.014 orient=2.5047], [x=67.160 y=27.494 orient=5.6512], [x=65.640 y=22.416 orient=5.5109], [x=60.174 y=22.617 orient=2.8975], [x=61.410 y=27.629 orient=1.9361], [x=64.786 y=31.835 orient=3.0217], [x=60.189 y=19.192 orient=4.4119], [x=62.669 y=29.136 orient=1.1942], [x=63.283 y=14.866 orient=2.0852], [x=63.283 y=14.866 orient=2.0852], [x=62.600 y=17.123 orient=5.6908], [x=63.749 y=28.510 orient=0.6105], [x=60.189 y=19.192 orient=4.4119], [x=58.709 y=20.893 orient=0.2426], [x=63.749 y=28.510 orient=0.6105], [x=62.669 y=29.136 orient=1.1942], [x=63.283 y=14.866 orient=2.0852], [x=69.238 y=18.692 orient=5.7303], [x=64.786 y=31.835 orient=3.0217], [x=65.640 y=22.416 orient=5.5109], [x=62.987 y=20.014 orient=2.5047], [x=60.174 y=22.617 orient=2.8975], [x=60.714 y=25.287 orient=4.9028], [x=60.714 y=25.287 orient=4.9028], [x=57.600 y=26.078 orient=5.5993], [x=60.174 y=22.617 orient=2.8975], [x=65.640 y=22.416 orient=5.5109], [x=64.725 y=17.230 orient=1.4140], [x=63.159 y=15.033 orient=0.2284], [x=62.987 y=20.014 orient=2.5047], [x=63.283 y=14.866 orient=2.0852], [x=63.040 y=33.040 orient=3.6497], [x=65.640 y=22.416 orient=5.5109], [x=65.640 y=22.416 orient=5.5109], [x=60.574 y=27.893 orient=5.5351], [x=60.714 y=25.287 orient=4.9028], [x=60.189 y=19.192 orient=4.4119], [x=61.410 y=27.629 orient=1.9361], [x=60.714 y=25.287 orient=4.9028], [x=64.786 y=31.835 orient=3.0217], [x=64.725 y=17.230 orient=1.4140], [x=58.783 y=27.311 orient=0.5627], [x=58.709 y=20.893 orient=0.2426], [x=61.410 y=27.629 orient=1.9361], [x=60.714 y=25.287 orient=4.9028], [x=62.600 y=17.123 orient=5.6908], [x=63.283 y=14.866 orient=2.0852], [x=67.110 y=32.163 orient=5.4945], [x=63.390 y=27.703 orient=3.3770], [x=60.574 y=27.893 orient=5.5351], [x=60.714 y=25.287 orient=4.9028], [x=62.987 y=20.014 orient=2.5047], [x=63.390 y=27.703 orient=3.3770], [x=61.410 y=27.629 orient=1.9361], [x=63.390 y=27.703 orient=3.3770], [x=60.174 y=22.617 orient=2.8975], [x=62.669 y=29.136 orient=1.1942], [x=63.749 y=28.510 orient=0.6105], [x=58.709 y=20.893 orient=0.2426], [x=60.714 y=25.287 orient=4.9028], [x=63.283 y=14.866 orient=2.0852], [x=60.574 y=27.893 orient=5.5351], [x=63.390 y=27.703 orient=3.3770], [x=63.159 y=15.033 orient=0.2284], [x=60.574 y=27.893 orient=5.5351], [x=68.072 y=25.445 orient=3.6899], [x=60.174 y=22.617 orient=2.8975], [x=60.574 y=27.893 orient=5.5351], [x=62.987 y=20.014 orient=2.5047], [x=68.072 y=25.445 orient=3.6899], [x=63.390 y=27.703 orient=3.3770], [x=62.600 y=17.123 orient=5.6908], [x=62.987 y=20.014 orient=2.5047], [x=58.709 y=20.893 orient=0.2426], [x=60.189 y=19.192 orient=4.4119], [x=60.714 y=25.287 orient=4.9028], [x=60.714 y=25.287 orient=4.9028], [x=68.072 y=25.445 orient=3.6899], [x=61.410 y=27.629 orient=1.9361], [x=58.709 y=20.893 orient=0.2426], [x=68.072 y=25.445 orient=3.6899], [x=62.892 y=16.125 orient=2.4730], [x=70.848 y=23.457 orient=4.8458], [x=63.390 y=27.703 orient=3.3770], [x=58.709 y=20.893 orient=0.2426], [x=65.640 y=22.416 orient=5.5109], [x=68.072 y=25.445 orient=3.6899], [x=62.600 y=17.123 orient=5.6908], [x=65.640 y=22.416 orient=5.5109], [x=60.714 y=25.287 orient=4.9028], [x=72.773 y=26.174 orient=1.8237], [x=69.057 y=33.039 orient=0.9117], [x=63.390 y=27.703 orient=3.3770], [x=60.189 y=19.192 orient=4.4119], [x=60.714 y=25.287 orient=4.9028], [x=70.848 y=23.457 orient=4.8458], [x=58.709 y=20.893 orient=0.2426], [x=62.987 y=20.014 orient=2.5047], [x=67.160 y=27.494 orient=5.6512], [x=58.709 y=20.893 orient=0.2426], [x=63.749 y=28.510 orient=0.6105], [x=62.987 y=20.014 orient=2.5047], [x=60.174 y=22.617 orient=2.8975], [x=60.174 y=22.617 orient=2.8975], [x=64.725 y=17.230 orient=1.4140], [x=68.072 y=25.445 orient=3.6899], [x=60.714 y=25.287 orient=4.9028], [x=60.714 y=25.287 orient=4.9028], [x=60.714 y=25.287 orient=4.9028], [x=61.410 y=27.629 orient=1.9361], [x=67.160 y=27.494 orient=5.6512], [x=63.749 y=28.510 orient=0.6105], [x=65.640 y=22.416 orient=5.5109], [x=60.189 y=19.192 orient=4.4119], [x=63.159 y=15.033 orient=0.2284], [x=58.709 y=20.893 orient=0.2426], [x=62.892 y=16.125 orient=2.4730], [x=72.137 y=27.087 orient=1.6225], [x=58.709 y=20.893 orient=0.2426], [x=61.410 y=27.629 orient=1.9361], [x=63.159 y=15.033 orient=0.2284], [x=63.749 y=28.510 orient=0.6105], [x=64.725 y=17.230 orient=1.4140], [x=64.725 y=17.230 orient=1.4140], [x=54.719 y=19.531 orient=1.2957], [x=60.189 y=19.192 orient=4.4119], [x=62.600 y=17.123 orient=5.6908], [x=61.410 y=27.629 orient=1.9361], [x=62.987 y=20.014 orient=2.5047], [x=61.410 y=27.629 orient=1.9361], [x=62.669 y=29.136 orient=1.1942], [x=69.238 y=18.692 orient=5.7303], [x=62.600 y=17.123 orient=5.6908], [x=62.669 y=29.136 orient=1.1942], [x=58.709 y=20.893 orient=0.2426], [x=58.709 y=20.893 orient=0.2426], [x=67.160 y=27.494 orient=5.6512], [x=63.390 y=27.703 orient=3.3770], [x=61.410 y=27.629 orient=1.9361], [x=62.987 y=20.014 orient=2.5047], [x=60.174 y=22.617 orient=2.8975], [x=60.714 y=25.287 orient=4.9028], [x=67.160 y=27.494 orient=5.6512], [x=60.574 y=27.893 orient=5.5351], [x=62.892 y=16.125 orient=2.4730], [x=67.110 y=32.163 orient=5.4945], [x=62.669 y=29.136 orient=1.1942], [x=68.072 y=25.445 orient=3.6899], [x=63.283 y=14.866 orient=2.0852], [x=63.390 y=27.703 orient=3.3770], [x=62.987 y=20.014 orient=2.5047], [x=60.174 y=22.617 orient=2.8975], [x=61.410 y=27.629 orient=1.9361], [x=62.987 y=20.014 orient=2.5047], [x=69.238 y=18.692 orient=5.7303], [x=61.410 y=27.629 orient=1.9361], [x=60.714 y=25.287 orient=4.9028], [x=68.072 y=25.445 orient=3.6899], [x=58.709 y=20.893 orient=0.2426], [x=64.725 y=17.230 orient=1.4140], [x=62.987 y=20.014 orient=2.5047], [x=63.159 y=15.033 orient=0.2284], [x=68.072 y=25.445 orient=3.6899], [x=60.174 y=22.617 orient=2.8975], [x=68.072 y=25.445 orient=3.6899], [x=67.160 y=27.494 orient=5.6512], [x=61.410 y=27.629 orient=1.9361], [x=67.110 y=32.163 orient=5.4945], [x=62.892 y=16.125 orient=2.4730], [x=60.174 y=22.617 orient=2.8975], [x=68.072 y=25.445 orient=3.6899], [x=60.189 y=19.192 orient=4.4119], [x=56.136 y=27.163 orient=4.3826], [x=65.640 y=22.416 orient=5.5109], [x=63.159 y=15.033 orient=0.2284], [x=65.640 y=22.416 orient=5.5109], [x=62.987 y=20.014 orient=2.5047], [x=62.600 y=17.123 orient=5.6908], [x=62.600 y=17.123 orient=5.6908], [x=60.189 y=19.192 orient=4.4119], [x=68.072 y=25.445 orient=3.6899], [x=65.640 y=22.416 orient=5.5109], [x=65.640 y=22.416 orient=5.5109], [x=65.640 y=22.416 orient=5.5109], [x=64.725 y=17.230 orient=1.4140], [x=68.072 y=25.445 orient=3.6899], [x=63.390 y=27.703 orient=3.3770], [x=65.640 y=22.416 orient=5.5109], [x=58.709 y=20.893 orient=0.2426], [x=63.283 y=14.866 orient=2.0852], [x=62.600 y=17.123 orient=5.6908], [x=62.987 y=20.014 orient=2.5047], [x=63.390 y=27.703 orient=3.3770], [x=62.987 y=20.014 orient=2.5047], [x=67.160 y=27.494 orient=5.6512], [x=60.174 y=22.617 orient=2.8975], [x=67.110 y=32.163 orient=5.4945], [x=63.749 y=28.510 orient=0.6105], [x=62.892 y=16.125 orient=2.4730], [x=65.640 y=22.416 orient=5.5109], [x=60.174 y=22.617 orient=2.8975], [x=63.390 y=27.703 orient=3.3770], [x=60.174 y=22.617 orient=2.8975], [x=58.709 y=20.893 orient=0.2426], [x=65.640 y=22.416 orient=5.5109], [x=65.640 y=22.416 orient=5.5109], [x=60.189 y=19.192 orient=4.4119], [x=62.669 y=29.136 orient=1.1942], [x=62.481 y=13.413 orient=1.6861], [x=67.160 y=27.494 orient=5.6512], [x=60.174 y=22.617 orient=2.8975], [x=62.669 y=29.136 orient=1.1942], [x=60.189 y=19.192 orient=4.4119], [x=63.390 y=27.703 orient=3.3770], [x=60.174 y=22.617 orient=2.8975], [x=67.160 y=27.494 orient=5.6512], [x=61.410 y=27.629 orient=1.9361], [x=61.410 y=27.629 orient=1.9361], [x=63.159 y=15.033 orient=0.2284], [x=62.892 y=16.125 orient=2.4730], [x=60.714 y=25.287 orient=4.9028], [x=72.773 y=26.174 orient=1.8237], [x=68.072 y=25.445 orient=3.6899], [x=65.640 y=22.416 orient=5.5109], [x=60.189 y=19.192 orient=4.4119], [x=63.571 y=32.633 orient=4.4861], [x=62.669 y=29.136 orient=1.1942], [x=62.892 y=16.125 orient=2.4730], [x=60.174 y=22.617 orient=2.8975], [x=64.725 y=17.230 orient=1.4140], [x=60.574 y=27.893 orient=5.5351], [x=62.987 y=20.014 orient=2.5047], [x=60.174 y=22.617 orient=2.8975], [x=62.987 y=20.014 orient=2.5047], [x=60.174 y=22.617 orient=2.8975], [x=69.057 y=33.039 orient=0.9117], [x=62.892 y=16.125 orient=2.4730], [x=62.892 y=16.125 orient=2.4730], [x=58.709 y=20.893 orient=0.2426], [x=60.189 y=19.192 orient=4.4119], [x=63.390 y=27.703 orient=3.3770], [x=72.773 y=26.174 orient=1.8237], [x=58.783 y=27.311 orient=0.5627], [x=58.709 y=20.893 orient=0.2426], [x=60.714 y=25.287 orient=4.9028], [x=62.987 y=20.014 orient=2.5047], [x=60.189 y=19.192 orient=4.4119], [x=58.783 y=27.311 orient=0.5627], [x=60.574 y=27.893 orient=5.5351], [x=60.714 y=25.287 orient=4.9028], [x=60.574 y=27.893 orient=5.5351], [x=68.072 y=25.445 orient=3.6899], [x=62.987 y=20.014 orient=2.5047], [x=62.481 y=13.413 orient=1.6861], [x=60.714 y=25.287 orient=4.9028], [x=65.640 y=22.416 orient=5.5109], [x=63.390 y=27.703 orient=3.3770], [x=62.892 y=16.125 orient=2.4730], [x=60.574 y=27.893 orient=5.5351], [x=63.571 y=32.633 orient=4.4861], [x=62.987 y=20.014 orient=2.5047], [x=62.987 y=20.014 orient=2.5047], [x=60.174 y=22.617 orient=2.8975], [x=67.160 y=27.494 orient=5.6512], [x=63.159 y=15.033 orient=0.2284], [x=60.174 y=22.617 orient=2.8975], [x=65.640 y=22.416 orient=5.5109], [x=71.186 y=15.235 orient=6.0356], [x=72.895 y=36.592 orient=4.0878], [x=61.410 y=27.629 orient=1.9361], [x=62.987 y=20.014 orient=2.5047], [x=64.725 y=17.230 orient=1.4140], [x=61.410 y=27.629 orient=1.9361], [x=65.640 y=22.416 orient=5.5109], [x=69.238 y=18.692 orient=5.7303], [x=58.783 y=27.311 orient=0.5627], [x=60.714 y=25.287 orient=4.9028], [x=67.160 y=27.494 orient=5.6512], [x=63.159 y=15.033 orient=0.2284], [x=60.174 y=22.617 orient=2.8975], [x=58.709 y=20.893 orient=0.2426], [x=67.160 y=27.494 orient=5.6512], [x=69.057 y=33.039 orient=0.9117], [x=57.600 y=26.078 orient=5.5993], [x=62.892 y=16.125 orient=2.4730], [x=62.669 y=29.136 orient=1.1942], [x=65.640 y=22.416 orient=5.5109], [x=62.669 y=29.136 orient=1.1942], [x=63.390 y=27.703 orient=3.3770], [x=62.669 y=29.136 orient=1.1942], [x=72.137 y=27.087 orient=1.6225], [x=61.410 y=27.629 orient=1.9361], [x=58.709 y=20.893 orient=0.2426], [x=58.709 y=20.893 orient=0.2426], [x=62.892 y=16.125 orient=2.4730], [x=62.892 y=16.125 orient=2.4730], [x=60.574 y=27.893 orient=5.5351], [x=63.749 y=28.510 orient=0.6105], [x=62.669 y=29.136 orient=1.1942], [x=63.283 y=14.866 orient=2.0852], [x=62.987 y=20.014 orient=2.5047], [x=60.714 y=25.287 orient=4.9028], [x=58.783 y=27.311 orient=0.5627], [x=55.973 y=21.065 orient=0.3253], [x=64.725 y=17.230 orient=1.4140], [x=68.072 y=25.445 orient=3.6899], [x=67.160 y=27.494 orient=5.6512], [x=63.749 y=28.510 orient=0.6105], [x=67.110 y=32.163 orient=5.4945], [x=60.174 y=22.617 orient=2.8975], [x=63.283 y=14.866 orient=2.0852], [x=60.714 y=25.287 orient=4.9028], [x=65.640 y=22.416 orient=5.5109], [x=60.174 y=22.617 orient=2.8975], [x=64.725 y=17.230 orient=1.4140], [x=65.640 y=22.416 orient=5.5109], [x=60.189 y=19.192 orient=4.4119], [x=65.640 y=22.416 orient=5.5109], [x=62.987 y=20.014 orient=2.5047], [x=66.264 y=13.297 orient=2.2057], [x=65.640 y=22.416 orient=5.5109], [x=58.783 y=27.311 orient=0.5627], [x=68.072 y=25.445 orient=3.6899], [x=60.189 y=19.192 orient=4.4119], [x=62.600 y=17.123 orient=5.6908], [x=62.600 y=17.123 orient=5.6908], [x=65.640 y=22.416 orient=5.5109], [x=72.137 y=27.087 orient=1.6225], [x=62.600 y=17.123 orient=5.6908], [x=67.160 y=27.494 orient=5.6512], [x=63.390 y=27.703 orient=3.3770], [x=60.714 y=25.287 orient=4.9028], [x=64.725 y=17.230 orient=1.4140], [x=65.640 y=22.416 orient=5.5109], [x=65.640 y=22.416 orient=5.5109], [x=62.669 y=29.136 orient=1.1942], [x=62.987 y=20.014 orient=2.5047], [x=66.264 y=13.297 orient=2.2057], [x=60.189 y=19.192 orient=4.4119], [x=69.238 y=18.692 orient=5.7303], [x=60.714 y=25.287 orient=4.9028], [x=65.640 y=22.416 orient=5.5109], [x=62.600 y=17.123 orient=5.6908], [x=60.574 y=27.893 orient=5.5351], [x=65.640 y=22.416 orient=5.5109], [x=61.410 y=27.629 orient=1.9361], [x=62.600 y=17.123 orient=5.6908], [x=58.709 y=20.893 orient=0.2426], [x=60.714 y=25.287 orient=4.9028], [x=60.714 y=25.287 orient=4.9028], [x=62.600 y=17.123 orient=5.6908], [x=68.072 y=25.445 orient=3.6899], [x=65.640 y=22.416 orient=5.5109], [x=62.987 y=20.014 orient=2.5047], [x=62.987 y=20.014 orient=2.5047], [x=60.189 y=19.192 orient=4.4119], [x=68.072 y=25.445 orient=3.6899], [x=58.709 y=20.893 orient=0.2426], [x=62.987 y=20.014 orient=2.5047], [x=63.749 y=28.510 orient=0.6105], [x=62.600 y=17.123 orient=5.6908], [x=60.189 y=19.192 orient=4.4119], [x=62.600 y=17.123 orient=5.6908], [x=58.709 y=20.893 orient=0.2426], [x=62.987 y=20.014 orient=2.5047], [x=60.174 y=22.617 orient=2.8975], [x=62.669 y=29.136 orient=1.1942], [x=62.987 y=20.014 orient=2.5047], [x=62.987 y=20.014 orient=2.5047], [x=58.709 y=20.893 orient=0.2426], [x=60.714 y=25.287 orient=4.9028], [x=63.571 y=32.633 orient=4.4861], [x=64.725 y=17.230 orient=1.4140], [x=69.238 y=18.692 orient=5.7303], [x=62.481 y=13.413 orient=1.6861], [x=62.600 y=17.123 orient=5.6908], [x=63.390 y=27.703 orient=3.3770], [x=63.749 y=28.510 orient=0.6105], [x=61.410 y=27.629 orient=1.9361], [x=68.072 y=25.445 orient=3.6899], [x=62.987 y=20.014 orient=2.5047], [x=64.786 y=31.835 orient=3.0217], [x=60.174 y=22.617 orient=2.8975], [x=65.640 y=22.416 orient=5.5109], [x=62.600 y=17.123 orient=5.6908], [x=63.283 y=14.866 orient=2.0852], [x=60.189 y=19.192 orient=4.4119], [x=60.189 y=19.192 orient=4.4119], [x=72.137 y=27.087 orient=1.6225], [x=67.160 y=27.494 orient=5.6512], [x=62.987 y=20.014 orient=2.5047], [x=67.160 y=27.494 orient=5.6512], [x=63.390 y=27.703 orient=3.3770], [x=67.160 y=27.494 orient=5.6512], [x=65.640 y=22.416 orient=5.5109], [x=60.714 y=25.287 orient=4.9028], [x=60.174 y=22.617 orient=2.8975], [x=61.410 y=27.629 orient=1.9361], [x=70.848 y=23.457 orient=4.8458], [x=65.640 y=22.416 orient=5.5109], [x=63.390 y=27.703 orient=3.3770], [x=63.390 y=27.703 orient=3.3770], [x=65.640 y=22.416 orient=5.5109], [x=65.640 y=22.416 orient=5.5109], [x=68.072 y=25.445 orient=3.6899], [x=63.390 y=27.703 orient=3.3770], [x=63.390 y=27.703 orient=3.3770], [x=63.749 y=28.510 orient=0.6105], [x=61.410 y=27.629 orient=1.9361], [x=62.892 y=16.125 orient=2.4730], [x=63.159 y=15.033 orient=0.2284], [x=62.892 y=16.125 orient=2.4730], [x=63.283 y=14.866 orient=2.0852], [x=65.640 y=22.416 orient=5.5109], [x=65.640 y=22.416 orient=5.5109], [x=65.640 y=22.416 orient=5.5109], [x=65.640 y=22.416 orient=5.5109], [x=62.600 y=17.123 orient=5.6908], [x=65.640 y=22.416 orient=5.5109], [x=61.410 y=27.629 orient=1.9361], [x=57.807 y=28.066 orient=5.1702], [x=65.640 y=22.416 orient=5.5109], [x=65.640 y=22.416 orient=5.5109], [x=60.714 y=25.287 orient=4.9028], [x=57.600 y=26.078 orient=5.5993], [x=61.410 y=27.629 orient=1.9361], [x=60.714 y=25.287 orient=4.9028], [x=60.189 y=19.192 orient=4.4119], [x=65.640 y=22.416 orient=5.5109], [x=63.749 y=28.510 orient=0.6105], [x=57.600 y=26.078 orient=5.5993], [x=62.669 y=29.136 orient=1.1942], [x=60.574 y=27.893 orient=5.5351], [x=60.174 y=22.617 orient=2.8975], [x=58.783 y=27.311 orient=0.5627], [x=60.174 y=22.617 orient=2.8975], [x=60.174 y=22.617 orient=2.8975], [x=63.283 y=14.866 orient=2.0852], [x=62.987 y=20.014 orient=2.5047], [x=55.973 y=21.065 orient=0.3253], [x=61.410 y=27.629 orient=1.9361], [x=67.160 y=27.494 orient=5.6512], [x=62.600 y=17.123 orient=5.6908], [x=63.571 y=32.633 orient=4.4861], [x=60.174 y=22.617 orient=2.8975], [x=60.174 y=22.617 orient=2.8975], [x=63.390 y=27.703 orient=3.3770], [x=62.892 y=16.125 orient=2.4730], [x=67.160 y=27.494 orient=5.6512], [x=69.238 y=18.692 orient=5.7303], [x=62.600 y=17.123 orient=5.6908], [x=72.773 y=26.174 orient=1.8237], [x=63.390 y=27.703 orient=3.3770], [x=68.072 y=25.445 orient=3.6899], [x=62.987 y=20.014 orient=2.5047], [x=62.600 y=17.123 orient=5.6908], [x=65.640 y=22.416 orient=5.5109], [x=60.189 y=19.192 orient=4.4119], [x=60.171 y=32.316 orient=1.9545], [x=60.189 y=19.192 orient=4.4119], [x=64.786 y=31.835 orient=3.0217], [x=60.189 y=19.192 orient=4.4119], [x=60.574 y=27.893 orient=5.5351], [x=60.174 y=22.617 orient=2.8975], [x=60.714 y=25.287 orient=4.9028], [x=60.174 y=22.617 orient=2.8975], [x=61.410 y=27.629 orient=1.9361], [x=62.987 y=20.014 orient=2.5047], [x=60.174 y=22.617 orient=2.8975], [x=60.174 y=22.617 orient=2.8975], [x=60.574 y=27.893 orient=5.5351], [x=62.987 y=20.014 orient=2.5047], [x=58.783 y=27.311 orient=0.5627], [x=62.987 y=20.014 orient=2.5047]]\n"
       ]
      }
     ],
     "prompt_number": 9
    },
    {
     "cell_type": "heading",
     "level": 2,
     "metadata": {},
     "source": [
      "If once is good twice is better"
     ]
    },
    {
     "cell_type": "markdown",
     "metadata": {},
     "source": [
      "Ok. If you look at your results for p above you will see that the x and y values are honing in on the true location of the robot. \n",
      "\n",
      "The one thing that is off is the orientation. Let's try to fix this by running our particle code twice."
     ]
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "myrobot = robot()\n",
      "\n",
      "N = 1000\n",
      "p = []\n",
      "\n",
      "\n",
      "print p #Leave this print statement for grading purposes!\n"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "[[x=47.492 y=42.468 orient=5.6405], [x=48.348 y=42.777 orient=5.6594], [x=45.834 y=40.981 orient=5.5410], [x=50.796 y=40.533 orient=5.5784], [x=45.104 y=41.135 orient=5.6026], [x=52.700 y=42.679 orient=5.7912], [x=44.748 y=40.904 orient=5.4589], [x=45.799 y=41.649 orient=5.4793], [x=45.799 y=41.649 orient=5.4793], [x=45.799 y=41.649 orient=5.4793], [x=49.329 y=39.471 orient=5.5911], [x=49.428 y=39.691 orient=5.6374], [x=43.951 y=40.109 orient=5.4402], [x=43.951 y=40.109 orient=5.4402], [x=45.724 y=41.047 orient=5.4656], [x=45.724 y=41.047 orient=5.4656], [x=45.526 y=41.090 orient=5.4726], [x=47.317 y=41.486 orient=5.5076], [x=44.962 y=40.253 orient=5.4470], [x=44.962 y=40.253 orient=5.4470], [x=44.892 y=40.199 orient=5.3988], [x=43.038 y=39.771 orient=5.3609], [x=49.063 y=43.042 orient=5.6244], [x=44.655 y=41.084 orient=5.5158], [x=48.724 y=42.758 orient=5.6979], [x=44.864 y=41.528 orient=5.5890], [x=45.307 y=40.096 orient=5.4307], [x=45.285 y=40.841 orient=5.5088], [x=47.534 y=43.247 orient=5.7012], [x=43.530 y=40.594 orient=5.5814], [x=45.166 y=40.188 orient=5.5103], [x=45.166 y=40.188 orient=5.5103], [x=47.349 y=41.759 orient=5.5692], [x=51.467 y=41.719 orient=5.7039], [x=43.768 y=39.941 orient=5.5139], [x=49.737 y=43.404 orient=5.6275], [x=46.174 y=42.962 orient=5.7476], [x=45.871 y=41.638 orient=5.5512], [x=45.111 y=40.430 orient=5.4303], [x=45.111 y=40.430 orient=5.4303], [x=45.111 y=40.430 orient=5.4303], [x=48.555 y=39.463 orient=5.5858], [x=45.179 y=40.461 orient=5.4248], [x=45.735 y=41.225 orient=5.6122], [x=42.992 y=39.803 orient=5.4339], [x=52.616 y=42.829 orient=5.8139], [x=44.743 y=41.044 orient=5.6407], [x=44.902 y=40.915 orient=5.5601], [x=44.902 y=40.915 orient=5.5601], [x=44.714 y=40.199 orient=5.5255], [x=44.650 y=41.643 orient=5.5838], [x=45.162 y=40.299 orient=5.5025], [x=45.115 y=41.849 orient=5.6446], [x=42.244 y=39.330 orient=5.3063], [x=45.984 y=41.173 orient=5.4976], [x=45.868 y=40.953 orient=5.5025], [x=47.890 y=41.929 orient=5.5283], [x=47.262 y=42.821 orient=5.6941], [x=51.265 y=40.866 orient=5.6357], [x=48.139 y=42.846 orient=5.7407], [x=48.139 y=42.846 orient=5.7407], [x=44.139 y=40.597 orient=5.4921], [x=47.551 y=41.474 orient=5.5251], [x=46.666 y=41.372 orient=5.6407], [x=50.275 y=40.519 orient=5.7110], [x=45.095 y=41.583 orient=5.5844], [x=43.113 y=40.649 orient=5.5295], [x=45.556 y=41.493 orient=5.5860], [x=45.556 y=41.493 orient=5.5860], [x=43.233 y=39.986 orient=5.4548], [x=49.555 y=43.196 orient=5.6113], [x=42.826 y=39.408 orient=5.4190], [x=45.142 y=40.495 orient=5.4411], [x=41.950 y=38.872 orient=5.2806], [x=43.825 y=39.470 orient=5.3592], [x=43.825 y=39.470 orient=5.3592], [x=44.576 y=40.302 orient=5.4571], [x=44.576 y=40.302 orient=5.4571], [x=46.144 y=41.518 orient=5.5276], [x=45.066 y=40.914 orient=5.4947], [x=43.331 y=40.647 orient=5.5188], [x=43.243 y=39.709 orient=5.3668], [x=45.341 y=40.983 orient=5.5067], [x=45.031 y=40.931 orient=5.5720], [x=46.420 y=41.140 orient=5.5327], [x=47.390 y=42.697 orient=5.6529], [x=47.390 y=42.697 orient=5.6529], [x=42.373 y=39.405 orient=5.3092], [x=44.469 y=40.845 orient=5.4966], [x=44.721 y=39.574 orient=5.4312], [x=44.721 y=39.574 orient=5.4312], [x=45.316 y=41.004 orient=5.5710], [x=42.837 y=39.993 orient=5.4552], [x=51.263 y=41.440 orient=5.7423], [x=46.438 y=40.863 orient=5.4944], [x=45.243 y=40.597 orient=5.4855], [x=45.429 y=41.346 orient=5.6477], [x=45.456 y=41.696 orient=5.6341], [x=45.181 y=41.393 orient=5.5523], [x=42.916 y=39.771 orient=5.3549], [x=45.241 y=41.438 orient=5.5284], [x=45.651 y=41.253 orient=5.5273], [x=42.545 y=40.073 orient=5.4751], [x=50.972 y=41.247 orient=5.7004], [x=44.370 y=39.989 orient=5.4067], [x=46.791 y=40.766 orient=5.3984], [x=48.089 y=38.669 orient=5.5148], [x=46.971 y=41.949 orient=5.5297], [x=42.646 y=39.251 orient=5.4240], [x=43.129 y=39.528 orient=5.3659], [x=43.521 y=40.067 orient=5.4576], [x=42.862 y=39.836 orient=5.3932], [x=44.909 y=40.256 orient=5.4971], [x=44.909 y=40.256 orient=5.4971], [x=49.834 y=39.596 orient=5.6141], [x=45.159 y=41.011 orient=5.4344], [x=41.718 y=38.842 orient=5.1980], [x=45.013 y=40.339 orient=5.3512], [x=49.860 y=40.487 orient=5.6852], [x=44.334 y=39.993 orient=5.2943], [x=44.579 y=40.235 orient=5.3627], [x=46.899 y=42.365 orient=5.6099], [x=45.441 y=40.497 orient=5.4011], [x=45.632 y=40.509 orient=5.4322], [x=41.552 y=39.223 orient=5.4271], [x=44.059 y=40.321 orient=5.3760], [x=45.064 y=41.169 orient=5.6460], [x=42.527 y=40.206 orient=5.5159], [x=43.217 y=39.532 orient=5.4320], [x=45.287 y=39.999 orient=5.4602], [x=43.322 y=40.664 orient=5.4935], [x=48.100 y=43.882 orient=5.7800], [x=43.454 y=40.948 orient=5.5337], [x=41.878 y=39.117 orient=5.2392], [x=44.307 y=40.073 orient=5.4039], [x=40.889 y=39.335 orient=5.4316], [x=45.266 y=41.902 orient=5.5635], [x=46.821 y=42.025 orient=5.6164], [x=43.237 y=40.236 orient=5.4472], [x=47.466 y=41.793 orient=5.6241], [x=45.457 y=40.843 orient=5.4761], [x=48.365 y=38.949 orient=5.5404], [x=48.365 y=38.949 orient=5.5404], [x=48.365 y=38.949 orient=5.5404], [x=45.483 y=40.871 orient=5.5147], [x=47.120 y=42.110 orient=5.6051], [x=46.115 y=41.333 orient=5.6335], [x=45.057 y=41.193 orient=5.5951], [x=44.268 y=40.553 orient=5.4364], [x=47.243 y=41.168 orient=5.4509], [x=41.649 y=39.116 orient=5.3938], [x=42.534 y=39.307 orient=5.3583], [x=42.534 y=39.307 orient=5.3583], [x=47.769 y=41.927 orient=5.5769], [x=44.345 y=40.616 orient=5.4760], [x=44.345 y=40.616 orient=5.4760], [x=43.877 y=40.918 orient=5.4703], [x=44.505 y=40.046 orient=5.4105], [x=50.235 y=40.036 orient=5.5980], [x=50.235 y=40.036 orient=5.5980], [x=50.235 y=40.036 orient=5.5980], [x=42.774 y=40.254 orient=5.4574], [x=42.774 y=40.254 orient=5.4574], [x=42.588 y=40.062 orient=5.4047], [x=43.261 y=40.051 orient=5.4416], [x=44.201 y=41.062 orient=5.6402], [x=44.826 y=39.915 orient=5.3446], [x=46.529 y=41.627 orient=5.5355], [x=43.297 y=39.302 orient=5.2922], [x=46.473 y=40.830 orient=5.4894], [x=47.224 y=41.837 orient=5.5950], [x=45.306 y=40.743 orient=5.5128], [x=49.306 y=42.913 orient=5.5788], [x=42.997 y=39.656 orient=5.4408], [x=45.419 y=41.450 orient=5.6008], [x=43.296 y=39.872 orient=5.4073], [x=46.791 y=42.160 orient=5.6234], [x=44.352 y=40.251 orient=5.4156], [x=44.352 y=40.251 orient=5.4156], [x=40.642 y=38.875 orient=5.3475], [x=44.634 y=41.434 orient=5.5017], [x=44.687 y=40.812 orient=5.4738], [x=44.687 y=40.812 orient=5.4738], [x=44.687 y=40.812 orient=5.4738], [x=49.514 y=39.633 orient=5.5854], [x=49.469 y=39.697 orient=5.5895], [x=44.058 y=40.243 orient=5.4799], [x=46.557 y=42.601 orient=5.6873], [x=43.508 y=40.323 orient=5.5124], [x=44.944 y=40.097 orient=5.3870], [x=44.831 y=40.477 orient=5.5001], [x=44.696 y=40.367 orient=5.4652], [x=44.989 y=40.395 orient=5.3921], [x=45.807 y=40.776 orient=5.4952], [x=42.034 y=38.994 orient=5.3072], [x=42.034 y=38.994 orient=5.3072], [x=44.459 y=40.355 orient=5.4727], [x=45.264 y=41.911 orient=5.5436], [x=44.585 y=40.734 orient=5.4801], [x=47.885 y=42.413 orient=5.6885], [x=42.229 y=39.744 orient=5.4189], [x=44.114 y=40.409 orient=5.5335], [x=47.788 y=41.558 orient=5.4866], [x=43.869 y=40.482 orient=5.4890], [x=45.276 y=39.997 orient=5.4908], [x=46.845 y=37.949 orient=5.3838], [x=42.319 y=39.212 orient=5.4021], [x=44.800 y=40.052 orient=5.4398], [x=43.711 y=39.221 orient=5.3444], [x=43.408 y=40.042 orient=5.4514], [x=43.923 y=40.765 orient=5.5726], [x=41.790 y=39.758 orient=5.4491], [x=43.588 y=39.991 orient=5.4283], [x=46.681 y=41.733 orient=5.4941], [x=43.192 y=40.623 orient=5.4798], [x=43.503 y=39.205 orient=5.3196], [x=44.867 y=40.581 orient=5.4790], [x=44.867 y=40.581 orient=5.4790], [x=49.186 y=39.777 orient=5.6456], [x=49.186 y=39.777 orient=5.6456], [x=44.668 y=40.107 orient=5.4069], [x=49.381 y=43.074 orient=5.5973], [x=46.328 y=41.042 orient=5.3664], [x=45.435 y=41.183 orient=5.5482], [x=46.138 y=41.012 orient=5.4554], [x=44.462 y=40.654 orient=5.5579], [x=44.341 y=40.780 orient=5.5607], [x=45.759 y=40.636 orient=5.3969], [x=45.759 y=40.636 orient=5.3969], [x=50.056 y=39.957 orient=5.6306], [x=49.538 y=39.576 orient=5.5156], [x=43.842 y=40.628 orient=5.5248], [x=51.154 y=41.580 orient=5.7671], [x=43.593 y=40.863 orient=5.6228], [x=44.669 y=41.120 orient=5.5230], [x=44.645 y=41.236 orient=5.5366], [x=43.908 y=40.237 orient=5.4560], [x=42.337 y=39.575 orient=5.4397], [x=44.774 y=40.634 orient=5.3793], [x=45.286 y=41.028 orient=5.5371], [x=45.420 y=41.211 orient=5.4720], [x=45.011 y=41.934 orient=5.5999], [x=46.129 y=41.541 orient=5.5059], [x=50.282 y=40.390 orient=5.6343], [x=50.282 y=40.390 orient=5.6343], [x=45.109 y=40.826 orient=5.4870], [x=44.915 y=41.084 orient=5.4967], [x=41.639 y=39.598 orient=5.5151], [x=42.654 y=40.138 orient=5.4847], [x=44.918 y=41.075 orient=5.5700], [x=43.592 y=39.645 orient=5.3882], [x=49.653 y=39.352 orient=5.5506], [x=46.328 y=42.099 orient=5.6167], [x=43.446 y=39.535 orient=5.4352], [x=48.671 y=42.911 orient=5.6375], [x=45.949 y=41.760 orient=5.5991], [x=46.043 y=41.787 orient=5.6152], [x=46.043 y=41.787 orient=5.6152], [x=45.797 y=41.418 orient=5.5560], [x=45.818 y=40.861 orient=5.5124], [x=45.818 y=40.861 orient=5.5124], [x=45.039 y=40.293 orient=5.4334], [x=43.737 y=39.956 orient=5.4603], [x=43.447 y=40.420 orient=5.4833], [x=43.447 y=40.420 orient=5.4833], [x=44.876 y=41.273 orient=5.5736], [x=48.731 y=42.826 orient=5.7099], [x=45.608 y=40.333 orient=5.5076], [x=41.671 y=39.291 orient=5.4080], [x=41.671 y=39.291 orient=5.4080], [x=44.798 y=40.466 orient=5.4387], [x=44.798 y=40.466 orient=5.4387], [x=41.946 y=38.871 orient=5.3440], [x=43.284 y=40.660 orient=5.4719], [x=44.874 y=40.948 orient=5.5131], [x=43.242 y=40.077 orient=5.4546], [x=44.638 y=40.236 orient=5.4541], [x=44.748 y=41.206 orient=5.5547], [x=51.240 y=40.902 orient=5.6464], [x=44.725 y=40.654 orient=5.5042], [x=45.209 y=40.977 orient=5.4401], [x=46.018 y=40.776 orient=5.4980], [x=47.187 y=41.870 orient=5.5060], [x=45.869 y=41.736 orient=5.5983], [x=45.869 y=41.736 orient=5.5983], [x=45.942 y=41.256 orient=5.5442], [x=46.955 y=41.839 orient=5.5416], [x=45.028 y=40.264 orient=5.4153], [x=41.586 y=39.013 orient=5.3652], [x=42.840 y=39.469 orient=5.3391], [x=44.250 y=40.613 orient=5.5107], [x=45.885 y=40.787 orient=5.4474], [x=43.110 y=40.174 orient=5.4355], [x=46.595 y=42.429 orient=5.6374], [x=44.535 y=41.291 orient=5.5848], [x=44.926 y=40.112 orient=5.4430], [x=44.926 y=40.112 orient=5.4430], [x=50.557 y=40.739 orient=5.7524], [x=45.544 y=41.638 orient=5.6452], [x=42.529 y=39.682 orient=5.3937], [x=46.140 y=41.386 orient=5.5546], [x=46.107 y=41.234 orient=5.5759], [x=46.715 y=42.631 orient=5.6677], [x=43.611 y=39.274 orient=5.3155], [x=44.591 y=40.719 orient=5.4863], [x=44.741 y=40.455 orient=5.5147], [x=44.741 y=40.455 orient=5.5147], [x=43.969 y=40.378 orient=5.4083], [x=44.555 y=40.707 orient=5.4991], [x=42.804 y=40.398 orient=5.5151], [x=46.124 y=40.922 orient=5.4411], [x=46.587 y=41.199 orient=5.6040], [x=46.587 y=41.199 orient=5.6040], [x=43.077 y=40.572 orient=5.5835], [x=47.871 y=42.318 orient=5.5613], [x=47.576 y=38.375 orient=5.5223], [x=47.576 y=38.375 orient=5.5223], [x=47.337 y=38.211 orient=5.4659], [x=43.784 y=40.651 orient=5.5860], [x=52.260 y=42.718 orient=5.7143], [x=46.697 y=41.675 orient=5.5862], [x=43.642 y=40.297 orient=5.5288], [x=42.983 y=39.487 orient=5.4267], [x=44.665 y=40.972 orient=5.5580], [x=44.233 y=39.656 orient=5.4457], [x=44.233 y=39.656 orient=5.4457], [x=44.766 y=40.339 orient=5.4897], [x=44.766 y=40.339 orient=5.4897], [x=43.907 y=40.886 orient=5.4476], [x=48.663 y=39.442 orient=5.5752], [x=44.896 y=41.000 orient=5.4826], [x=46.333 y=41.577 orient=5.6159], [x=46.209 y=41.847 orient=5.5364], [x=46.209 y=41.847 orient=5.5364], [x=45.555 y=41.313 orient=5.5844], [x=45.086 y=41.063 orient=5.5121], [x=44.296 y=40.288 orient=5.4683], [x=44.296 y=40.288 orient=5.4683], [x=44.296 y=40.288 orient=5.4683], [x=44.555 y=40.537 orient=5.4502], [x=47.303 y=42.574 orient=5.6228], [x=42.909 y=39.636 orient=5.3845], [x=43.752 y=40.201 orient=5.4039], [x=50.531 y=40.760 orient=5.7099], [x=46.652 y=40.938 orient=5.4799], [x=42.635 y=40.421 orient=5.4807], [x=46.380 y=40.917 orient=5.4937], [x=46.750 y=41.394 orient=5.5529], [x=46.750 y=41.394 orient=5.5529], [x=44.941 y=40.280 orient=5.3984], [x=44.941 y=40.280 orient=5.3984], [x=45.733 y=41.618 orient=5.5927], [x=45.074 y=41.094 orient=5.5644], [x=44.351 y=40.392 orient=5.4873], [x=51.554 y=41.289 orient=5.6930], [x=51.531 y=41.155 orient=5.6685], [x=45.682 y=41.526 orient=5.5249], [x=46.231 y=41.524 orient=5.5543], [x=41.263 y=38.956 orient=5.3650], [x=42.400 y=40.063 orient=5.5343], [x=46.657 y=40.642 orient=5.3621], [x=45.082 y=41.814 orient=5.6467], [x=45.082 y=41.814 orient=5.6467], [x=45.244 y=41.069 orient=5.4456], [x=45.244 y=41.069 orient=5.4456], [x=43.766 y=40.334 orient=5.5291], [x=43.751 y=40.474 orient=5.5475], [x=46.985 y=41.200 orient=5.5354], [x=46.035 y=41.469 orient=5.5714], [x=46.140 y=41.575 orient=5.6013], [x=46.104 y=41.451 orient=5.5776], [x=44.991 y=40.237 orient=5.5060], [x=49.597 y=39.571 orient=5.5801], [x=43.112 y=40.008 orient=5.4833], [x=45.107 y=40.410 orient=5.3747], [x=46.450 y=42.292 orient=5.6679], [x=42.490 y=40.040 orient=5.4754], [x=46.095 y=41.081 orient=5.6070], [x=45.513 y=40.347 orient=5.3934], [x=44.459 y=40.094 orient=5.3425], [x=44.459 y=40.094 orient=5.3425], [x=48.195 y=42.107 orient=5.5573], [x=45.022 y=41.107 orient=5.6011], [x=45.022 y=41.107 orient=5.6011], [x=46.256 y=41.950 orient=5.5487], [x=45.173 y=39.984 orient=5.4877], [x=45.106 y=39.988 orient=5.4787], [x=44.536 y=41.334 orient=5.5645], [x=44.536 y=41.334 orient=5.5645], [x=43.058 y=40.505 orient=5.4155], [x=41.892 y=38.777 orient=5.2671], [x=41.892 y=38.777 orient=5.2671], [x=43.365 y=39.726 orient=5.4107], [x=44.916 y=40.011 orient=5.3628], [x=44.907 y=40.004 orient=5.3740], [x=44.907 y=40.004 orient=5.3740], [x=47.267 y=42.676 orient=5.7754], [x=46.957 y=42.111 orient=5.6467], [x=47.575 y=42.039 orient=5.6766], [x=45.857 y=41.429 orient=5.5558], [x=45.483 y=40.797 orient=5.4736], [x=45.243 y=40.718 orient=5.4585], [x=46.378 y=41.787 orient=5.6380], [x=42.339 y=39.275 orient=5.3238], [x=47.260 y=41.792 orient=5.5990], [x=47.260 y=41.792 orient=5.5990], [x=47.260 y=41.792 orient=5.5990], [x=45.148 y=41.251 orient=5.6156], [x=43.785 y=40.541 orient=5.5305], [x=44.651 y=40.402 orient=5.4815], [x=47.779 y=41.916 orient=5.5767], [x=47.779 y=41.916 orient=5.5767], [x=47.779 y=41.916 orient=5.5767], [x=44.495 y=39.638 orient=5.3945], [x=43.565 y=40.299 orient=5.3502], [x=44.388 y=39.991 orient=5.3854], [x=42.403 y=39.290 orient=5.4152], [x=44.228 y=39.784 orient=5.3882], [x=45.267 y=41.141 orient=5.5909], [x=45.267 y=41.141 orient=5.5909], [x=44.379 y=40.512 orient=5.4765], [x=44.935 y=39.941 orient=5.3651], [x=43.791 y=39.989 orient=5.3395], [x=43.791 y=39.989 orient=5.3395], [x=43.659 y=40.279 orient=5.4746], [x=43.659 y=40.279 orient=5.4746], [x=43.129 y=40.401 orient=5.4402], [x=47.367 y=41.850 orient=5.6148], [x=45.092 y=40.658 orient=5.4699], [x=45.394 y=40.723 orient=5.4230], [x=45.090 y=41.136 orient=5.5103], [x=45.090 y=41.136 orient=5.5103], [x=43.678 y=40.263 orient=5.5061], [x=52.246 y=41.669 orient=5.5748], [x=46.659 y=41.337 orient=5.5707], [x=44.929 y=40.279 orient=5.3927], [x=44.114 y=40.256 orient=5.4460], [x=44.483 y=41.291 orient=5.5459], [x=44.483 y=41.291 orient=5.5459], [x=44.958 y=41.019 orient=5.5409], [x=44.958 y=41.019 orient=5.5409], [x=42.363 y=39.954 orient=5.5184], [x=43.021 y=39.307 orient=5.3472], [x=44.794 y=41.362 orient=5.6206], [x=44.222 y=40.587 orient=5.5339], [x=44.658 y=39.969 orient=5.3263], [x=45.763 y=40.820 orient=5.5242], [x=45.523 y=40.589 orient=5.4580], [x=44.831 y=40.493 orient=5.5023], [x=45.903 y=41.024 orient=5.5441], [x=45.991 y=41.101 orient=5.5509], [x=45.991 y=41.101 orient=5.5509], [x=44.226 y=39.542 orient=5.4465], [x=44.226 y=39.542 orient=5.4465], [x=44.601 y=40.883 orient=5.5178], [x=44.652 y=40.633 orient=5.5397], [x=44.652 y=40.633 orient=5.5397], [x=44.652 y=40.633 orient=5.5397], [x=46.877 y=43.114 orient=5.7339], [x=46.739 y=42.992 orient=5.6990], [x=44.559 y=40.704 orient=5.4724], [x=47.588 y=42.167 orient=5.6285], [x=42.859 y=40.256 orient=5.5002], [x=47.042 y=41.944 orient=5.5871], [x=43.817 y=40.442 orient=5.4759], [x=46.012 y=40.632 orient=5.5221], [x=44.911 y=39.798 orient=5.4104], [x=43.571 y=40.450 orient=5.4837], [x=47.162 y=38.050 orient=5.4457], [x=47.162 y=38.050 orient=5.4457], [x=45.650 y=41.274 orient=5.6195], [x=45.650 y=41.274 orient=5.6195], [x=43.632 y=41.057 orient=5.4825], [x=43.622 y=40.875 orient=5.4406], [x=50.920 y=40.944 orient=5.6688], [x=42.073 y=39.105 orient=5.3276], [x=42.331 y=39.302 orient=5.3918], [x=43.248 y=39.642 orient=5.4764], [x=45.248 y=41.445 orient=5.6015], [x=49.309 y=40.112 orient=5.7107], [x=49.309 y=40.112 orient=5.7107], [x=45.407 y=41.210 orient=5.4951], [x=45.407 y=41.210 orient=5.4951], [x=45.407 y=41.210 orient=5.4951], [x=48.108 y=42.306 orient=5.5830], [x=46.297 y=41.647 orient=5.5721], [x=44.211 y=40.142 orient=5.4753], [x=44.212 y=40.198 orient=5.4323], [x=44.212 y=40.198 orient=5.4323], [x=45.730 y=42.477 orient=5.6880], [x=40.384 y=39.089 orient=5.3691], [x=44.279 y=40.504 orient=5.5118], [x=45.927 y=40.827 orient=5.4470], [x=42.474 y=39.152 orient=5.3436], [x=42.474 y=39.152 orient=5.3436], [x=44.203 y=41.018 orient=5.6022], [x=50.077 y=40.077 orient=5.6523], [x=43.646 y=40.653 orient=5.5008], [x=44.959 y=40.439 orient=5.5125], [x=44.959 y=40.439 orient=5.5125], [x=44.959 y=40.439 orient=5.5125], [x=51.633 y=41.984 orient=5.7396], [x=44.892 y=40.981 orient=5.5232], [x=42.425 y=39.632 orient=5.4605], [x=44.095 y=39.633 orient=5.3738], [x=45.090 y=42.062 orient=5.6298], [x=46.198 y=41.636 orient=5.5293], [x=47.833 y=38.540 orient=5.4791], [x=47.492 y=42.468 orient=5.6405], [x=45.515 y=40.516 orient=5.4299], [x=45.834 y=40.981 orient=5.5410], [x=43.137 y=40.086 orient=5.4679], [x=44.527 y=40.648 orient=5.5306], [x=42.201 y=39.418 orient=5.4118], [x=42.201 y=39.418 orient=5.4118], [x=46.173 y=41.919 orient=5.5698], [x=46.173 y=41.919 orient=5.5698], [x=49.305 y=39.533 orient=5.5975], [x=49.428 y=39.691 orient=5.6374], [x=46.363 y=41.202 orient=5.5008], [x=45.010 y=41.979 orient=5.6894], [x=45.554 y=41.380 orient=5.5174], [x=45.535 y=41.208 orient=5.4900], [x=42.280 y=41.175 orient=5.6597], [x=42.280 y=41.175 orient=5.6597], [x=44.962 y=40.253 orient=5.4470], [x=43.038 y=39.771 orient=5.3609], [x=49.063 y=43.042 orient=5.6244], [x=49.413 y=43.402 orient=5.7236], [x=44.203 y=40.430 orient=5.4672], [x=44.655 y=41.084 orient=5.5158], [x=48.724 y=42.758 orient=5.6979], [x=44.864 y=41.528 orient=5.5890], [x=45.285 y=40.841 orient=5.5088], [x=43.530 y=40.594 orient=5.5814], [x=45.250 y=40.213 orient=5.5413], [x=45.166 y=40.188 orient=5.5103], [x=42.922 y=39.686 orient=5.3817], [x=47.349 y=41.759 orient=5.5692], [x=47.349 y=41.759 orient=5.5692], [x=43.511 y=39.717 orient=5.4464], [x=45.132 y=41.450 orient=5.6412], [x=49.737 y=43.404 orient=5.6275], [x=45.361 y=41.810 orient=5.5038], [x=45.838 y=41.334 orient=5.5796], [x=46.019 y=40.870 orient=5.5115], [x=45.111 y=40.430 orient=5.4303], [x=47.098 y=41.907 orient=5.4986], [x=48.922 y=39.697 orient=5.6686], [x=48.555 y=39.463 orient=5.5858], [x=45.603 y=41.380 orient=5.5091], [x=45.603 y=41.380 orient=5.5091], [x=45.735 y=41.225 orient=5.6122], [x=45.486 y=40.792 orient=5.5550], [x=46.034 y=40.891 orient=5.4834], [x=44.902 y=40.915 orient=5.5601], [x=44.714 y=40.199 orient=5.5255], [x=45.162 y=40.299 orient=5.5025], [x=45.162 y=40.299 orient=5.5025], [x=47.223 y=42.783 orient=5.7017], [x=42.894 y=38.711 orient=5.2932], [x=45.887 y=41.039 orient=5.4657], [x=45.984 y=41.173 orient=5.4976], [x=45.868 y=40.953 orient=5.5025], [x=45.868 y=40.953 orient=5.5025], [x=45.868 y=40.953 orient=5.5025], [x=47.890 y=41.929 orient=5.5283], [x=47.809 y=41.880 orient=5.5102], [x=46.450 y=42.138 orient=5.5973], [x=46.450 y=42.138 orient=5.5973], [x=45.274 y=41.748 orient=5.5290], [x=46.982 y=41.312 orient=5.4849], [x=42.430 y=39.775 orient=5.4091], [x=46.666 y=41.372 orient=5.6407], [x=46.666 y=41.372 orient=5.6407], [x=50.275 y=40.519 orient=5.7110], [x=45.095 y=41.583 orient=5.5844], [x=44.332 y=39.930 orient=5.3788], [x=43.113 y=40.649 orient=5.5295], [x=45.556 y=41.493 orient=5.5860], [x=41.498 y=39.662 orient=5.4121], [x=42.826 y=39.408 orient=5.4190], [x=45.142 y=40.495 orient=5.4411], [x=43.186 y=40.432 orient=5.5004], [x=46.021 y=41.406 orient=5.5349], [x=44.293 y=41.118 orient=5.5357], [x=46.144 y=41.518 orient=5.5276], [x=44.552 y=40.615 orient=5.3794], [x=45.985 y=41.332 orient=5.5336], [x=42.374 y=39.159 orient=5.4461], [x=45.341 y=40.983 orient=5.5067], [x=46.420 y=41.140 orient=5.5327], [x=44.469 y=40.845 orient=5.4966], [x=44.721 y=39.574 orient=5.4312], [x=44.777 y=39.469 orient=5.4259], [x=45.316 y=41.004 orient=5.5710], [x=46.735 y=41.066 orient=5.5098], [x=42.837 y=39.993 orient=5.4552], [x=41.620 y=40.037 orient=5.4859], [x=46.438 y=40.863 orient=5.4944], [x=46.438 y=40.863 orient=5.4944], [x=45.243 y=40.597 orient=5.4855], [x=45.429 y=41.346 orient=5.6477], [x=45.429 y=41.346 orient=5.6477], [x=45.456 y=41.696 orient=5.6341], [x=51.600 y=41.163 orient=5.6776], [x=45.241 y=41.438 orient=5.5284], [x=45.651 y=41.253 orient=5.5273], [x=45.932 y=41.595 orient=5.5892], [x=45.932 y=41.595 orient=5.5892], [x=45.932 y=41.595 orient=5.5892], [x=42.320 y=38.863 orient=5.3477], [x=44.370 y=39.989 orient=5.4067], [x=42.404 y=40.050 orient=5.5329], [x=48.089 y=38.669 orient=5.5148], [x=46.971 y=41.949 orient=5.5297], [x=43.129 y=39.528 orient=5.3659], [x=47.536 y=41.657 orient=5.6747], [x=45.866 y=41.437 orient=5.5589], [x=45.866 y=41.437 orient=5.5589], [x=45.866 y=41.437 orient=5.5589], [x=44.771 y=40.144 orient=5.4612], [x=49.834 y=39.596 orient=5.6141], [x=45.159 y=41.011 orient=5.4344], [x=41.718 y=38.842 orient=5.1980], [x=42.893 y=39.928 orient=5.3800], [x=49.860 y=40.487 orient=5.6852], [x=50.546 y=41.093 orient=5.7654], [x=44.802 y=40.383 orient=5.4165], [x=43.101 y=38.731 orient=5.2959], [x=45.035 y=40.443 orient=5.4667], [x=45.035 y=40.443 orient=5.4667], [x=46.899 y=42.365 orient=5.6099], [x=45.441 y=40.497 orient=5.4011], [x=45.903 y=40.745 orient=5.5037], [x=45.632 y=40.509 orient=5.4322], [x=41.552 y=39.223 orient=5.4271], [x=44.719 y=41.234 orient=5.5346], [x=42.527 y=40.206 orient=5.5159], [x=45.297 y=40.540 orient=5.5189], [x=48.343 y=42.315 orient=5.6082], [x=43.217 y=39.532 orient=5.4320], [x=43.217 y=39.532 orient=5.4320], [x=43.712 y=40.802 orient=5.4079], [x=45.205 y=39.932 orient=5.4393], [x=43.322 y=40.664 orient=5.4935], [x=44.418 y=40.719 orient=5.5288], [x=44.385 y=40.978 orient=5.4921], [x=51.217 y=41.216 orient=5.7073], [x=43.267 y=40.790 orient=5.4848], [x=41.878 y=39.117 orient=5.2392], [x=43.074 y=40.528 orient=5.5638], [x=51.981 y=41.532 orient=5.7112], [x=45.266 y=41.902 orient=5.5635], [x=40.769 y=39.375 orient=5.4000], [x=43.237 y=40.236 orient=5.4472], [x=42.391 y=39.206 orient=5.4277], [x=47.466 y=41.793 orient=5.6241], [x=47.466 y=41.793 orient=5.6241], [x=45.895 y=41.212 orient=5.5664], [x=45.457 y=40.843 orient=5.4761], [x=45.457 y=40.843 orient=5.4761], [x=45.483 y=40.871 orient=5.5147], [x=46.363 y=41.595 orient=5.6092], [x=45.074 y=40.430 orient=5.4407], [x=45.057 y=41.193 orient=5.5951], [x=44.268 y=40.553 orient=5.4364], [x=53.686 y=42.981 orient=5.7702], [x=42.534 y=39.307 orient=5.3583], [x=43.257 y=40.222 orient=5.5099], [x=44.494 y=39.677 orient=5.3994], [x=43.877 y=40.918 orient=5.4703], [x=45.335 y=40.756 orient=5.5029], [x=44.505 y=40.046 orient=5.4105], [x=50.235 y=40.036 orient=5.5980], [x=50.065 y=39.992 orient=5.5695], [x=44.544 y=40.035 orient=5.4690], [x=43.261 y=40.051 orient=5.4416], [x=44.062 y=40.265 orient=5.4935], [x=44.093 y=40.249 orient=5.4956], [x=41.599 y=39.173 orient=5.3726], [x=44.826 y=39.915 orient=5.3446], [x=46.529 y=41.627 orient=5.5355], [x=43.590 y=40.841 orient=5.4864], [x=46.473 y=40.830 orient=5.4894], [x=47.224 y=41.837 orient=5.5950], [x=43.288 y=40.133 orient=5.4119], [x=46.023 y=41.985 orient=5.7048], [x=46.023 y=41.985 orient=5.7048], [x=45.513 y=41.628 orient=5.6404], [x=43.296 y=39.872 orient=5.4073], [x=43.296 y=39.872 orient=5.4073], [x=46.791 y=42.160 orient=5.6234], [x=46.507 y=41.280 orient=5.5420], [x=44.887 y=40.360 orient=5.3964], [x=44.683 y=41.385 orient=5.5016], [x=44.683 y=41.385 orient=5.5016], [x=44.683 y=41.385 orient=5.5016], [x=44.710 y=40.882 orient=5.4868], [x=44.687 y=40.812 orient=5.4738], [x=49.691 y=39.953 orient=5.6576], [x=49.514 y=39.633 orient=5.5854], [x=49.514 y=39.633 orient=5.5854], [x=44.058 y=40.243 orient=5.4799], [x=44.784 y=39.959 orient=5.4891], [x=44.784 y=39.959 orient=5.4891], [x=44.784 y=39.959 orient=5.4891], [x=46.557 y=42.601 orient=5.6873], [x=46.557 y=42.601 orient=5.6873], [x=44.944 y=40.097 orient=5.3870], [x=44.944 y=40.097 orient=5.3870], [x=44.696 y=40.367 orient=5.4652], [x=44.989 y=40.395 orient=5.3921], [x=44.439 y=39.467 orient=5.4675], [x=48.729 y=42.538 orient=5.5658], [x=48.729 y=42.538 orient=5.5658], [x=44.459 y=40.355 orient=5.4727], [x=44.459 y=40.355 orient=5.4727], [x=45.264 y=41.911 orient=5.5436], [x=46.458 y=42.737 orient=5.6249], [x=47.885 y=42.413 orient=5.6885], [x=46.996 y=41.326 orient=5.4729], [x=47.614 y=41.980 orient=5.6025], [x=46.710 y=41.516 orient=5.4781], [x=44.114 y=40.409 orient=5.5335], [x=44.114 y=40.409 orient=5.5335], [x=46.057 y=40.736 orient=5.4062], [x=43.869 y=40.482 orient=5.4890], [x=43.467 y=40.286 orient=5.4111], [x=45.276 y=39.997 orient=5.4908], [x=42.723 y=39.777 orient=5.4533], [x=46.845 y=37.949 orient=5.3838], [x=46.845 y=37.949 orient=5.3838], [x=46.439 y=42.158 orient=5.5262], [x=44.800 y=40.052 orient=5.4398], [x=43.046 y=38.939 orient=5.3168], [x=43.408 y=40.042 orient=5.4514], [x=43.923 y=40.765 orient=5.5726], [x=43.588 y=39.991 orient=5.4283], [x=43.318 y=39.909 orient=5.4543], [x=46.681 y=41.733 orient=5.4941], [x=45.636 y=41.191 orient=5.4880], [x=45.812 y=42.246 orient=5.6953], [x=43.931 y=39.403 orient=5.4110], [x=44.867 y=40.581 orient=5.4790], [x=49.019 y=39.758 orient=5.6185], [x=49.186 y=39.777 orient=5.6456], [x=49.186 y=39.777 orient=5.6456], [x=42.847 y=39.423 orient=5.3039], [x=42.048 y=39.446 orient=5.4179], [x=49.381 y=43.074 orient=5.5973], [x=45.940 y=40.954 orient=5.5590], [x=45.435 y=41.183 orient=5.5482], [x=46.138 y=41.012 orient=5.4554], [x=46.138 y=41.012 orient=5.4554], [x=46.138 y=41.012 orient=5.4554], [x=44.462 y=40.654 orient=5.5579], [x=44.341 y=40.780 orient=5.5607], [x=41.521 y=39.960 orient=5.4977], [x=50.056 y=39.957 orient=5.6306], [x=48.083 y=42.019 orient=5.5163], [x=51.154 y=41.580 orient=5.7671], [x=45.989 y=40.612 orient=5.4613], [x=45.989 y=40.612 orient=5.4613], [x=44.645 y=41.236 orient=5.5366], [x=44.233 y=40.350 orient=5.4936], [x=45.761 y=41.448 orient=5.5584], [x=44.774 y=40.634 orient=5.3793], [x=42.850 y=39.599 orient=5.3606], [x=42.891 y=39.635 orient=5.3715], [x=42.954 y=40.414 orient=5.4377], [x=45.487 y=41.183 orient=5.4778], [x=45.487 y=41.183 orient=5.4778], [x=47.683 y=41.470 orient=5.5837], [x=46.129 y=41.541 orient=5.5059], [x=46.751 y=42.041 orient=5.5962], [x=48.170 y=38.783 orient=5.5314], [x=44.915 y=41.084 orient=5.4967], [x=43.238 y=39.942 orient=5.4991], [x=50.914 y=40.696 orient=5.6185], [x=44.918 y=41.075 orient=5.5700], [x=43.592 y=39.645 orient=5.3882], [x=49.648 y=39.442 orient=5.5634], [x=49.653 y=39.352 orient=5.5506], [x=43.446 y=39.535 orient=5.4352], [x=43.202 y=39.441 orient=5.3863], [x=43.202 y=39.441 orient=5.3863], [x=46.032 y=41.353 orient=5.5523], [x=45.949 y=41.760 orient=5.5991], [x=45.797 y=41.418 orient=5.5560], [x=42.060 y=40.451 orient=5.5458], [x=45.039 y=40.293 orient=5.4334], [x=43.491 y=40.035 orient=5.4648], [x=43.536 y=40.208 orient=5.4955], [x=43.737 y=39.956 orient=5.4603], [x=43.447 y=40.420 orient=5.4833], [x=44.876 y=41.273 orient=5.5736], [x=48.731 y=42.826 orient=5.7099], [x=42.905 y=39.880 orient=5.4252], [x=45.369 y=40.904 orient=5.5295], [x=44.820 y=40.029 orient=5.4373], [x=45.132 y=40.109 orient=5.4943], [x=44.798 y=40.466 orient=5.4387], [x=44.874 y=40.948 orient=5.5131], [x=44.874 y=40.948 orient=5.5131], [x=44.638 y=40.236 orient=5.4541], [x=44.748 y=41.206 orient=5.5547], [x=43.608 y=39.968 orient=5.3120], [x=44.725 y=40.654 orient=5.5042], [x=45.209 y=40.977 orient=5.4401], [x=45.209 y=40.977 orient=5.4401], [x=46.018 y=40.776 orient=5.4980], [x=45.909 y=40.759 orient=5.4802], [x=48.766 y=39.494 orient=5.6175], [x=45.601 y=41.267 orient=5.4929], [x=45.942 y=41.256 orient=5.5442], [x=46.955 y=41.839 orient=5.5416], [x=45.028 y=40.264 orient=5.4153], [x=46.933 y=41.433 orient=5.5129], [x=44.250 y=40.613 orient=5.5107], [x=45.885 y=40.787 orient=5.4474], [x=44.921 y=40.972 orient=5.5711], [x=44.308 y=39.579 orient=5.3826], [x=44.308 y=39.579 orient=5.3826], [x=44.535 y=41.291 orient=5.5848], [x=44.926 y=40.112 orient=5.4430], [x=43.433 y=39.772 orient=5.4881], [x=44.815 y=40.058 orient=5.5025], [x=44.141 y=40.980 orient=5.5124], [x=46.140 y=41.386 orient=5.5546], [x=47.979 y=42.091 orient=5.5644], [x=46.715 y=42.631 orient=5.6677], [x=43.611 y=39.274 orient=5.3155], [x=44.591 y=40.719 orient=5.4863], [x=44.741 y=40.455 orient=5.5147], [x=43.969 y=40.378 orient=5.4083], [x=47.789 y=42.268 orient=5.6055], [x=43.962 y=40.405 orient=5.4398], [x=43.962 y=40.405 orient=5.4398], [x=42.291 y=39.631 orient=5.3692], [x=47.155 y=41.086 orient=5.4143], [x=43.540 y=40.220 orient=5.4146], [x=46.587 y=41.199 orient=5.6040], [x=48.619 y=42.688 orient=5.5849], [x=47.576 y=38.375 orient=5.5223], [x=47.277 y=38.268 orient=5.4649], [x=47.337 y=38.211 orient=5.4659], [x=45.467 y=41.407 orient=5.5614], [x=40.605 y=39.173 orient=5.3166], [x=42.935 y=39.530 orient=5.3588], [x=46.781 y=42.950 orient=5.7991], [x=45.609 y=41.367 orient=5.4894], [x=46.697 y=41.675 orient=5.5862], [x=42.983 y=39.487 orient=5.4267], [x=44.233 y=39.656 orient=5.4457], [x=43.907 y=40.886 orient=5.4476], [x=48.663 y=39.442 orient=5.5752], [x=44.163 y=40.875 orient=5.5321], [x=46.333 y=41.577 orient=5.6159], [x=43.042 y=39.968 orient=5.4509], [x=44.296 y=40.288 orient=5.4683], [x=44.296 y=40.288 orient=5.4683], [x=44.296 y=40.288 orient=5.4683], [x=44.555 y=40.537 orient=5.4502], [x=46.122 y=40.859 orient=5.4507], [x=47.303 y=42.574 orient=5.6228], [x=42.909 y=39.636 orient=5.3845], [x=43.752 y=40.201 orient=5.4039], [x=43.752 y=40.201 orient=5.4039], [x=41.357 y=38.842 orient=5.2958], [x=44.768 y=39.546 orient=5.4346], [x=44.818 y=40.445 orient=5.4224], [x=44.818 y=40.445 orient=5.4224], [x=46.652 y=40.938 orient=5.4799], [x=45.306 y=40.371 orient=5.5274], [x=42.635 y=40.421 orient=5.4807], [x=46.380 y=40.917 orient=5.4937], [x=46.380 y=40.917 orient=5.4937], [x=46.380 y=40.917 orient=5.4937], [x=46.380 y=40.917 orient=5.4937], [x=46.750 y=41.394 orient=5.5529], [x=45.733 y=41.618 orient=5.5927], [x=45.074 y=41.094 orient=5.5644], [x=41.619 y=39.709 orient=5.4657], [x=44.105 y=40.172 orient=5.4494], [x=53.322 y=43.069 orient=5.7433], [x=50.864 y=40.932 orient=5.6360], [x=41.263 y=38.956 orient=5.3650], [x=44.033 y=39.724 orient=5.3644], [x=42.400 y=40.063 orient=5.5343], [x=45.082 y=41.814 orient=5.6467], [x=47.966 y=38.521 orient=5.4768], [x=45.244 y=41.069 orient=5.4456], [x=45.244 y=41.069 orient=5.4456], [x=42.651 y=39.394 orient=5.3746], [x=43.336 y=39.719 orient=5.4218], [x=43.751 y=40.474 orient=5.5475], [x=42.632 y=39.892 orient=5.3705], [x=46.140 y=41.575 orient=5.6013], [x=46.140 y=41.575 orient=5.6013], [x=53.121 y=42.972 orient=5.8264], [x=42.294 y=39.242 orient=5.3375], [x=45.107 y=40.410 orient=5.3747], [x=49.556 y=40.163 orient=5.5957], [x=49.556 y=40.163 orient=5.5957], [x=42.010 y=40.695 orient=5.5583], [x=45.513 y=40.347 orient=5.3934], [x=41.264 y=38.900 orient=5.3409], [x=45.663 y=40.890 orient=5.4761], [x=43.566 y=39.783 orient=5.5167], [x=45.022 y=41.107 orient=5.6011], [x=45.022 y=41.107 orient=5.6011], [x=46.647 y=42.043 orient=5.5523], [x=45.173 y=39.984 orient=5.4877], [x=44.536 y=41.334 orient=5.5645], [x=43.058 y=40.505 orient=5.4155], [x=43.255 y=40.657 orient=5.4647], [x=43.365 y=39.726 orient=5.4107], [x=44.844 y=41.193 orient=5.5553], [x=44.916 y=40.011 orient=5.3628], [x=44.916 y=40.011 orient=5.3628], [x=44.907 y=40.004 orient=5.3740], [x=44.783 y=40.024 orient=5.3569], [x=46.957 y=42.111 orient=5.6467], [x=44.114 y=39.715 orient=5.4322], [x=45.723 y=41.118 orient=5.5295], [x=45.636 y=41.020 orient=5.5032], [x=48.697 y=39.435 orient=5.6572], [x=48.697 y=39.435 orient=5.6572], [x=46.378 y=41.787 orient=5.6380], [x=42.730 y=39.670 orient=5.4350], [x=46.670 y=41.393 orient=5.4612], [x=47.260 y=41.792 orient=5.5990], [x=52.794 y=42.868 orient=5.8411], [x=43.785 y=40.541 orient=5.5305], [x=43.785 y=40.541 orient=5.5305], [x=42.743 y=39.560 orient=5.4219], [x=47.560 y=41.663 orient=5.5098], [x=47.560 y=41.663 orient=5.5098], [x=47.560 y=41.663 orient=5.5098], [x=47.605 y=41.790 orient=5.5345], [x=44.789 y=39.838 orient=5.4559], [x=44.105 y=40.440 orient=5.4166], [x=44.705 y=40.464 orient=5.4433], [x=44.388 y=39.991 orient=5.3854], [x=44.228 y=39.784 orient=5.3882], [x=43.851 y=39.928 orient=5.4162], [x=45.267 y=41.141 orient=5.5909], [x=44.395 y=40.638 orient=5.4963], [x=44.935 y=39.941 orient=5.3651], [x=44.935 y=39.941 orient=5.3651], [x=43.791 y=39.989 orient=5.3395], [x=43.659 y=40.279 orient=5.4746], [x=43.659 y=40.279 orient=5.4746], [x=47.046 y=41.210 orient=5.5908], [x=47.046 y=41.210 orient=5.5908], [x=47.367 y=41.850 orient=5.6148], [x=45.092 y=40.658 orient=5.4699], [x=45.394 y=40.723 orient=5.4230], [x=45.090 y=41.136 orient=5.5103], [x=45.090 y=41.136 orient=5.5103], [x=42.343 y=39.555 orient=5.4689], [x=46.317 y=41.208 orient=5.5050], [x=45.294 y=41.614 orient=5.5898], [x=45.528 y=40.997 orient=5.5366], [x=44.385 y=41.268 orient=5.5294], [x=42.363 y=39.954 orient=5.5184], [x=43.969 y=40.231 orient=5.4655], [x=43.021 y=39.307 orient=5.3472], [x=44.690 y=41.024 orient=5.5551], [x=44.794 y=41.362 orient=5.6206], [x=47.690 y=41.972 orient=5.5158], [x=42.470 y=39.307 orient=5.3217], [x=45.763 y=40.820 orient=5.5242], [x=45.523 y=40.589 orient=5.4580], [x=45.523 y=40.589 orient=5.4580], [x=44.797 y=40.438 orient=5.4898], [x=45.903 y=41.024 orient=5.5441], [x=45.991 y=41.101 orient=5.5509], [x=45.991 y=41.101 orient=5.5509], [x=42.223 y=39.976 orient=5.3840], [x=44.601 y=40.883 orient=5.5178], [x=44.652 y=40.633 orient=5.5397], [x=44.559 y=40.704 orient=5.4724], [x=47.498 y=42.052 orient=5.5838], [x=47.588 y=42.167 orient=5.6285], [x=44.593 y=41.276 orient=5.5380], [x=47.042 y=41.944 orient=5.5871], [x=41.941 y=39.291 orient=5.3669], [x=47.240 y=43.271 orient=5.7473], [x=43.571 y=40.450 orient=5.4837], [x=43.571 y=40.450 orient=5.4837], [x=47.162 y=38.050 orient=5.4457], [x=51.197 y=41.546 orient=5.7116], [x=44.788 y=40.023 orient=5.4342], [x=43.632 y=41.057 orient=5.4825], [x=50.648 y=40.562 orient=5.6191], [x=50.920 y=40.944 orient=5.6688], [x=43.256 y=40.337 orient=5.4875], [x=42.854 y=39.499 orient=5.3070]]\n"
       ]
      }
     ],
     "prompt_number": 11
    },
    {
     "cell_type": "heading",
     "level": 3,
     "metadata": {},
     "source": [
      "running it 10 times"
     ]
    },
    {
     "cell_type": "markdown",
     "metadata": {},
     "source": [
      "Ok. The orientations did seem to improve much. What happens if we run the code 10 times (just modify the code above)"
     ]
    },
    {
     "cell_type": "markdown",
     "metadata": {},
     "source": [
      "I hope that you will see that the orientations are all looking good! We have located the robot!"
     ]
    },
    {
     "cell_type": "heading",
     "level": 2,
     "metadata": {},
     "source": [
      "How awesome are we?"
     ]
    },
    {
     "cell_type": "markdown",
     "metadata": {},
     "source": [
      "In the code box below there is a function, <code>eval</code> that takes a robot and the set of particles and computes the mean error.\n",
      "\n",
      "Can you add it to your code so that for every iteration of the 10 iterations it prints the mean error? Something like this:\n",
      "    \n",
      "<code>\n",
      "\n",
      "4.80772045063\n",
      "3.66861975453\n",
      "3.67804838182\n",
      "3.74272012533\n",
      "4.34961300568\n",
      "4.61097899692\n",
      "4.38030581185\n",
      "3.84733993036\n",
      "3.37866737882\n",
      "2.84838797295\n",
      "</code>\n",
      "    \n",
      "    "
     ]
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "def eval(r, p):\n",
      "    sum = 0.0;\n",
      "    for i in range(len(p)): # calculate mean error\n",
      "        dx = (p[i].x - r.x + (world_size/2.0)) % world_size - (world_size/2.0)\n",
      "        dy = (p[i].y - r.y + (world_size/2.0)) % world_size - (world_size/2.0)\n",
      "        err = sqrt(dx * dx + dy * dy)\n",
      "        sum += err\n",
      "    return sum / float(len(p))"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [],
     "prompt_number": 16
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "myrobot = robot()\n",
      "myrobot = myrobot.move(0.1, 5.0)\n",
      "Z = myrobot.sense()\n",
      "N = 1000\n",
      "T = 10 #Leave this as 10 for grading purposes.\n",
      "\n"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "5.50951107199\n",
        "5.07428979845\n",
        "4.21431379919\n",
        "3.99636880956\n",
        "4.16173346204"
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "\n",
        "3.26156643639\n",
        "2.6974431503\n",
        "2.67174869585"
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "\n",
        "2.7581601168\n",
        "2.84907634186\n"
       ]
      }
     ],
     "prompt_number": 17
    },
    {
     "cell_type": "markdown",
     "metadata": {},
     "source": [
      "Finally, can you add an eval before you call the particle filter (but after you create the set of particles)? What is the jump in improvement? (just add this to the code above)"
     ]
    },
    {
     "cell_type": "heading",
     "level": 1,
     "metadata": {},
     "source": [
      "Congratulations. WOW! Etc. You just programmed a particle filter."
     ]
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [],
     "language": "python",
     "metadata": {},
     "outputs": []
    }
   ],
   "metadata": {}
  }
 ]
}